@@ -1,6 +1,6 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005 Rasmus Neckelmann (neckelmann@gmail.com)
+Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -22,7 +22,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 /* 
  *  Convex polygon generation using BSP trees.
  */
-
 #include "Game.h"
 #include "BSP.h"
 #include "VFileIO.h"
@@ -112,6 +111,8 @@ namespace vapp {
       
         delete pPoly;
         Log("** Warning ** : BSP::_Recurse() - empty final polygon ignored");
+        
+        m_nNumErrors++;
       }
     }
     else {
@@ -165,7 +166,8 @@ namespace vapp {
 
     /* Empty? */
     if(pPoly->Vertices.empty()) {
-      Log("** Warning ** : BSP::_SplitPoly() - empty polygon encountered, bash the coder");
+      Log("** Warning ** : BSP::_SplitPoly() - empty polygon encountered");
+      m_nNumErrors++;
       return;
     }
     
@@ -190,7 +192,7 @@ namespace vapp {
     if(nNumInBack==0 && nNumInFront==0) {
       /* Everything is on the line */                 
       Log("** Warning ** : BSP::_SplitPoly() - polygon fully plane aligned");
-      
+      m_nNumErrors++;
       //printf("   %d verts :\n",pPoly->Vertices.size());
       //for(int i=0;i<pPoly->Vertices.size();i++) {
       //  printf("     [%f %f]\n",pPoly->Vertices[i]->P.x,pPoly->Vertices[i]->P.y);
@@ -259,6 +261,8 @@ namespace vapp {
           if(den == 0.0f) { 
             /* This should REALLY not be the case... warning! */
             Log("** Warning ** : BSP::_SplitPoly() - impossible case (1)");
+            m_nNumErrors++;
+            
             /* Now it's best simply to ignore this */
             continue;
           }
@@ -368,6 +372,8 @@ namespace vapp {
           if(den == 0.0f) { 
             /* This should REALLY not be the case... warning! */
             Log("** Warning ** : BSP::_SplitLines() - impossible case (1)");
+            m_nNumErrors++;
+            
             /* Now it's best simply to ignore this */
             continue;
           }
@@ -404,6 +410,8 @@ namespace vapp {
           else {
             /* Another thing we should just ignore */
             Log("** Warning ** : BSP::_SplitLines() - impossible case (2)");
+            m_nNumErrors++;
+            
             continue;
           }         
         }
