@@ -27,8 +27,8 @@ Info
 =============================================================================*/
 
 #define BUILD_MAJORVERSION    0
-#define BUILD_VERSION         1
-#define BUILD_MINORVERSION    16
+#define BUILD_VERSION         2
+#define BUILD_MINORVERSION    0
 #define BUILD_EXTRAINFO       ""
 
 /*=============================================================================
@@ -53,12 +53,18 @@ Build configuration
 /* ENABLE_ZOOMING - Allow user to zoom in and out while playing */
 //#define ENABLE_ZOOMING
 
+/* ALLOW_GHOST - Allow user to see replay ghosts while playing */
+/* (BUG: disabling this will make it impossible to compile) */
 #define ALLOW_GHOST
 
 /* DO_NOT_ALLOW_WEBACCESS - Don't compile with web-access support, 
    regardless of whether libcurl is available or not */
 //#define DO_NOT_ALLOW_WEBACCESS
 
+/* BREAK_ON_EXCEPTION - (Visual C++ debug-mode only) Will break program if an
+   exception occurs */
+//#define BREAK_ON_EXCEPTION
+
 /*=============================================================================
 Misc, don't touch
 =============================================================================*/
