@@ -204,23 +204,6 @@ namespace vapp {
 		m_EntityTable.loadFile("editor.dat");
 		m_EntityTable.consoleDump();
     
-    /* Load textures */  
-    TexMan.setDefaultTextureName("Dirt");         
-    printf("Loading texture thumbnails...\n");
-    std::vector<std::string> TextureFiles = FS::findPhysFiles("Textures/*.jpg");
-    for(int i=0;i<TextureFiles.size();i++) {
-      /* Ignore .. and . */
-      if(TextureFiles[i].at(TextureFiles[i].length()-1) != '.' &&
-        !FS::isDir(TextureFiles[i])) {
-	      printf("    [%s]\n",TextureFiles[i].c_str() );
-        Texture *pTex = TexMan.loadTexture(TextureFiles[i],true);
-        if(pTex != NULL) {
-          pTex->Tag="BLK"; /* this texture is suitable for block graphics */
-        }
-      }
-    }
-    printf("  %d loaded OK\n",TextureFiles.size());
-  
     /* Determine position and size of main GUI elements */
     m_MainMenuAreaSize = Vector2f(160,getDispHeight()-132);
     m_MainMenuAreaPos  = Vector2f(getDispWidth()-m_MainMenuAreaSize.x,0);
@@ -298,9 +281,12 @@ namespace vapp {
     else {
       _NewLevel();
     }
+    
+    /* Load default theme */
+    m_theme.load("Themes/original.xml");
 
 		/* Output log message */
-		m_Log.msg("Ready.");		
+		m_Log.msg("Ready. (X-Moto version %s)",getVersionString().c_str());		
   }
   
   /*============================================================================
@@ -310,7 +296,6 @@ namespace vapp {
     if(m_pLevelSrc != NULL) delete m_pLevelSrc;
     delete m_pEntityMenu;
     delete m_pMainMenu;
-    TexMan.unloadTextures();
   }
   
   /*============================================================================
@@ -437,9 +422,17 @@ namespace vapp {
             TextureSelectionTool Sel;
             std::vector<Texture *> TexList;
             
-            /* Only list textures tagged with "BLK" */
-            TexList = TexMan.fetchTaggedTextures("BLK");
-            
+	          std::vector<Sprite*> v_sprites = m_theme.getSpritesList();
+	          Texture* v_texture;
+	          for(int i=0; i<v_sprites.size(); i++) {
+	            if(v_sprites[i]->getType() == SPRITE_TYPE_TEXTURE) {
+                v_texture = v_sprites[i]->getTexture();
+                if(v_texture != NULL) {
+	                TexList.push_back(v_texture);
+                }
+	            }
+	          }
+	                      
             Vector2f A=Vector2f(17,17);
             Vector2f B=Vector2f(getDispWidth()-66,getDispHeight()-27);
             //glScissor(A.x,getDispHeight() - B.y-1,B.x-A.x+1,B.y-A.y+1);
@@ -1752,7 +1745,13 @@ namespace vapp {
       }      
       CommonTextureID = Blocks[i]->Texture;
     }  
-    return TexMan.getTexture(CommonTextureID);  /* TODO: throw exception if not found instead */
+
+    Sprite* v_sprite = m_theme.getSprite(SPRITE_TYPE_TEXTURE, CommonTextureID);
+    if(v_sprite == NULL) {
+      return NULL;
+    }
+
+    return v_sprite->getTexture();   
   }
   
   /*============================================================================
@@ -2211,7 +2210,7 @@ namespace vapp {
     return pBlock->Vertices[j - 1];
   }  
   
-  void EditorApp::_SmoothEdge(LevelBlock *pBlock,LevelBlockVertex *pEdge,int j) {
+  void EditorApp::_SmoothEdge(LevelBlock *pBlock,LevelBlockVertex *pEdge,unsigned int j) {
     /* Please don't read this (and the related ones) function! :D   I just
        caught my self thinking how this can be done in the easiest way possible 
        *Sigh* */
@@ -2270,7 +2269,7 @@ namespace vapp {
   ============================================================================*/
   void EditorApp::_EntitySnapCursor(void) {
     Vector2f NearP;
-    float fDist;
+    float fDist = 0;
     bool bGotPoint = false;
   
     for(int i=0;i<m_pLevelSrc->getEntityList().size();i++) {
@@ -2296,8 +2295,8 @@ namespace vapp {
     bool bGotPoint = false;
   
     /* Find nearest edge, snap if it's close */
-    for(int i=0;i<m_pLevelSrc->getBlockList().size();i++) {
-      for(int j=0;j<m_pLevelSrc->getBlockList()[i]->Vertices.size();j++) {
+    for(unsigned int i=0;i<m_pLevelSrc->getBlockList().size();i++) {
+      for(unsigned int j=0;j<m_pLevelSrc->getBlockList()[i]->Vertices.size();j++) {
         int k;
         LevelBlockVertex *pVertex = m_pLevelSrc->getBlockList()[i]->Vertices[j];
         LevelBlockVertex *pNextVertex = _NextVertex(m_pLevelSrc->getBlockList()[i],j,&k);
@@ -2346,13 +2345,13 @@ namespace vapp {
   Deleters
   ============================================================================*/
   void EditorApp::_DeleteSelectedBlocks(void) {    
-    int i=0;
-    int nDeleted = 0;
+    unsigned int i=0;
+    unsigned int nDeleted = 0;
     while(1) {
       if(i >= m_pLevelSrc->getBlockList().size()) break;
 
       if(_IsBlockSelected(m_pLevelSrc->getBlockList()[i])) {
-        for(int j=0;j<m_pLevelSrc->getBlockList()[i]->Vertices.size();j++) {
+        for(unsigned int j=0;j<m_pLevelSrc->getBlockList()[i]->Vertices.size();j++) {
           delete m_pLevelSrc->getBlockList()[i]->Vertices[j];
         }
         delete m_pLevelSrc->getBlockList()[i];
@@ -2366,12 +2365,12 @@ namespace vapp {
   }
   
   void EditorApp::_DeleteSelectedVertices(void) {
-    int i=0;
-    int nDeleted = 0,nDeletedObjects = 0;
+    unsigned int i=0;
+    unsigned int nDeleted = 0,nDeletedObjects = 0;
     while(1) {
       if(i >= m_pLevelSrc->getBlockList().size()) break;
 
-      int j=0;
+      unsigned int j=0;
       while(1) {
         if(j >= m_pLevelSrc->getBlockList()[i]->Vertices.size()) break;
         
@@ -2384,7 +2383,7 @@ namespace vapp {
       }
       
       if(m_pLevelSrc->getBlockList()[i]->Vertices.size() < 3) {
-        for(int j=0;j<m_pLevelSrc->getBlockList()[i]->Vertices.size();j++) {
+        for(unsigned int j=0;j<m_pLevelSrc->getBlockList()[i]->Vertices.size();j++) {
           delete m_pLevelSrc->getBlockList()[i]->Vertices[j];
         }
         delete m_pLevelSrc->getBlockList()[i];
@@ -2398,13 +2397,13 @@ namespace vapp {
   }
   
   void EditorApp::_DeleteSelectedEdges(void) {
-    int i=0;
-    int nDeleted = 0,nDeletedObjects = 0;
+    unsigned int i=0;
+    unsigned int nDeleted = 0,nDeletedObjects = 0;
     bool bDeleteNext = false;
     while(1) {
       if(i >= m_pLevelSrc->getBlockList().size()) break;
 
-      int j=0;
+      unsigned int j=0;
       while(1) {
         if(j >= m_pLevelSrc->getBlockList()[i]->Vertices.size()) break;
         
@@ -2431,7 +2430,7 @@ namespace vapp {
       }
       
       if(m_pLevelSrc->getBlockList()[i]->Vertices.size() < 3) {
-        for(int j=0;j<m_pLevelSrc->getBlockList()[j]->Vertices.size();j++) {
+        for(unsigned int j=0;j<m_pLevelSrc->getBlockList()[j]->Vertices.size();j++) {
           delete m_pLevelSrc->getBlockList()[i]->Vertices[j];
         }
         delete m_pLevelSrc->getBlockList()[i];
@@ -2446,13 +2445,13 @@ namespace vapp {
   }
   
   void EditorApp::_DeleteSelectedEntities(void) {
-    int i=0;
-    int nDeleted = 0;
+    unsigned int i=0;
+    unsigned int nDeleted = 0;
     while(1) {
       if(i >= m_pLevelSrc->getEntityList().size()) break;
       
       if(m_pLevelSrc->getEntityList()[i]->bSelected) {
-        for(int j=0;j<m_pLevelSrc->getEntityList()[i]->Params.size();j++)
+        for(unsigned int j=0;j<m_pLevelSrc->getEntityList()[i]->Params.size();j++)
           delete m_pLevelSrc->getEntityList()[i]->Params[j];
         
         delete m_pLevelSrc->getEntityList()[i];
@@ -2468,7 +2467,7 @@ namespace vapp {
   Toggle selected blocks background on/off
   ============================================================================*/
   void EditorApp::_ToggleSelectedBlockBackground(void) {
-    for(int i=0;i<m_pLevelSrc->getBlockList().size();i++) {
+    for(unsigned int i=0;i<m_pLevelSrc->getBlockList().size();i++) {
       LevelBlock *pBlock = m_pLevelSrc->getBlockList()[i];
       if(_IsBlockSelected(pBlock)) {
         pBlock->bBackground = !pBlock->bBackground;
@@ -2480,7 +2479,7 @@ namespace vapp {
   Toggle selected blocks water on/off
   ============================================================================*/
   void EditorApp::_ToggleSelectedBlockWater(void) {
-    for(int i=0;i<m_pLevelSrc->getBlockList().size();i++) {
+    for(unsigned int i=0;i<m_pLevelSrc->getBlockList().size();i++) {
       LevelBlock *pBlock = m_pLevelSrc->getBlockList()[i];
       if(_IsBlockSelected(pBlock)) {
         pBlock->bWater = !pBlock->bWater;
