@@ -253,7 +253,6 @@ namespace vapp {
     
     /* Should we do some text? */
     if(m_bTextInput && m_pTextInputFont!=NULL) {      
-      UIFont *pOldFont = getFont();
       setFont(m_pTextInputFont);
       putText(16,120,m_TextInput + std::string("|"));
     }
@@ -380,7 +379,7 @@ namespace vapp {
   /*===========================================================================
   Base painting
   ===========================================================================*/
-  void UIWindow::putText(int x,int y,std::string Text) {
+  void UIWindow::putText(int x,int y,std::string Text,bool bRotated) {
     /* Draw text at location */
     if(m_pCurFont != NULL) {
       Color c0 = MAKE_COLOR(GET_RED(getTextStyle().c0),
@@ -399,10 +398,14 @@ namespace vapp {
                             GET_GREEN(getTextStyle().c3),
                             GET_BLUE(getTextStyle().c3),
                             (int)(GET_ALPHA(getTextStyle().c3)*getOpacity()/100));
-      UITextDraw::printRawGrad(getFont(),getAbsPosX()+x+1,getAbsPosY()+y+1,
-                               Text,MAKE_COLOR(0,0,0,255),MAKE_COLOR(0,0,0,255),MAKE_COLOR(0,0,0,255),MAKE_COLOR(0,0,0,255));
-      UITextDraw::printRawGrad(getFont(),getAbsPosX()+x,getAbsPosY()+y,
-                               Text,c0,c1,c2,c3);
+
+      UIFont *v_font = getFont();
+      if(v_font != NULL) {
+	UITextDraw::printRawGrad(v_font,getAbsPosX()+x+1,getAbsPosY()+y+1,
+				 Text,MAKE_COLOR(0,0,0,255),MAKE_COLOR(0,0,0,255),MAKE_COLOR(0,0,0,255),MAKE_COLOR(0,0,0,255),bRotated);
+	UITextDraw::printRawGrad(v_font,getAbsPosX()+x,getAbsPosY()+y,
+				 Text,c0,c1,c2,c3,bRotated);
+      }
     }
   }
    
@@ -433,6 +436,8 @@ namespace vapp {
   }
 
   void UIWindow::putElem(int x,int y,int nWidth,int nHeight,UIElem Elem,bool bDisabled,bool bActive) {
+    Texture *vTexture;
+
     struct _ElemTable {
       UIElem E; int nX,nY,nWidth,nHeight;
     };
@@ -469,7 +474,7 @@ namespace vapp {
       UI_ELEM_FRAME_BR,187,198,8,8,
       (UIElem)-1
     };
-    
+        
     int nElem = 0;
     _ElemTable *p = NULL;
     while(Table[nElem].E != -1) {
@@ -499,10 +504,18 @@ namespace vapp {
     int cy = getAbsPosY() + y;
     
     /* Nice. Now we know what to draw */    
-    if(bDisabled) 
-      glBindTexture(GL_TEXTURE_2D,UITexture::getMiscDisabledTexture()->nID);
-    else
-      glBindTexture(GL_TEXTURE_2D,UITexture::getMiscTexture()->nID);
+    if(bDisabled) {
+      vTexture = UITexture::getMiscDisabledTexture();
+      if(vTexture != NULL) {
+	glBindTexture(GL_TEXTURE_2D, vTexture->nID);
+      }
+    }
+    else {
+      vTexture = UITexture::getMiscTexture();
+      if(vTexture != NULL) {
+	glBindTexture(GL_TEXTURE_2D, vTexture->nID);
+      }
+    }
     glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);
     glEnable(GL_TEXTURE_2D);
     glEnable(GL_BLEND);
@@ -530,7 +543,11 @@ namespace vapp {
       if(n<0) n=0;
       if(n>255) n=255; /* just to be sure, i'm lazy */    
       c1=c2=c3=c4=MAKE_COLOR(255,255,255,(int)(n*getOpacity()/100));
-      glBindTexture(GL_TEXTURE_2D,UITexture::getMiscActiveTexture()->nID);
+
+      vTexture = UITexture::getMiscActiveTexture();
+      if(vTexture != NULL) {
+	glBindTexture(GL_TEXTURE_2D, vTexture->nID);
+      }
       glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);
       glEnable(GL_TEXTURE_2D);
       glEnable(GL_BLEND);
@@ -672,8 +689,12 @@ FRAME_BR (187,198) (8x8)
         int nX1,nY1,nX2,nY2;
         getTextExt(m_CurrentContextHelp,&nX1,&nY1,&nX2,&nY2);
         
-        UITextDraw::printRaw(getFont(),getApp()->getDispWidth()-(nX2-nY1),getApp()->getDispHeight()-5,
-                            m_CurrentContextHelp,MAKE_COLOR(255,255,0,255));
+	UIFont *v_font = getFont();
+
+	if(v_font != NULL) {
+	  UITextDraw::printRaw(v_font,getApp()->getDispWidth()-(nX2-nY1),getApp()->getDispHeight()-5,
+			       m_CurrentContextHelp,MAKE_COLOR(255,255,0,255));
+	}
       }
     }
   }
@@ -772,18 +793,20 @@ FRAME_BR (187,198) (8x8)
     int wy = y - pWindow->getPosition().nY;    
     
     /* Inside window? */
-    if(wx >= 0 && wy >= 0 && wx < pWindow->getPosition().nWidth && wy < pWindow->getPosition().nHeight) {
+    if(wx >= 0 && wy >= 0 && wx < pWindow->getPosition().nWidth && wy < pWindow->getPosition().nHeight) {  
       /* Offer activation to this window first */
       if((Event == UI_ROOT_MOUSE_LBUTTON_UP || Event == UI_ROOT_MOUSE_RBUTTON_UP)
           && pWindow->offerActivation()) {
         /* Nice, acquire it. */
         deactivate(this); /* start by making sure nothing is activated */
         pWindow->setActive(true); /* then activate it */
-      }
-    
+      }      
+
       /* Recurse children */
-      for(int i=0;i<pWindow->getChildren().size();i++) {
-        if(_RootMouseEvent(pWindow->getChildren()[i],Event,wx,wy)) return true;
+      for(int i=pWindow->getChildren().size()-1;i>=0;i--) {
+        if(pWindow->getChildren()[i]->offerMouseEvent()) {
+          if(_RootMouseEvent(pWindow->getChildren()[i],Event,wx,wy)) return true;
+        }
       }
       
       /* Then it must be this */
@@ -879,13 +902,18 @@ FRAME_BR (187,198) (8x8)
                 Image = pc;
                 
               /* Try loading texture */
-              Texture *pTexture = getApp()->TexMan.loadTexture(std::string("./Textures/Fonts/") + Image,false,true,false);
+              Texture *pTexture = NULL;
+	      Sprite *pSprite   = getApp()->m_theme.getSprite(SPRITE_TYPE_FONT, Name);
+	      if(pSprite != NULL) {
+	      	pTexture = pSprite->getTexture(false, true, false);
+	      }
+
+
               if(pTexture == NULL)
                 Log("** Warning ** : font texture '%s' missing",Image.c_str());
               else {                  
                 /* Got an empty font */
                 UIFont *pFont = new UIFont;
-                pFont->Image = Image;
                 pFont->Name = Name;
                 pFont->pTexture = pTexture;
                 m_Fonts.push_back(pFont);
@@ -995,7 +1023,7 @@ FRAME_BR (187,198) (8x8)
     glDisable(GL_TEXTURE_2D);
   }
 
-  void UITextDraw::printRawGrad(UIFont *pFont,int x,int y,std::string Text,Color c1,Color c2,Color c3,Color c4) {  
+  void UITextDraw::printRawGrad(UIFont *pFont,int x,int y,std::string Text,Color c1,Color c2,Color c3,Color c4,bool bRotated) {  
     /* Draw text string */
     int cx=x,cy=y;
     
@@ -1007,26 +1035,95 @@ FRAME_BR (187,198) (8x8)
     for(int i=0;i<Text.size();i++) {
       int nChar = Text[i];
       if(nChar == '\n') {
-        cy += (pFont->Chars['|'].nHeight*3)/2;
-        cx = x;
+        if(bRotated) {
+          cy += (pFont->Chars['|'].nHeight*3)/2;
+          cx = x;
+        }
+        else {
+          cy += (pFont->Chars['|'].nHeight*3)/2;
+          cx = x;
+        }
       }
       else if(pFont->Chars[nChar].bAvail) {
-        glBegin(GL_POLYGON);
-        glColor4ub(GET_RED(c1),GET_GREEN(c1),GET_BLUE(c1),GET_ALPHA(c1));
-        glTexCoord2f(pFont->Chars[nChar].fX1,pFont->Chars[nChar].fY1);
-        getApp()->glVertex((cx+pFont->Chars[nChar].nOffsetX),(cy-pFont->Chars[nChar].nOffsetY));
-        glColor4ub(GET_RED(c2),GET_GREEN(c2),GET_BLUE(c2),GET_ALPHA(c2));
-        glTexCoord2f(pFont->Chars[nChar].fX2,pFont->Chars[nChar].fY1);        
-        getApp()->glVertex(cx+pFont->Chars[nChar].nWidth+pFont->Chars[nChar].nOffsetX,cy-pFont->Chars[nChar].nOffsetY);
-        glColor4ub(GET_RED(c3),GET_GREEN(c3),GET_BLUE(c3),GET_ALPHA(c3));
-        glTexCoord2f(pFont->Chars[nChar].fX2,pFont->Chars[nChar].fY2);
-        getApp()->glVertex(cx+pFont->Chars[nChar].nWidth+pFont->Chars[nChar].nOffsetX,cy+pFont->Chars[nChar].nHeight-pFont->Chars[nChar].nOffsetY);
-        glColor4ub(GET_RED(c4),GET_GREEN(c4),GET_BLUE(c4),GET_ALPHA(c4));
-        glTexCoord2f(pFont->Chars[nChar].fX1,pFont->Chars[nChar].fY2);
-        getApp()->glVertex(cx+pFont->Chars[nChar].nOffsetX,cy+pFont->Chars[nChar].nHeight-pFont->Chars[nChar].nOffsetY);
-        glEnd();
-        
-        cx += pFont->Chars[nChar].nIncX;
+        if(bRotated) {
+          //glBegin(GL_POLYGON);
+          //glColor4ub(GET_RED(c1),GET_GREEN(c1),GET_BLUE(c1),GET_ALPHA(c1));
+          //glTexCoord2f(pFont->Chars[nChar].fX1,pFont->Chars[nChar].fY1);
+          //getApp()->glVertex((cx-pFont->Chars[nChar].nOffsetY),(cy-pFont->Chars[nChar].nOffsetX));
+          //glColor4ub(GET_RED(c2),GET_GREEN(c2),GET_BLUE(c2),GET_ALPHA(c2));
+          //glTexCoord2f(pFont->Chars[nChar].fX2,pFont->Chars[nChar].fY1);        
+          //getApp()->glVertex(cx-pFont->Chars[nChar].nOffsetY,cy-pFont->Chars[nChar].nOffsetX-pFont->Chars[nChar].nWidth);
+          //glColor4ub(GET_RED(c3),GET_GREEN(c3),GET_BLUE(c3),GET_ALPHA(c3));
+          //glTexCoord2f(pFont->Chars[nChar].fX2,pFont->Chars[nChar].fY2);
+          //getApp()->glVertex(cx+pFont->Chars[nChar].nHeight-pFont->Chars[nChar].nOffsetY,cy-pFont->Chars[nChar].nOffsetX-pFont->Chars[nChar].nWidth);
+          //glColor4ub(GET_RED(c4),GET_GREEN(c4),GET_BLUE(c4),GET_ALPHA(c4));
+          //glTexCoord2f(pFont->Chars[nChar].fX1,pFont->Chars[nChar].fY2);
+          //getApp()->glVertex(cx+pFont->Chars[nChar].nHeight-pFont->Chars[nChar].nOffsetY,(cy-pFont->Chars[nChar].nOffsetX));
+          //glEnd();
+
+          glBegin(GL_POLYGON);
+          glColor4ub(GET_RED(c1),GET_GREEN(c1),GET_BLUE(c1),GET_ALPHA(c1));
+          glTexCoord2f(pFont->Chars[nChar].fX1,pFont->Chars[nChar].fY1);
+          getApp()->glVertex((cx+pFont->Chars[nChar].nOffsetX),(cy-pFont->Chars[nChar].nOffsetY));
+          glColor4ub(GET_RED(c2),GET_GREEN(c2),GET_BLUE(c2),GET_ALPHA(c2));
+          glTexCoord2f(pFont->Chars[nChar].fX2,pFont->Chars[nChar].fY1);        
+          getApp()->glVertex(cx+pFont->Chars[nChar].nWidth+pFont->Chars[nChar].nOffsetX,cy-pFont->Chars[nChar].nOffsetY);
+          glColor4ub(GET_RED(c3),GET_GREEN(c3),GET_BLUE(c3),GET_ALPHA(c3));
+          glTexCoord2f(pFont->Chars[nChar].fX2,pFont->Chars[nChar].fY2);
+          getApp()->glVertex(cx+pFont->Chars[nChar].nWidth+pFont->Chars[nChar].nOffsetX,cy+pFont->Chars[nChar].nHeight-pFont->Chars[nChar].nOffsetY);
+          glColor4ub(GET_RED(c4),GET_GREEN(c4),GET_BLUE(c4),GET_ALPHA(c4));
+          glTexCoord2f(pFont->Chars[nChar].fX1,pFont->Chars[nChar].fY2);
+          getApp()->glVertex(cx+pFont->Chars[nChar].nOffsetX,cy+pFont->Chars[nChar].nHeight-pFont->Chars[nChar].nOffsetY);
+          glEnd();
+
+          //glBegin(GL_POLYGON);
+          //glColor4ub(GET_RED(c1),GET_GREEN(c1),GET_BLUE(c1),GET_ALPHA(c1));
+          //glTexCoord2f(pFont->Chars[nChar].fX1,pFont->Chars[nChar].fY1);
+          //getApp()->glVertex((cx-pFont->Chars[nChar].nOffsetY),(cy-pFont->Chars[nChar].nOffsetX));
+          //glColor4ub(GET_RED(c2),GET_GREEN(c2),GET_BLUE(c2),GET_ALPHA(c2));
+          //glTexCoord2f(pFont->Chars[nChar].fX2,pFont->Chars[nChar].fY1);        
+          //getApp()->glVertex(cx-pFont->Chars[nChar].nOffsetY,cy-pFont->Chars[nChar].nOffsetX-pFont->Chars[nChar].nWidth);
+          //glColor4ub(GET_RED(c3),GET_GREEN(c3),GET_BLUE(c3),GET_ALPHA(c3));
+          //glTexCoord2f(pFont->Chars[nChar].fX2,pFont->Chars[nChar].fY2);
+          //getApp()->glVertex(cx+pFont->Chars[nChar].nHeight-pFont->Chars[nChar].nOffsetY,cy-pFont->Chars[nChar].nOffsetX-pFont->Chars[nChar].nWidth);
+          //glColor4ub(GET_RED(c4),GET_GREEN(c4),GET_BLUE(c4),GET_ALPHA(c4));
+          //glTexCoord2f(pFont->Chars[nChar].fX1,pFont->Chars[nChar].fY2);
+          //getApp()->glVertex(cx+pFont->Chars[nChar].nHeight-pFont->Chars[nChar].nOffsetY,(cy-pFont->Chars[nChar].nOffsetX));
+          //glEnd();
+          
+          //glDisable(GL_TEXTURE_2D);
+          //glBegin(GL_LINE_LOOP);
+          //glColor4f(1,0,0,1);          
+          //getApp()->glVertex((cx+pFont->Chars[nChar].nOffsetX),(cy-pFont->Chars[nChar].nOffsetY));
+          //glColor4f(0,1,0,1);          
+          //getApp()->glVertex(cx+pFont->Chars[nChar].nOffsetX,cy-pFont->Chars[nChar].nOffsetY-pFont->Chars[nChar].nWidth);
+          //glColor4f(0,0,1,1);          
+          //getApp()->glVertex(cx+pFont->Chars[nChar].nHeight+pFont->Chars[nChar].nOffsetX,cy-pFont->Chars[nChar].nOffsetY-pFont->Chars[nChar].nWidth);
+          //glColor4f(0,0,0,1);          
+          //getApp()->glVertex(cx+pFont->Chars[nChar].nHeight+pFont->Chars[nChar].nOffsetX,(cy-pFont->Chars[nChar].nOffsetY));
+          //glEnd();
+          //glEnable(GL_TEXTURE_2D);
+          //
+          cy += (pFont->Chars[nChar].nHeight*5)/4;
+        }
+        else {
+          glBegin(GL_POLYGON);
+          glColor4ub(GET_RED(c1),GET_GREEN(c1),GET_BLUE(c1),GET_ALPHA(c1));
+          glTexCoord2f(pFont->Chars[nChar].fX1,pFont->Chars[nChar].fY1);
+          getApp()->glVertex((cx+pFont->Chars[nChar].nOffsetX),(cy-pFont->Chars[nChar].nOffsetY));
+          glColor4ub(GET_RED(c2),GET_GREEN(c2),GET_BLUE(c2),GET_ALPHA(c2));
+          glTexCoord2f(pFont->Chars[nChar].fX2,pFont->Chars[nChar].fY1);        
+          getApp()->glVertex(cx+pFont->Chars[nChar].nWidth+pFont->Chars[nChar].nOffsetX,cy-pFont->Chars[nChar].nOffsetY);
+          glColor4ub(GET_RED(c3),GET_GREEN(c3),GET_BLUE(c3),GET_ALPHA(c3));
+          glTexCoord2f(pFont->Chars[nChar].fX2,pFont->Chars[nChar].fY2);
+          getApp()->glVertex(cx+pFont->Chars[nChar].nWidth+pFont->Chars[nChar].nOffsetX,cy+pFont->Chars[nChar].nHeight-pFont->Chars[nChar].nOffsetY);
+          glColor4ub(GET_RED(c4),GET_GREEN(c4),GET_BLUE(c4),GET_ALPHA(c4));
+          glTexCoord2f(pFont->Chars[nChar].fX1,pFont->Chars[nChar].fY2);
+          getApp()->glVertex(cx+pFont->Chars[nChar].nOffsetX,cy+pFont->Chars[nChar].nHeight-pFont->Chars[nChar].nOffsetY);
+          glEnd();
+          
+          cx += pFont->Chars[nChar].nIncX;
+        }
       }
       else
         cx += pFont->Chars['-'].nIncX;
@@ -1089,18 +1186,7 @@ FRAME_BR (187,198) (8x8)
 
   /*===========================================================================
   Texture mangling
-  ===========================================================================*/
-  Texture *UITexture::load(std::string Name) {
-    for(int i=0;i<m_Textures.size();i++) {
-      if(m_TextureNames[i] == Name) return m_Textures[i];
-    }
-    Texture *pTex = m_pApp->TexMan.loadTexture(Name,false,true,false);
-    if(pTex == NULL) throw Exception("UI texture failed to load");
-    m_TextureNames.push_back(Name);
-    m_Textures.push_back(pTex);
-    return pTex;
-  }
-  
+  ===========================================================================*/ 
   App *UITexture::getApp(void) {
     return m_pApp;
   }
@@ -1120,14 +1206,25 @@ FRAME_BR (187,198) (8x8)
   void UITexture::setApp(App *pApp) {
     m_pApp = pApp;
     
-    m_pUIElemTexture = load("./Textures/UI/Misc.png");
-    m_pUIElemTextureD = load("./Textures/UI/MiscDisabled.png");
-    m_pUIElemTextureA = load("./Textures/UI/MiscActive.png");
+    Sprite *pSprite;
+
+    pSprite = m_pApp->m_theme.getSprite(SPRITE_TYPE_UI, "Misc");
+    if(pSprite != NULL) {
+      m_pUIElemTexture = pSprite->getTexture(false,true,false);
+    }
+
+    pSprite = m_pApp->m_theme.getSprite(SPRITE_TYPE_UI, "MiscDisabled");
+    if(pSprite != NULL) {
+      m_pUIElemTextureD = pSprite->getTexture(false,true,false);
+    }
+
+    pSprite = m_pApp->m_theme.getSprite(SPRITE_TYPE_UI, "MiscActive");
+    if(pSprite != NULL) {
+      m_pUIElemTextureA = pSprite->getTexture(false,true,false);
+    }
   }
   
   /* Static class data */  
-  std::vector<Texture *> UITexture::m_Textures;
-  std::vector<std::string> UITexture::m_TextureNames;
   App *UITexture::m_pApp = NULL;
   Texture *UITexture::m_pUIElemTexture = NULL;
   Texture *UITexture::m_pUIElemTextureD = NULL;
