@@ -114,7 +114,6 @@ namespace vapp {
     }
   
     std::string Name;
-    std::string Image;
     UIFontChar Chars[256];
     Texture *pTexture;
   };
@@ -136,7 +135,6 @@ namespace vapp {
   ===========================================================================*/
   class UITexture {
     public:
-      static Texture *load(std::string Name);
       static App *getApp(void);
       static void setApp(App *pApp);
       static Texture *getMiscTexture(void);
@@ -144,8 +142,6 @@ namespace vapp {
       static Texture *getMiscActiveTexture(void);
     
     private:
-      static std::vector<Texture *> m_Textures;
-      static std::vector<std::string> m_TextureNames;
       static App *m_pApp;
       
       static Texture *m_pUIElemTexture;
@@ -162,7 +158,7 @@ namespace vapp {
       static void uninitTextDrawing(void);
       static UIFont *getFont(std::string Name);
       static void printRaw(UIFont *pFont,int x,int y,std::string Text,Color c);
-      static void printRawGrad(UIFont *pFont,int x,int y,std::string Text,Color c1,Color c2,Color c3,Color c4);
+      static void printRawGrad(UIFont *pFont,int x,int y,std::string Text,Color c1,Color c2,Color c3,Color c4,bool bRotated=false);
       static int getRefCount(void);
       static App *getApp(void);
       static void getTextExt(UIFont *pFont,std::string Text,int *pnMinX,int *pnMinY,int *pnMaxX,int *pnMaxY);
@@ -221,10 +217,11 @@ namespace vapp {
       virtual bool keyDown(int nKey,int nChar) {return false;}
       virtual bool keyUp(int nKey) {return false;}
       virtual bool offerActivation(void) {return false;}
+      virtual bool offerMouseEvent(void) {return true;}
       virtual std::string subContextHelp(int x,int y) {return "";}
 
       /* Painting */            
-      void putText(int x,int y,std::string Text);      
+      void putText(int x,int y,std::string Text,bool bRotated=false);      
       void putImage(int x,int y,int nWidth,int nHeight,Texture *pImage);
       void putElem(int x,int y,int nWidth,int nHeight,UIElem Elem,bool bDisabled,bool bActive=false);
       void putRect(int x,int y,int nWidth,int nHeight,Color c);
@@ -259,7 +256,7 @@ namespace vapp {
       App *getApp(void) {return m_pApp;}
       void setApp(App *pApp) {m_pApp=pApp;}
       void setID(std::string ID) {m_ID=ID;}
-      std::string getID(void) {return m_ID;}
+      std::string getID(void) {return m_ID;}      
       std::vector<UIWindow *> &getChildren(void) {return m_Children;}
       UIRect &getPosition(void) {return m_Pos;}
       void setPosition(int x,int y,int nWidth,int nHeight) {m_Pos.nX=x; m_Pos.nY=y; m_Pos.nWidth=nWidth; m_Pos.nHeight=nHeight;}
@@ -344,24 +341,25 @@ namespace vapp {
   ===========================================================================*/
   enum UIFrameStyle {
     UI_FRAMESTYLE_MENU,                         /* "Iron-like" scaled menu */
-    UI_FRAMESTYLE_TRANS                         /* Generic transparent one */
+    UI_FRAMESTYLE_TRANS,                        /* Generic transparent one */
+    UI_FRAMESTYLE_LEFTTAG,                      /* Like above, but with left tag */
   };
   
   class UIFrame : public UIWindow {
     public:
-      UIFrame() {}
-      UIFrame(UIWindow *pParent,int x=0,int y=0,std::string Caption="",int nWidth=0,int nHeight=0) {
-        initW(pParent,x,y,Caption,nWidth,nHeight);
-        
-        m_Style=UI_FRAMESTYLE_TRANS;
-        m_pMenuTL=UITexture::load("./Textures/UI/MenuTL.png");
-        m_pMenuTR=UITexture::load("./Textures/UI/MenuTR.png");
-        m_pMenuBL=UITexture::load("./Textures/UI/MenuBL.png");
-        m_pMenuBR=UITexture::load("./Textures/UI/MenuBR.png");                         
-      }      
+      UIFrame();
+      UIFrame(UIWindow *pParent,
+	      int x=0,int y=0,
+	      std::string Caption="",
+	      int nWidth=0,int nHeight=0);    
     
       /* Methods */
       virtual void paint(void);
+      virtual void mouseLDown(int x,int y);
+      virtual void mouseHover(int x,int y);
+      
+      void makeMinimizable(int nMinX,int nMinY);
+      void setMinimized(bool b);
       
       /* Data interface */
       UIFrameStyle getStyle(void) {return m_Style;}
@@ -371,6 +369,12 @@ namespace vapp {
       /* Data */
       UIFrameStyle m_Style;
       
+      bool m_bHover;
+      bool m_bMinimizable;
+      bool m_bMinimized;
+      int m_nMinimizedX,m_nMinimizedY; /* Minimized position */
+      int m_nMaximizedX,m_nMaximizedY; /* Maximized position */
+      float m_fMinMaxTime;
       Texture *m_pMenuTL,*m_pMenuTR,*m_pMenuBL,*m_pMenuBR;
   };
 
@@ -486,13 +490,19 @@ namespace vapp {
         
         m_bBackgroundShade = false;
         
-        m_pDarkBlobTexture = UITexture::load("./Textures/UI/DarkBlob.png");                         
+        m_pDarkBlobTexture = NULL;
+	Sprite *pSprite;
+	pSprite = getApp()->m_theme.getSprite(SPRITE_TYPE_UI, "DarkBlob");
+	if(pSprite != NULL) {
+	  m_pDarkBlobTexture = pSprite->getTexture(false,true,false);
+	}
         
         m_pCustomBackgroundTexture = NULL;
       }      
 
       /* Methods */
       virtual void paint(void);
+      virtual bool offerMouseEvent(void) {return false;}
       
       /* Data interface */
       void setVAlign(UIAlign Align) {m_VAlign=Align;}
@@ -597,6 +607,10 @@ namespace vapp {
         
 	m_bClicked = false;
 
+	m_bChanged = false;
+
+	m_lastRefreshTime = getApp()->getRealTime();
+
         unhideAllColumns();
       }      
       virtual ~UIList() {_FreeUIList();}
@@ -621,7 +635,7 @@ namespace vapp {
       std::vector<UIListEntry *> &getEntries(void) {return m_Entries;}      
       std::vector<std::string> &getColumns(void) {return m_Columns;}
       int getSelected(void) {return m_nSelected;}
-      void setSelected(int n) {m_nSelected = n;}
+      void setSelected(int n) {m_bChanged = true; m_nSelected = n;}
       void addColumn(std::string Title,int nWidth) {m_Columns.push_back(Title); m_ColumnWidths.push_back(nWidth);}
       void setEnterButton(UIButton *pButton) {m_pEnterButton = pButton;}
       bool isItemActivated(void) {return m_bItemActivated;}
@@ -632,8 +646,13 @@ namespace vapp {
       bool isClicked(void) {return m_bClicked;}
       void setClicked(bool b) {m_bClicked=b;}
 
+      bool isChanged(void) {return m_bChanged;}
+      void setChanged(bool b) {m_bChanged=b;}
+
     private:
       /* Data */
+      bool m_bChanged;
+      float m_lastRefreshTime;
       bool m_bSort;
       std::vector<UIListEntry *> m_Entries;
       std::vector<std::string> m_Columns;
@@ -654,6 +673,7 @@ namespace vapp {
       void _FreeUIList(void);
       void _NewlySelectedItem(void);
       void _Scroll(int nPixels);
+      void _refreshByTime();
   };
 
 	/*===========================================================================
@@ -666,7 +686,7 @@ namespace vapp {
         initW(pParent,x,y,Caption,nWidth,nHeight);        
         
         m_nSelected = 0;
-	m_bChanged = 0;
+	m_bChanged = false;
       }      
 
       /* Methods */
@@ -679,7 +699,7 @@ namespace vapp {
       virtual std::string subContextHelp(int x,int y);
       
       void setTabContextHelp(int nTab,const std::string &s);
-      
+
       /* Data interface */      
       UIWindow *getSelected(void) {
         if(!getChildren().empty() && m_nSelected >= 0 && m_nSelected < getChildren().size()) 
@@ -689,14 +709,14 @@ namespace vapp {
       void setSelected(int n) {
         m_nSelected = n;
       }
-      
+
       bool isChanged(void) {return m_bChanged;}
       void setChanged(bool b) {m_bChanged=b;}
 
     private:
       /* Data */
-      int m_nSelected;
       bool m_bChanged;
+      int m_nSelected;
       std::vector<std::string> m_TabContextHelp;
   };
 
