@@ -28,15 +28,34 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 namespace vapp {
 
+  void UIList::_refreshByTime() {
+    float v_time = getApp()->getRealTime();
+
+    while(m_lastRefreshTime + 0.01 < v_time) {
+      
+      if(m_bScrollDownPressed) {
+	      _Scroll(-1);
+      }
+      
+      if(m_bScrollUpPressed) {
+	      _Scroll(1);
+      }
+      
+      m_lastRefreshTime = v_time;
+    }
+  }
+
   /*===========================================================================
   Painting
   ===========================================================================*/
   void UIList::paint(void) {
+    _refreshByTime();
+
     bool bDisabled = isDisabled();
     bool bActive = isActive();
-    
+
     m_bItemActivated = false;
-  
+
     /* Draw list frame */
     putElem(0,0,-1,-1,UI_ELEM_FRAME_TL,false);
     putElem(getPosition().nWidth-8,0,-1,-1,UI_ELEM_FRAME_TR,false);
@@ -193,7 +212,7 @@ namespace vapp {
         if(x >= nLX && x <getPosition().nWidth-6 &&
           y >= yy && y < yy+nRowHeight) {
           /* Select this */
-          m_nSelected = i;
+	  setSelected(i);
           _NewlySelectedItem();
           
           /* AND invoke enter-button */
@@ -222,11 +241,13 @@ namespace vapp {
     if(x >= nLX+nLWidth && x < nLX+nLWidth + 20 &&
        y >= 6 && y < 6+20) {
       /* Scroll up! */
+      //_Scroll(16);
       m_bScrollUpPressed = true;
     } 
     else if(x >= nLX+nLWidth && x < nLX+nLWidth + 20 &&
        y >= nLY+nLHeight-20 && y < nLY+nLHeight) {
       /* Scroll down! */
+	 // _Scroll(-16);
       m_bScrollDownPressed = true;
     }    
     else {
@@ -236,7 +257,7 @@ namespace vapp {
         if(x >= nLX && x <getPosition().nWidth-6 &&
           y >= yy && y < yy+nRowHeight) {
           /* Select this */
-          m_nSelected = i;
+	  setSelected(i);
           _NewlySelectedItem();
           break;
         }
@@ -255,12 +276,12 @@ namespace vapp {
     if(x >= nLX+nLWidth && x < nLX+nLWidth + 20 &&
        y >= 6 && y < 26) {
       /* Scroll up! */
-      _Scroll(16);
+      //_Scroll(16);
     } 
     else if(x >= nLX+nLWidth && x < nLX+nLWidth + 20 &&
        y >= nLY+nLHeight-20 && y < nLY+nLHeight) {
       /* Scroll down! */
-      _Scroll(-16);
+      //_Scroll(-16);
     }
 
     m_bClicked = true;  
@@ -301,11 +322,21 @@ namespace vapp {
     p->Text.push_back(Text);
     p->pvUser = pvUser;
     
+    /* Make a temp. lowercase text */
+    std::string LCText = Text;
+    for(int i=0;i<LCText.length();i++)
+      LCText[i] = tolower(LCText[i]);
+    
     /* Sorted? */
     if(m_bSort) {
       /* Yeah, keep it alphabetical, please */
       for(int i=0;i<m_Entries.size();i++) {
-        if(Text < m_Entries[i]->Text[0]) {
+        /* Make lowercase before comparing */
+        std::string LC = m_Entries[i]->Text[0];
+        for(int j=0;j<LC.length();j++)  
+          LC[j] = tolower(LC[j]);
+      
+        if(LCText < LC) {
           /* Here! */
           m_Entries.insert(m_Entries.begin() + i,p);
           return p;
@@ -403,6 +434,36 @@ namespace vapp {
         return true;
     }
     
+    /* Maybe it's a character? If so, try jumping to a suitable place in the list */
+    if(nChar != 0) {
+      bool bContinue;
+      int nPos = 0;
+      
+      do {
+        bContinue = false;
+        
+        /* Look at character number 'nPos' in all entries */
+        for(int i=0;i<m_Entries.size();i++) {
+          int nEntryIdx = i + getSelected() + 1; /* always start looking at the next */
+          nEntryIdx %= m_Entries.size();
+        
+          if(m_Entries[nEntryIdx]->Text[0].length() > nPos) {
+            if(tolower(m_Entries[nEntryIdx]->Text[0].at(nPos)) == tolower(nChar)) {
+              /* Nice, select this one */
+              setSelected(nEntryIdx);
+              _NewlySelectedItem();              
+              bContinue = false;
+              return true;
+            }
+            
+            bContinue = true;
+          }
+        }
+        
+        nPos++;
+      } while(bContinue);
+    }
+    
     /* w00t? we don't want that silly keypress! */
     return false;
   }
