@@ -37,6 +37,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "WWW.h"
 #include "WWWAppInterface.h"
 #include "GUIXMoto.h"
+#include "Stats.h"
 
 namespace vapp {
 
@@ -106,10 +107,11 @@ namespace vapp {
                  m_bTimeDemo=false;
                  m_bShowFrameRate=false;
                  m_bEnableLevelCache=true;
+                 m_bEnableMenuMusic=false;
                  m_pQuitMsgBox=NULL;
                  m_pNotifyMsgBox=NULL;
 #if defined(SUPPORT_WEBACCESS)
-                 m_pDownloadLevelsMsgBox=NULL;
+                 m_pDownloadMsgBox=NULL;
                  m_pNewLevelsAvailIcon=NULL;
                  m_pWebConfEditor=NULL;
                  m_pWebConfMsgBox=NULL;
@@ -120,12 +122,14 @@ namespace vapp {
                  m_pSaveReplayMsgBox=NULL;
                  m_pReplaysWindow=NULL;
                  m_pLevelPacksWindow=NULL;
+                 m_pStatsReport=NULL;
                  m_pLevelPackViewer=NULL;  
                  m_pActiveLevelPack=NULL;
                  m_pGameInfoWindow=NULL;
                  m_b50FpsMode = false;
                  m_bUglyMode = false;
                  m_pReplay = NULL;
+                 m_pMenuMusic = NULL;
 #if defined(ALLOW_GHOST)
 		 m_pGhostReplay = NULL;
 		 m_lastGhostReplay = "";
@@ -144,7 +148,7 @@ namespace vapp {
                  m_bEnableEngineSound = true;
                  m_bCompressReplays = true;
                  m_bBenchmark = false;
-                 m_bEnableContextHelp = true;
+                 m_bEnableContextHelp = true;                 
 
 #if defined(SUPPORT_WEBACCESS)
                  m_bShowWebHighscoreInGame = false;
@@ -158,13 +162,20 @@ namespace vapp {
 		 m_bEnableCheckNewLevelsAtStartup  = true;
 		 m_bEnableCheckHighscoresAtStartup = true;
 #endif
+		 m_fLastSqueekTime = 0.0f;
+
+
+		 m_Renderer.setTheme(&m_theme);
+		 m_MotoGame.setRenderer(&m_Renderer);
+
+		 m_currentThemeName = THEME_DEFAULT_THEMENAME;
                  }
                  
 #if defined(SUPPORT_WEBACCESS)                 
         /* WWWAppInterface implementation */ 
         virtual void setTaskProgress(float fPercent);
 
-        virtual void setBeingDownloadedLevel(const std::string &LevelName,bool p_bNew = true);
+        virtual void setBeingDownloadedInformation(const std::string &p_information,bool p_bNew = true);
         virtual void readEvents(void);
         
         virtual bool doesLevelExist(const std::string &LevelID); 
@@ -173,6 +184,7 @@ namespace vapp {
         virtual std::string levelPathForUpdate(const std::string &p_LevelId);
         virtual std::string levelCRC32Sum(const std::string &p_LevelId);
         virtual std::string levelMD5Sum(const std::string &LevelID);
+
 #endif
       
       /* Virtual methods */
@@ -188,10 +200,14 @@ namespace vapp {
       virtual void parseUserArgs(std::vector<std::string> &UserArgs);
       virtual void helpUserArgs(void);
       virtual void selectDisplayMode(int *pnWidth,int *pnHeight,int *pnBPP,bool *pbWindowed);
-      
+      virtual std::string getConfigThemeName(ThemeChoicer *p_themeChoicer);
+
       /* Methods */
       void setState(GameState s);
       void notifyMsg(std::string Msg);      
+      
+      /* Data interface */
+      bool isUglyMode(void) {return m_bUglyMode;}
     
     private: 
       EngineSoundSimulator m_EngineSound;
@@ -199,7 +215,8 @@ namespace vapp {
       /* Data */
       ReplayList m_ReplayList;                  /* Replay list */
       std::vector<LevelPack *> m_LevelPacks;    /* Level packs */
-      
+
+      bool m_bEnableMenuMusic;                  /* true: Play menu music */      
       bool m_bEnableContextHelp;                /* true: Show context help */
       bool m_bBenchmark;                        /* true: Test game performance */
       bool m_bShowFrameRate;                    /* true: frame rate */
@@ -229,11 +246,14 @@ namespace vapp {
       int m_nFrame;                             /* Frame # */
       PlayerProfile *m_pPlayer;                 /* The player's profile */
       
+      Mix_Music *m_pMenuMusic;
+      
       double m_fLastFrameTime;                  /* When the last frama was initiated */
       double m_fLastPerfStateTime;
       float m_fLastStateSerializationTime;    
       double m_fLastPhysTime;                  /* When the last physic was computed */
       double m_fStartTime;                      
+      double m_fLastSqueekTime;
       
       bool m_b50FpsMode;
       
@@ -257,7 +277,8 @@ namespace vapp {
       WebRoom *m_pWebHighscores;
       WebLevels *m_pWebLevels;
       ProxySettings m_ProxySettings;
-      std::string m_DownloadingLevel;
+      std::string m_DownloadingInformation;
+      std::string m_DownloadingMessage;
       float m_fDownloadTaskProgressLast;
 
       bool m_bEnableWebHighscores;              /* true: Read world highscores from website */
@@ -268,6 +289,11 @@ namespace vapp {
 
 #endif
       
+      ThemeChoicer *m_themeChoicer;
+
+      Stats m_GameStats;
+      UIWindow *m_pStatsReport;
+      
       /* Sound effects */
       SoundSample *m_pEndOfLevelSFX;
       SoundSample *m_pStrawberryPickupSFX;
@@ -278,9 +304,8 @@ namespace vapp {
       UIMsgBox *m_pQuitMsgBox;
       UIMsgBox *m_pNotifyMsgBox;
 #if defined(SUPPORT_WEBACCESS)
-      UIMsgBox *m_pDownloadLevelsMsgBox;
-      UIRect m_DownloadLevelsMsgBoxRect;
-      UIRect m_pDownloadHighscoreMsgBoxRect;
+      UIMsgBox *m_pDownloadMsgBox;
+      UIRect m_DownloadMsgBoxRect;
 #endif            
 
       /* Main menu background / title */
@@ -299,6 +324,7 @@ namespace vapp {
       UIWindow *m_pMainMenu;
       UIMsgBox *m_pDeleteReplayMsgBox;
       UIFrame *m_pGameInfoWindow;
+      UIFrame *m_pStatsWindow;
       
       /* LEVEL lists */
       UILevelList *m_pPlayExternalLevelsList;
@@ -368,7 +394,8 @@ namespace vapp {
       bool m_bRecordReplays;
       float m_fReplayFrameRate;
       float m_fCurrentReplayFrameRate;
-            
+      std::string m_currentThemeName;            
+
       /* Helpers */
 #if defined(SUPPORT_WEBACCESS) 
       void _UpdateWorldRecord(const std::string &LevelID);
@@ -386,6 +413,7 @@ namespace vapp {
       void _HandleLevelPackViewer(void);
       void _CreateLevelLists(UILevelList *pExternalLevels,UILevelList *pInternalLevels);
       void _CreateReplaysList(UIList *pList);
+      void _CreateThemesList(UIList *pList);
       void _CreateProfileList(void);
       void _CreateDefaultConfig(void);
       void _CreateLevelPackLevelList(void);
@@ -406,6 +434,7 @@ namespace vapp {
       void _UpdateSettings(void);
       void _UpdateLevelLists(void);
       void _UpdateReplaysList(void);
+      void _UpdateThemesLists(void);
       void _GameScreenshot(void);
       void _SaveReplay(const std::string &Name);
     
@@ -430,6 +459,8 @@ namespace vapp {
       void _CheckForExtraLevels(void);
       void _UpdateWebHighscores(bool bSilent);
       void _UpdateWebLevels(bool bSilent);
+      void _UpdateWebThemes(bool bSilent);
+      void _UpdateWebTheme(ThemeChoice* pThemeChoice, bool bNotify);
       void _UpgradeWebHighscores();
       void _DownloadExtraLevels(void);
       void _ConfigureProxy(void);
