@@ -192,6 +192,26 @@ namespace vapp {
 	}
 	break;
 	
+      case GAME_EVENT_LUA_CALL_SETBLOCKCENTER:
+	{
+	  int n;
+	  (*Buffer) >> n;
+	  if(n >= sizeof(Event.u.LuaCallSetBlockCenter.cBlockID)) {
+	    Log("** Warning ** : Block name in replay too long, ignoring all events!");
+	    bError = true;
+	  }
+	  else {
+	    (*Buffer).readBuf(Event.u.LuaCallSetBlockCenter.cBlockID,n);
+	    Event.u.LuaCallSetBlockCenter.cBlockID[n] = '\0';
+
+	    (*Buffer) >> Event.u.LuaCallSetBlockCenter.x;
+	    (*Buffer) >> Event.u.LuaCallSetBlockCenter.y;
+
+	    bIsOk = true;
+	  }
+	}
+	break;
+	
       case GAME_EVENT_LUA_CALL_SETGRAVITY:
 	{
 	  (*Buffer) >> Event.u.LuaCallSetgravity.x;
@@ -209,6 +229,147 @@ namespace vapp {
 	}
 	break;
 	
+    case GAME_EVENT_LUA_CALL_SETDYNAMICENTITYROTATION:
+      {
+	  int n;
+	  (*Buffer) >> n;
+	  if(n >= sizeof(Event.u.LuaCallSetDynamicEntityRotation.cEntityID)) {
+	    Log("** Warning ** : Entity name in replay too long, ignoring all events!");
+	    bError = true;
+	  }
+	  else {
+	    (*Buffer).readBuf(Event.u.LuaCallSetDynamicEntityRotation.cEntityID,n);
+	    Event.u.LuaCallSetDynamicEntityRotation.cEntityID[n] = '\0';
+
+	    (*Buffer) >> Event.u.LuaCallSetDynamicEntityRotation.fInitAngle;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicEntityRotation.fRadius;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicEntityRotation.fPeriod;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicEntityRotation.startTime;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicEntityRotation.endTime;
+
+	    bIsOk = true;
+	  }
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_SETDYNAMICENTITYTRANSLATION:
+      {
+	  int n;
+	  (*Buffer) >> n;
+	  if(n >= sizeof(Event.u.LuaCallSetDynamicEntityTranslation.cEntityID)) {
+	    Log("** Warning ** : Entity name in replay too long, ignoring all events!");
+	    bError = true;
+	  }
+	  else {
+	    (*Buffer).readBuf(Event.u.LuaCallSetDynamicEntityTranslation.cEntityID,n);
+	    Event.u.LuaCallSetDynamicEntityTranslation.cEntityID[n] = '\0';
+
+	    (*Buffer) >> Event.u.LuaCallSetDynamicEntityTranslation.fX;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicEntityTranslation.fY;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicEntityTranslation.fPeriod;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicEntityTranslation.startTime;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicEntityTranslation.endTime;
+
+	    bIsOk = true;
+	  }
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_SETDYNAMICENTITYNONE:
+      {
+	  int n;
+	  (*Buffer) >> n;
+	  if(n >= sizeof(Event.u.LuaCallSetDynamicEntityNone.cEntityID)) {
+	    Log("** Warning ** : Entity name in replay too long, ignoring all events!");
+	    bError = true;
+	  }
+	  else {
+	    (*Buffer).readBuf(Event.u.LuaCallSetDynamicEntityNone.cEntityID,n);
+	    Event.u.LuaCallSetDynamicEntityNone.cEntityID[n] = '\0';
+
+	    bIsOk = true;
+	  }
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_SETDYNAMICBLOCKROTATION:
+      {
+	  int n;
+	  (*Buffer) >> n;
+	  if(n >= sizeof(Event.u.LuaCallSetDynamicBlockRotation.cBlockID)) {
+	    Log("** Warning ** : Block name in replay too long, ignoring all events!");
+	    bError = true;
+	  }
+	  else {
+	    (*Buffer).readBuf(Event.u.LuaCallSetDynamicBlockRotation.cBlockID,n);
+	    Event.u.LuaCallSetDynamicBlockRotation.cBlockID[n] = '\0';
+
+	    (*Buffer) >> Event.u.LuaCallSetDynamicBlockRotation.fInitAngle;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicBlockRotation.fRadius;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicBlockRotation.fPeriod;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicBlockRotation.startTime;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicBlockRotation.endTime;
+
+	    bIsOk = true;
+	  }
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_SETDYNAMICBLOCKTRANSLATION:
+      {
+	  int n;
+	  (*Buffer) >> n;
+	  if(n >= sizeof(Event.u.LuaCallSetDynamicBlockTranslation.cBlockID)) {
+	    Log("** Warning ** : Block name in replay too long, ignoring all events!");
+	    bError = true;
+	  }
+	  else {
+	    (*Buffer).readBuf(Event.u.LuaCallSetDynamicBlockTranslation.cBlockID,n);
+	    Event.u.LuaCallSetDynamicBlockTranslation.cBlockID[n] = '\0';
+
+	    (*Buffer) >> Event.u.LuaCallSetDynamicBlockTranslation.fX;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicBlockTranslation.fY;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicBlockTranslation.fPeriod;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicBlockTranslation.startTime;
+	    (*Buffer) >> Event.u.LuaCallSetDynamicBlockTranslation.endTime;
+
+	    bIsOk = true;
+	  }
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_SETDYNAMICBLOCKNONE:
+      {
+	  int n;
+	  (*Buffer) >> n;
+	  if(n >= sizeof(Event.u.LuaCallSetDynamicBlockNone.cBlockID)) {
+	    Log("** Warning ** : Block name in replay too long, ignoring all events!");
+	    bError = true;
+	  }
+	  else {
+	    (*Buffer).readBuf(Event.u.LuaCallSetDynamicBlockNone.cBlockID,n);
+	    Event.u.LuaCallSetDynamicBlockNone.cBlockID[n] = '\0';
+
+	    bIsOk = true;
+	  }
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_CAMERAZOOM:
+      {
+	(*Buffer) >> Event.u.LuaCallCameraZoom.fZoom;
+	bIsOk = true;
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_CAMERAMOVE:
+      {
+	(*Buffer) >> Event.u.LuaCallCameraMove.x;
+	(*Buffer) >> Event.u.LuaCallCameraMove.y;
+	bIsOk = true;
+      }
+      break;
+
       default:
 	Log("** Warning ** : Failed to parse game events in replay, it will probably not play right!");
 	bError = true;
@@ -329,6 +490,18 @@ namespace vapp {
       }
       break;
       
+    case GAME_EVENT_LUA_CALL_SETBLOCKCENTER:
+      {
+	int i;
+	Buffer << getTime();
+	Buffer << pEvent->Type;
+	Buffer << (i=strlen(pEvent->u.LuaCallSetBlockCenter.cBlockID));
+	Buffer.writeBuf(pEvent->u.LuaCallSetBlockCenter.cBlockID,i);
+	Buffer << pEvent->u.LuaCallSetBlockCenter.x;
+	Buffer << pEvent->u.LuaCallSetBlockCenter.y;
+      }
+      break;
+      
     case GAME_EVENT_LUA_CALL_SETGRAVITY:
       {
 	Buffer << getTime();
@@ -347,7 +520,103 @@ namespace vapp {
 	Buffer << pEvent->u.LuaCallSetplayerposition.bRight;
       }
       break;
-      
+
+    case GAME_EVENT_LUA_CALL_SETDYNAMICENTITYROTATION:
+      {
+	int i;
+	Buffer << getTime();
+	Buffer << pEvent->Type;
+	Buffer << (i=strlen(pEvent->u.LuaCallSetDynamicEntityRotation.cEntityID));
+	Buffer.writeBuf(pEvent->u.LuaCallSetDynamicEntityRotation.cEntityID,i);
+	Buffer << pEvent->u.LuaCallSetDynamicEntityRotation.fInitAngle;
+	Buffer << pEvent->u.LuaCallSetDynamicEntityRotation.fRadius;
+	Buffer << pEvent->u.LuaCallSetDynamicEntityRotation.fPeriod;
+	Buffer << pEvent->u.LuaCallSetDynamicEntityRotation.startTime;
+	Buffer << pEvent->u.LuaCallSetDynamicEntityRotation.endTime;
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_SETDYNAMICENTITYTRANSLATION:
+      {
+	int i;
+	Buffer << getTime();
+	Buffer << pEvent->Type;
+	Buffer << (i=strlen(pEvent->u.LuaCallSetDynamicEntityTranslation.cEntityID));
+	Buffer.writeBuf(pEvent->u.LuaCallSetDynamicEntityTranslation.cEntityID,i);
+	Buffer << pEvent->u.LuaCallSetDynamicEntityTranslation.fX;
+	Buffer << pEvent->u.LuaCallSetDynamicEntityTranslation.fY;
+	Buffer << pEvent->u.LuaCallSetDynamicEntityTranslation.fPeriod;
+	Buffer << pEvent->u.LuaCallSetDynamicEntityTranslation.startTime;
+	Buffer << pEvent->u.LuaCallSetDynamicEntityTranslation.endTime;
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_SETDYNAMICENTITYNONE:
+      {
+	int i;
+	Buffer << getTime();
+	Buffer << pEvent->Type;
+	Buffer << (i=strlen(pEvent->u.LuaCallSetDynamicEntityNone.cEntityID));
+	Buffer.writeBuf(pEvent->u.LuaCallSetDynamicEntityNone.cEntityID,i);
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_SETDYNAMICBLOCKROTATION:
+      {
+	int i;
+	Buffer << getTime();
+	Buffer << pEvent->Type;
+	Buffer << (i=strlen(pEvent->u.LuaCallSetDynamicBlockRotation.cBlockID));
+	Buffer.writeBuf(pEvent->u.LuaCallSetDynamicBlockRotation.cBlockID,i);
+	Buffer << pEvent->u.LuaCallSetDynamicBlockRotation.fInitAngle;
+	Buffer << pEvent->u.LuaCallSetDynamicBlockRotation.fRadius;
+	Buffer << pEvent->u.LuaCallSetDynamicBlockRotation.fPeriod;
+	Buffer << pEvent->u.LuaCallSetDynamicBlockRotation.startTime;
+	Buffer << pEvent->u.LuaCallSetDynamicBlockRotation.endTime;
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_SETDYNAMICBLOCKTRANSLATION:
+      {
+	int i;
+	Buffer << getTime();
+	Buffer << pEvent->Type;
+	Buffer << (i=strlen(pEvent->u.LuaCallSetDynamicBlockTranslation.cBlockID));
+	Buffer.writeBuf(pEvent->u.LuaCallSetDynamicBlockTranslation.cBlockID,i);
+	Buffer << pEvent->u.LuaCallSetDynamicBlockTranslation.fX;
+	Buffer << pEvent->u.LuaCallSetDynamicBlockTranslation.fY;
+	Buffer << pEvent->u.LuaCallSetDynamicBlockTranslation.fPeriod;
+	Buffer << pEvent->u.LuaCallSetDynamicBlockTranslation.startTime;
+	Buffer << pEvent->u.LuaCallSetDynamicBlockTranslation.endTime;
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_SETDYNAMICBLOCKNONE:
+      {
+	int i;
+	Buffer << getTime();
+	Buffer << pEvent->Type;
+	Buffer << (i=strlen(pEvent->u.LuaCallSetDynamicBlockNone.cBlockID));
+	Buffer.writeBuf(pEvent->u.LuaCallSetDynamicBlockNone.cBlockID,i);
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_CAMERAZOOM:
+      {
+	Buffer << getTime();
+	Buffer << pEvent->Type;
+	Buffer << pEvent->u.LuaCallCameraZoom.fZoom;
+      }
+      break;
+
+    case GAME_EVENT_LUA_CALL_CAMERAMOVE:
+      {
+	Buffer << getTime();
+	Buffer << pEvent->Type;
+	Buffer << pEvent->u.LuaCallCameraMove.x;
+	Buffer << pEvent->u.LuaCallCameraMove.y;
+      }
+      break;
     }            
   }
 
