@@ -43,6 +43,7 @@ Central place to keep many in-game text strings
                                       "and best times of other players?"
 #define GAMETEXT_ALLRECORDS           "All (on this computer):"
 #define GAMETEXT_ALREADYUSED          "Already used!"
+#define GAMETEXT_AND                  "and"
 #define GAMETEXT_AUDIO                "Audio"
 #define GAMETEXT_AUTHOR               "Author: "
 #define GAMETEXT_AUTOSAVEREPLAYS      "Automatic saving of replays"
@@ -51,6 +52,10 @@ Central place to keep many in-game text strings
 #define GAMETEXT_BRAKE                "Brake"
 #define GAMETEXT_BUILTINLEVELS        "Built-In Levels"     
 #define GAMETEXT_BY                   "by"
+#define GAMETEXT_CAMERAMOVEXDOWN      "Move Camera to left"
+#define GAMETEXT_CAMERAMOVEXUP        "Move Camera to right"
+#define GAMETEXT_CAMERAMOVEYDOWN      "Move Camera down"
+#define GAMETEXT_CAMERAMOVEYUP        "Move Camera up"
 #define GAMETEXT_CANCEL               "Cancel"
 #define GAMETEXT_CHANGE               "Change..."
 #define GAMETEXT_CHANGEDIR            "Change direction"
@@ -77,6 +82,8 @@ Central place to keep many in-game text strings
 #define GAMETEXT_DLHIGHSCORES         "Downloading high-scores..."
 #define GAMETEXT_DLLEVELS             "Downloading extra levels...\nPress ESC to abort.\n\n "
 #define GAMETEXT_DLLEVELSCHECK        "Checking for new levels..."
+#define GAMETEXT_DLTHEME              "Getting the theme\nPress ESC to abort.\n\n "
+#define GAMETEXT_DLTHEMESLISTCHECK    "Checking for new themes..."
 #define GAMETEXT_DOWNLOADLEVELS       "Get More Levels!"
 #define GAMETEXT_DRIVE                "Drive"
 #define GAMETEXT_ENABLEAUDIO          "Enable Audio"
@@ -86,6 +93,7 @@ Central place to keep many in-game text strings
 #define GAMETEXT_ENABLEENGINESOUND    "Enable Engine Sound"
 #define GAMETEXT_ENABLEGHOST          "Enable Ghost"
 #define GAMETEXT_ENABLEINGAMEWORLDRECORD "Show World Record in-game"
+#define GAMETEXT_ENABLEMUSIC          "Enable Music"
 #define GAMETEXT_ENABLEWEBHIGHSCORES  "Enable WWW Access"
 #define GAMETEXT_ENTERPLAYERNAME      "Enter player name:"
 #define GAMETEXT_ENTERREPLAYNAME      "Enter name of replay:"
@@ -95,8 +103,11 @@ Central place to keep many in-game text strings
 #define GAMETEXT_FAILEDDLHIGHSCORES   "Failed to download high-scores.\nCheck your Internet connection!"
 #define GAMETEXT_FAILEDDLLEVELS       "Failed to download levels.\nCheck your Internet connection!"
 #define GAMETEXT_FAILEDDLREPLAY       "Failed to download the replay.\nCheck your Internet connection!"
+#define GAMETEXT_FAILEDGETSELECTEDTHEME "Failed to get the selected theme\nCheck your Internet connection!"
+#define GAMETEXT_FAILEDTOINITLEVEL    "Failed to initialize level!"
 #define GAMETEXT_FAILEDTOLOADREPLAY   "Failed to load replay!"
 #define GAMETEXT_FAILEDTOSAVEREPLAY   "Failed to save replay!\nMaybe you should try with another name?"
+#define GAMETEXT_FAILEDUPDATETHEMESLIST "Failed to update the theme list\nCheck your Internet connection!"
 #define GAMETEXT_FILE                 "File"
 #define GAMETEXT_FINISH               "Finished!"
 #define GAMETEXT_FINISHTIME           "Finish Time"
@@ -105,30 +116,32 @@ Central place to keep many in-game text strings
 #define GAMETEXT_GAMEGFX              "Game Graphics:"
 #define GAMETEXT_GENERAL              "General"
 #define GAMETEXT_GENERALINFO          "General Info"
+#define GAMETEXT_GETSELECTEDTHEME     "Get this theme"
 #define GAMETEXT_GHOST_STRATEGIES_TYPE  "Type"
 #define GAMETEXT_GHOST_STRATEGY_BESTOFROOM "The highscore of the room"
 #define GAMETEXT_GHOST_STRATEGY_MYBEST  "The best of my replays (on this computer)"
 #define GAMETEXT_GHOST_STRATEGY_THEBEST "The best of the replays (on this computer)"
-#define GAMETEXT_GHOSTOF              "Ghost of"
+#define GAMETEXT_GHOSTOF              "Ghost of "
 #define GAMETEXT_GHOSTTAB             "Ghost"
 #define GAMETEXT_HELP                 "Help"
 
 
 #define GAMETEXT_HELPTEXT(accelerate_KEY, brake_KEY, rotate_counter_clockwise_KEY, rotate_clockwise_KEY, change_direction_KEY)   \
                                         "You control your bike using the keyboard:\n"                      \
-                                        "\n"                                                               \
                                         "  " + accelerate_KEY + " - Accelerates\n"                                       \
                                         "  " + brake_KEY + " - Brakes\n"                                          \
                                         "  " + rotate_counter_clockwise_KEY + " - Rotates it counter-clockwise\n"                    \
                                         "  " + rotate_clockwise_KEY + " - Rotates it clockwise\n"                           \
                                         "  " + change_direction_KEY + " - Turns around and drives in the other direction\n"       \
+                                        "  Esc - Pause\n"       \
+                                        "  Return - Restart the level\n"       \
                                         "  F12 - Take a screenshot\n"       \
                                         "\n" \
                                         "Find all the strawberries and touch the flower to finish\n"       \
                                         "the level.\n"                                                     \
                                         "\n"                                                               \
                                         "Read the README file or check out the website at\n"               \
-                                        "http://xmoto.sourceforce.net for more information."
+                                        "http://xmoto.sourceforge.net for more information."
 
 #define GAMETEXT_HIGH                 "High"
 #define GAMETEXT_INETCONF             "Internet Configuration"
@@ -160,8 +173,10 @@ Central place to keep many in-game text strings
 #define GAMETEXT_MISSINGTEXTURES      "Level references unknown textures, it could be unplayable!"
 #define GAMETEXT_MODIFYSELECTED       "Modify Selected..."
 #define GAMETEXT_MONO                 "Mono"
+#define GAMETEXT_MOSTPLAYEDLEVELSFOLLOW "Following are your most played levels:"
 #define GAMETEXT_MOTIONBLURGHOST      "Motion blur ghost"
 #define GAMETEXT_NAME                 "Name"
+#define GAMETEXT_NEWERXMOTOREQUIRED   "X-Moto %s or newer required to load level"
 #define GAMETEXT_NEWHIGHSCORE         "New highscore!"
 #define GAMETEXT_NEWHIGHSCOREPERSONAL "New personal highscore!"
 #define GAMETEXT_NEWLEVELAVAIL        "%d new or updated level available. Download now?"
@@ -173,6 +188,7 @@ Central place to keep many in-game text strings
 #define GAMETEXT_NONE                 "(None)"
 #define GAMETEXT_NONEWLEVELS          "No new or updated levels available.\n\nTry again another time."
 #define GAMETEXT_NONEXTLEVEL          "No level following this one, sorry."
+#define GAMETEXT_NOSTATS              "No statistics for this profile."
 #define GAMETEXT_NOTFINISHED          "(Not finished)"
 #define GAMETEXT_NOTIFYATINIT         "Important note!\n"                                                \
                                       "\n"                                                               \
@@ -221,12 +237,21 @@ Central place to keep many in-game text strings
 #define GAMETEXT_SCRIPTED             "Scripted"
 #define GAMETEXT_SKIPPED              " (Skipped)"
 #define GAMETEXT_STARTLEVEL           "Play!"
+#define GAMETEXT_STATISTICS           "Statistics"
+#define GAMETEXT_STATS                "STATS"
 #define GAMETEXT_STEREO               "Stereo"
+#define GAMETEXT_THEMES               "Theme"
+#define GAMETEXT_THEMEHOSTED          "Available"
+#define GAMETEXT_THEMENOTHOSTED       "To download"
+#define GAMETEXT_THEMEREQUIREUPDATE   "To be updated"
+#define GAMETEXT_THEMEUPTODATE        "The theme is now up to date"
 #define GAMETEXT_TIME                 "Time:"
 #define GAMETEXT_TRYAGAIN             "Try This Level Again"
 #define GAMETEXT_TUTORIAL             "Tutorial"
 #define GAMETEXT_UNKNOWNLEVEL         "(Unknown)"
+#define GAMETEXT_UPDATE               "Update"
 #define GAMETEXT_UPDATEHIGHSCORES     "Check WWW"
+#define GAMETEXT_UPDATETHEMESLIST      "Update the theme list"
 #define GAMETEXT_UPDATINGLEVELS       "Updating level lists..."
 #define GAMETEXT_USEENVVARS           "Use Environment Vars"
 #define GAMETEXT_USEPROFILE           "Use Profile"
@@ -239,11 +264,18 @@ Central place to keep many in-game text strings
 #define GAMETEXT_WANTTOUPDATELEVEL    "Do you want to update level \"%s\"?\n(%s)"
 #define GAMETEXT_WARNING              "Warning:"
 #define GAMETEXT_WORLDRECORDNA        "--:--:--"
-#define GAMETEXT_WWWTAB             "WWW"
+#define GAMETEXT_WWWTAB               "WWW"
+#define GAMETEXT_XHOURS               "%d hours"  
+#define GAMETEXT_XMINUTES             "%d minutes"  
+#define GAMETEXT_XMOTOGLOBALSTATS     "(Stats since: %s)\n"                                         \
+                                      "X-Moto started %d times; %d plays (%d different levels),\n"  \
+                                      "%d deaths, %d finishes, and %d restarts.\nTime played: %s"
+#define GAMETEXT_XMOTOLEVELSTATS      "%d plays, %d deaths, %d finishes, and %d restarts"
+#define GAMETEXT_XSECONDS             "%d seconds"  
 #define GAMETEXT_YES                  "Yes"
 #define GAMETEXT_ZOOMIN  	            "Zoom in"
+#define GAMETEXT_ZOOMINIT 	          "Reinitialize zoom"
 #define GAMETEXT_ZOOMOUT 	            "Zoom out"
-#define GAMETEXT_ZOOMINIT 	            "Reinitialize zoom"
 
 /* Context help strings */
 #define CONTEXTHELP_UPDATEHIGHSCORES "Download the latest X-Moto world records and check for new levels"
@@ -335,7 +367,15 @@ Central place to keep many in-game text strings
 #define CONTEXTHELP_AUTOSAVEREPLAYS "If you make a highscore it will automatically be saved as a replay"
 #define CONTEXTHELP_VIEWTHEHIGHSCORE "View the replay of the room's highscore"
 
-#define CONTEXTHELP_ENABLE_CHECK_NEW_LEVELS_AT_STARTUP "Check new levels at startup"
-#define CONTEXTHELP_ENABLE_CHECK_HIGHSCORES_AT_STARTUP "Check new highscores at startup"
+#define CONTEXTHELP_ENABLE_CHECK_NEW_LEVELS_AT_STARTUP "Check for new levels at startup"
+#define CONTEXTHELP_ENABLE_CHECK_HIGHSCORES_AT_STARTUP "Check for new highscores at startup"
+
+#define CONTEXTHELP_STATS "Show various statistics about X-Moto"
+#define CONTEXTHELP_UPDATESTATS "Update statistics (also happens each time X-Moto is started)"
+#define CONTEXTHELP_MUSIC "Enables background music in the main menu"
+
+#define CONTEXTHELP_THEMES "Choose the X-Moto graphics theme"
+#define CONTEXTHELP_UPDATETHEMESLIST "Check for new themes on the web"
+#define CONTEXTHELP_GETSELECTEDTHEME "Download or update the selected theme"
 
 #endif
