@@ -30,20 +30,25 @@ namespace vapp {
   Globals
   ===========================================================================*/  
   /* Action ID to string table */
+	/*
   InputActionType InputHandler::m_ActionTypeTable[] = {
     "Drive",           ACTION_DRIVE,
     "Brake",           ACTION_BRAKE,             
-    "PullBack",        ACTION_PULLBACK,          
-    "PushForward",     ACTION_PUSHFORWARD,       
+    "Pull",            ACTION_PULL,          
+    "Push",            ACTION_PUSH,       
     "ChangeDirection", ACTION_CHANGEDIR,     
     #if defined(ENABLE_ZOOMING)    
-      "ZoomIn",        ACTION_ZOOMIN,     
-      "ZoomOut",       ACTION_ZOOMOUT,
-      "ZoomInit",      ACTION_ZOOMINIT, 
+      "ZoomIn",          ACTION_ZOOMIN,     
+      "ZoomOut",         ACTION_ZOOMOUT,
+      "ZoomInit",        ACTION_ZOOMINIT,
+      "CameraMoveXUp",   ACTION_CAMERAMOVEXUP,
+      "CameraMoveXDown", ACTION_CAMERAMOVEXDOWN,
+      "CameraMoveYUp",   ACTION_CAMERAMOVEYUP,
+      "CameraMoveYDown", ACTION_CAMERAMOVEYDOWN,
     #endif
     NULL
   };
-
+*/
   /* Key code to string table */  
   InputKeyMap InputHandler::m_KeyMap[] = {
     "Up",              SDLK_UP,
@@ -97,6 +102,17 @@ namespace vapp {
     "Middle Click",    SDL_BUTTON_MIDDLE,
     "Wheel down",      SDL_BUTTON_WHEELDOWN,
     "Wheel up",        SDL_BUTTON_WHEELUP,
+    "Pad 0", SDLK_KP0,
+    "Pad 1", SDLK_KP1,
+    "Pad 2", SDLK_KP2,
+    "Pad 3", SDLK_KP3,
+    "Pad 4", SDLK_KP4,
+    "Pad 5", SDLK_KP5,
+    "Pad 6", SDLK_KP6,
+    "Pad 7", SDLK_KP7,
+    "Pad 8", SDLK_KP8,
+    "Pad 9", SDLK_KP9,
+
     /* TODO: add more */
     NULL    
   };
@@ -149,6 +165,39 @@ namespace vapp {
     SDL_QuitSubSystem(SDL_INIT_JOYSTICK);
   }
 
+  namespace {
+    /**
+     * converts a raw joystick axis value to a float, according to specified minimum and maximum values, as well as the deadzone.
+     * 
+     *                 (+)      ____
+     *           result |      /|
+     *                  |     / |
+     *                  |    /  |
+     *  (-)________ ____|___/___|____(+)
+     *             /|   |   |   |    input
+     *            / |   |   |   |
+     *           /  |   |   |   |
+     *     _____/   |   |   |   | 
+     *          |   |  (-)  |   |
+     *         neg  dead-zone  pos
+     *         
+     */
+    float joyRawToFloat(float raw, float neg, float deadzone_neg, float deadzone_pos, float pos) {
+
+      if (neg > pos) {
+	std::swap(neg, pos);
+	std::swap(deadzone_neg, deadzone_pos);
+      }
+
+      if (raw > pos) return +1.0f;
+      if (raw > deadzone_pos) return +((raw - deadzone_pos) / (pos - deadzone_pos));
+      if (raw < neg) return -1.0f;
+      if (raw < deadzone_neg) return -((raw - deadzone_neg) / (neg - deadzone_neg));
+
+      return 0.0f;
+    }
+  }
+
   /*===========================================================================
   Input device update
   ===========================================================================*/  
@@ -158,11 +207,8 @@ namespace vapp {
       SDL_JoystickUpdate();     
       
       pController->fDrive = 0.0f;      
-      pController->fBrake = 0.0f;    
-      
+      pController->fPull = 0.0f;  
       pController->bChangeDir = false;  
-      pController->bPullBack = false;  
-      pController->bPushForward = false;  
       
       /* Update buttons */
       for(int i=0;i<SDL_JoystickNumButtons(m_pActiveJoystick1);i++) {
@@ -173,93 +219,18 @@ namespace vapp {
               pController->bChangeDir = true;
             }
           }
-          
-          /* Just down */
-          if(m_nJoyButtonFlipLeft1 == i) {
-            pController->bPullBack = true;
-          }
-          else if(m_nJoyButtonFlipRight1 == i) {
-            pController->bPushForward = true;
-          }
-          
+
           m_JoyButtonsPrev[i] = true;
         }        
         else
           m_JoyButtonsPrev[i] = false;
       }
       
-      /* Get the primary axis and map it. The following nice ASCII figure
-         should explain how it is done :)
-        
-                     (+)
-                   drive
-                  throttle    _______
-                      |      /|
-                      |     / |
-                      |    /  |
-      (-)________ ____|___/___|____raw axis data (+)
-                 /|   |   |   |
-                / |   |   |   |
-               /  |   |   |   |
-         _____/   |   |   |   | 
-              |   | brake |   |
-              |   | power |   |
-              |   |  (-)  |   |
-             Min  LL     UL  Max
-             
-             
-         Min: The minimum raw axis data to expect.
-         Max: Maximum raw axis data to expect.
-         LL: Lower limit. If the data is between this and zero, nothing 
-             happens.
-         UL: Upper limit. If the data is between this and zero, nothing 
-             happens.
-         Drive throttle: A value between 0 and 1.
-         Brake power: A value between 0 and 1.
-      */
-            
-      int nRaw = -SDL_JoystickGetAxis(m_pActiveJoystick1,m_nJoyAxisPrim1);
-      
-      if(m_nJoyAxisPrimMin1 > m_nJoyAxisPrimMax1) {
-        /* Drive? */
-        if(nRaw < m_nJoyAxisPrimUL1) {
-          float f = ((float)(nRaw - m_nJoyAxisPrimUL1)) / 
-                    (float)(m_nJoyAxisPrimMax1 - m_nJoyAxisPrimUL1);
-          if(f>1.0f) f=1.0f;
-          if(f>0.0f) {
-            pController->fDrive = f;
-          }
-        }
-        /* Brake? */
-        else if(nRaw > m_nJoyAxisPrimLL1) {
-          float f = ((float)(m_nJoyAxisPrimLL1 - nRaw)) / 
-                    (float)(m_nJoyAxisPrimLL1 - m_nJoyAxisPrimMin1);
-          if(f>1.0f) f=1.0f;
-          if(f>0.0f) {
-            pController->fBrake = f;
-          }
-        }
-      }
-      else if(m_nJoyAxisPrimMin1 < m_nJoyAxisPrimMax1) {
-        /* Brake? */
-        if(nRaw > m_nJoyAxisPrimUL1) {
-          float f = ((float)(nRaw - m_nJoyAxisPrimUL1)) / 
-                    (float)(m_nJoyAxisPrimMax1 - m_nJoyAxisPrimUL1);
-          if(f>1.0f) f=1.0f;
-          if(f>0.0f) {
-            pController->fBrake = f;
-          }
-        }
-        /* Drive? */
-        else if(nRaw < m_nJoyAxisPrimLL1) {
-          float f = ((float)(m_nJoyAxisPrimLL1 - nRaw)) / 
-                    (float)(m_nJoyAxisPrimLL1 - m_nJoyAxisPrimMin1);
-          if(f>1.0f) f=1.0f;
-          if(f>0.0f) {
-            pController->fDrive = f;
-          }
-        }
-      }
+      /** Update axis */           
+      int nRawPrim = SDL_JoystickGetAxis(m_pActiveJoystick1,m_nJoyAxisPrim1);
+      pController->fDrive = -joyRawToFloat(nRawPrim, m_nJoyAxisPrimMin1, m_nJoyAxisPrimLL1, m_nJoyAxisPrimUL1, m_nJoyAxisPrimMax1);
+      int nRawSec = SDL_JoystickGetAxis(m_pActiveJoystick1,m_nJoyAxisSec1);
+      pController->fPull = -joyRawToFloat(nRawSec, m_nJoyAxisSecMin1, m_nJoyAxisSecLL1, m_nJoyAxisSecUL1, m_nJoyAxisSecMax1);
     }
   }
   
@@ -327,13 +298,19 @@ namespace vapp {
 	m_nZoomIn   = _StringToKey(pConfig->getString("KeyZoomIn"));
 	m_nZoomOut  = _StringToKey(pConfig->getString("KeyZoomOut"));
 	m_nZoomInit = _StringToKey(pConfig->getString("KeyZoomInit"));
+	m_nCameraMoveXUp   = _StringToKey(pConfig->getString("KeyCameraMoveXUp"));
+	m_nCameraMoveXDown = _StringToKey(pConfig->getString("KeyCameraMoveXDown"));
+	m_nCameraMoveYUp   = _StringToKey(pConfig->getString("KeyCameraMoveYUp"));
+	m_nCameraMoveYDown = _StringToKey(pConfig->getString("KeyCameraMoveYDown"));
 	#endif
         
         /* All good? */
         if(m_nDriveKey1<0 || m_nBrakeKey1<0 || m_nPullBackKey1<0 ||
           m_nPushForwardKey1<0 || m_nChangeDirKey1<0 
           #if defined(ENABLE_ZOOMING)
-            ||m_nZoomIn<0 || m_nZoomOut <0 || m_nZoomInit <0
+            || m_nZoomIn<0 || m_nZoomOut <0 || m_nZoomInit <0
+	    || m_nCameraMoveXUp<0 || m_nCameraMoveXDown<0 
+            || m_nCameraMoveYUp<0 || m_nCameraMoveYDown<0
           #endif
 	        ) {
           Log("** Warning ** : Invalid keyboard configuration!");
@@ -359,9 +336,14 @@ namespace vapp {
           m_nJoyAxisPrimMin1 = pConfig->getInteger("JoyAxisPrimMin1");
           m_nJoyAxisPrimUL1 = pConfig->getInteger("JoyAxisPrimUL1");
           m_nJoyAxisPrimLL1 = pConfig->getInteger("JoyAxisPrimLL1");
-          m_nJoyButtonFlipLeft1 = pConfig->getInteger("JoyButtonFlipLeft1");
-          m_nJoyButtonFlipRight1 = pConfig->getInteger("JoyButtonFlipRight1");
-          m_nJoyButtonChangeDir1 = pConfig->getInteger("JoyButtonChangeDir1");
+          
+          m_nJoyAxisSec1 = pConfig->getInteger("JoyAxisSec1");
+          m_nJoyAxisSecMax1 = pConfig->getInteger("JoyAxisSecMax1");
+          m_nJoyAxisSecMin1 = pConfig->getInteger("JoyAxisSecMin1");
+          m_nJoyAxisSecUL1 = pConfig->getInteger("JoyAxisSecUL1");
+          m_nJoyAxisSecLL1 = pConfig->getInteger("JoyAxisSecLL1");
+	  
+	  m_nJoyButtonChangeDir1 = pConfig->getInteger("JoyButtonChangeDir1");
           
           /* Init all joystick buttons */
           m_JoyButtonsPrev.clear();
@@ -405,15 +387,15 @@ namespace vapp {
           }
           else if(m_nBrakeKey1 == nKey) {
             /* Brake */
-            pController->fBrake = 1.0f;
+            pController->fDrive = -1.0f;
           }
           else if(m_nPullBackKey1 == nKey) {
             /* Pull back */
-            pController->bPullBack = true;
+            pController->fPull = 1.0f;
           }
           else if(m_nPushForwardKey1 == nKey) {
             /* Push forward */
-            pController->bPushForward = true;            
+            pController->fPull = -1.0f;            
           } 
 #if defined(ENABLE_ZOOMING)          
 	else if(m_nZoomIn == nKey) {
@@ -425,9 +407,21 @@ namespace vapp {
 	  pGameRender->zoom(-0.002);
 	}
 	else if(m_nZoomInit == nKey) {
-	  /* Zoom out */
+	  /* Zoom init */
 	  pGameRender->initZoom();
 	}
+	else if(m_nCameraMoveXUp == nKey) {
+	  pGameRender->moveCamera(1.0, 0.0);
+	}
+	else if(m_nCameraMoveXDown == nKey) {
+	  pGameRender->moveCamera(-1.0, 0.0);
+	}
+	else if(m_nCameraMoveYUp == nKey) {
+	  pGameRender->moveCamera(0.0, 1.0);
+	}
+	else if(m_nCameraMoveYDown == nKey) {
+	  pGameRender->moveCamera(0.0, -1.0);
+	}
 #endif
 
           break;
@@ -438,15 +432,15 @@ namespace vapp {
           }
           else if(m_nBrakeKey1 == nKey) {
             /* Don't brake */
-            pController->fBrake = 0.0f;
+            pController->fDrive = 0.0f;
           }
           else if(m_nPullBackKey1 == nKey) {
             /* Pull back */
-            pController->bPullBack = false;
+            pController->fPull = 0.0f;
           }
           else if(m_nPushForwardKey1 == nKey) {
             /* Push forward */
-            pController->bPushForward = false;            
+            pController->fPull = 0.0f;            
           }
           else if(m_nChangeDirKey1 == nKey) {
             /* Change dir */
@@ -483,6 +477,10 @@ namespace vapp {
       m_nZoomIn          = SDLK_PAGEUP;
       m_nZoomOut         = SDLK_PAGEDOWN;
       m_nZoomOut         = SDLK_HOME;
+      m_nCameraMoveXUp   = SDLK_KP6;
+      m_nCameraMoveXDown = SDLK_KP4;
+      m_nCameraMoveYUp   = SDLK_KP8;
+      m_nCameraMoveYDown = SDLK_KP2;
     #endif
   }  
 
@@ -499,6 +497,10 @@ namespace vapp {
     if(m_nZoomIn          < 0) { m_nZoomIn          = SDLK_PAGEUP;   }
     if(m_nZoomOut         < 0) { m_nZoomOut         = SDLK_PAGEDOWN; }
     if(m_nZoomInit        < 0) { m_nZoomInit        = SDLK_HOME; }
+    if(m_nCameraMoveXUp   < 0) { m_nCameraMoveXUp   = SDLK_KP6; }
+    if(m_nCameraMoveXDown < 0) { m_nCameraMoveXDown = SDLK_KP4; }
+    if(m_nCameraMoveYUp   < 0) { m_nCameraMoveYUp   = SDLK_KP8; }
+    if(m_nCameraMoveYDown < 0) { m_nCameraMoveYDown = SDLK_KP2; }
     #endif
   }
 
@@ -508,16 +510,20 @@ namespace vapp {
   std::string InputHandler::getKeyByAction(const std::string &Action) {
     if(m_ControllerModeID1 != CONTROLLER_MODE_KEYBOARD) return "?";
     
-    if(Action == "Drive") return _KeyToString(m_nDriveKey1);
-    if(Action == "Brake") return _KeyToString(m_nBrakeKey1);
-    if(Action == "PullBack") return _KeyToString(m_nPullBackKey1);
+    if(Action == "Drive")    	return _KeyToString(m_nDriveKey1);
+    if(Action == "Brake")    	return _KeyToString(m_nBrakeKey1);
+    if(Action == "PullBack") 	return _KeyToString(m_nPullBackKey1);
     if(Action == "PushForward") return _KeyToString(m_nPushForwardKey1);
-    if(Action == "ChangeDir") return _KeyToString(m_nChangeDirKey1);
+    if(Action == "ChangeDir")   return _KeyToString(m_nChangeDirKey1);
     
     #if defined(ENABLE_ZOOMING)    
-    if(Action == "ZoomIn")   return _KeyToString(m_nZoomIn);
-    if(Action == "ZoomOut")  return _KeyToString(m_nZoomOut);
-    if(Action == "ZoomInit") return _KeyToString(m_nZoomInit);
+    if(Action == "ZoomIn")   	    return _KeyToString(m_nZoomIn);
+    if(Action == "ZoomOut")  	    return _KeyToString(m_nZoomOut);
+    if(Action == "ZoomInit") 	    return _KeyToString(m_nZoomInit);
+    if(Action == "CameraMoveXUp")   return _KeyToString(m_nCameraMoveXUp);
+    if(Action == "CameraMoveXDown") return _KeyToString(m_nCameraMoveXDown);
+    if(Action == "CameraMoveYUp")   return _KeyToString(m_nCameraMoveYUp);
+    if(Action == "CameraMoveYDown") return _KeyToString(m_nCameraMoveYDown);
     #endif
 
     return "?";
