@@ -29,6 +29,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "VFileIO.h"
 
 namespace vapp {
+
   /*===========================================================================
   Unload
   ===========================================================================*/
@@ -79,7 +80,7 @@ namespace vapp {
     FS::writeLineF(pfh,"<?xml version=\"1.0\" encoding=\"utf-8\"?>");
     
     if(m_LevelPack != "")
-      FS::writeLineF(pfh,"<level id=\"%s\" levelpack=\"%s\">",m_ID.c_str(),m_LevelPack.c_str());
+      FS::writeLineF(pfh,"<level id=\"%s\" levelpack=\"%s\" rversion=\"%s\">",m_ID.c_str(),m_LevelPack.c_str(),m_RequiredVersion.c_str());
     else
       FS::writeLineF(pfh,"<level id=\"%s\">",m_ID.c_str());
     
@@ -98,7 +99,7 @@ namespace vapp {
       FS::writeByte(pfh,'\t'); FS::writeByte(pfh,'\t');
       
       /* Write script and transform dangerous characters */
-      for(int i=0;i<m_ScriptSource.length();i++) {
+      for(unsigned int i=0;i<m_ScriptSource.length();i++) {
         int c = m_ScriptSource[i];
         if(c == '<') FS::writeBuf(pfh,"&lt;",4);
         else if(c == '>') FS::writeBuf(pfh,"&gt;",4);
@@ -113,7 +114,7 @@ namespace vapp {
       FS::writeLineF(pfh,"\t<script>");
       FS::writeByte(pfh,'\t'); FS::writeByte(pfh,'\t');
       /* Write script and transform dangerous characters */
-      for(int i=0;i<m_ScriptSource.length();i++) {
+      for(unsigned int i=0;i<m_ScriptSource.length();i++) {
         int c = m_ScriptSource[i];
         if(c == '<') FS::writeBuf(pfh,"&lt;",4);
         else if(c == '>') FS::writeBuf(pfh,"&gt;",4);
@@ -126,16 +127,26 @@ namespace vapp {
     FS::writeLineF(pfh,"\t<limits left=\"%f\" right=\"%f\" top=\"%f\" bottom=\"%f\"/>",m_fLeftLimit,m_fRightLimit,m_fTopLimit,m_fBottomLimit);
     
     /* BLOCKS */
-    for(int i=0;i<m_Blocks.size();i++) {
+    for(unsigned int i=0;i<m_Blocks.size();i++) {
       FS::writeLineF(pfh,"\t<block id=\"%s\">",m_Blocks[i]->ID.c_str());
-      if(m_Blocks[i]->bBackground)
-        FS::writeLineF(pfh,"\t\t<position x=\"%f\" y=\"%f\" background=\"true\"/>",m_Blocks[i]->fPosX,m_Blocks[i]->fPosY);
-      else if(m_Blocks[i]->bWater)
-        FS::writeLineF(pfh,"\t\t<position x=\"%f\" y=\"%f\" water=\"true\"/>",m_Blocks[i]->fPosX,m_Blocks[i]->fPosY);
-      else
-        FS::writeLineF(pfh,"\t\t<position x=\"%f\" y=\"%f\"/>",m_Blocks[i]->fPosX,m_Blocks[i]->fPosY);
+      if(m_Blocks[i]->bDynamic) {
+        if(m_Blocks[i]->bBackground)
+          FS::writeLineF(pfh,"\t\t<position x=\"%f\" y=\"%f\" dynamic=\"true\" background=\"true\"/>",m_Blocks[i]->fPosX,m_Blocks[i]->fPosY);
+        else if(m_Blocks[i]->bWater)
+          FS::writeLineF(pfh,"\t\t<position x=\"%f\" y=\"%f\" dynamic=\"true\" water=\"true\"/>",m_Blocks[i]->fPosX,m_Blocks[i]->fPosY);
+        else
+          FS::writeLineF(pfh,"\t\t<position x=\"%f\" y=\"%f\" dynamic=\"true\"/>",m_Blocks[i]->fPosX,m_Blocks[i]->fPosY);
+      }
+      else {
+        if(m_Blocks[i]->bBackground)
+          FS::writeLineF(pfh,"\t\t<position x=\"%f\" y=\"%f\" background=\"true\"/>",m_Blocks[i]->fPosX,m_Blocks[i]->fPosY);
+        else if(m_Blocks[i]->bWater)
+          FS::writeLineF(pfh,"\t\t<position x=\"%f\" y=\"%f\" water=\"true\"/>",m_Blocks[i]->fPosX,m_Blocks[i]->fPosY);
+        else
+          FS::writeLineF(pfh,"\t\t<position x=\"%f\" y=\"%f\"/>",m_Blocks[i]->fPosX,m_Blocks[i]->fPosY);
+      }
       FS::writeLineF(pfh,"\t\t<usetexture id=\"%s\"/>",m_Blocks[i]->Texture.c_str());
-      for(int j=0;j<m_Blocks[i]->Vertices.size();j++) {
+      for(unsigned int j=0;j<m_Blocks[i]->Vertices.size();j++) {
         if(m_Blocks[i]->Vertices[j]->EdgeEffect != "")
           FS::writeLineF(pfh,"\t\t<vertex x=\"%f\" y=\"%f\" edge=\"%s\"/>",
             m_Blocks[i]->Vertices[j]->fX,m_Blocks[i]->Vertices[j]->fY,m_Blocks[i]->Vertices[j]->EdgeEffect.c_str());
@@ -147,11 +158,11 @@ namespace vapp {
     }
     
     /* ENTITIES */
-    for(int i=0;i<m_Entities.size();i++) {
+    for(unsigned int i=0;i<m_Entities.size();i++) {
 			FS::writeLineF(pfh,"\t<entity id=\"%s\" typeid=\"%s\">",m_Entities[i]->ID.c_str(),m_Entities[i]->TypeID.c_str());
 			FS::writeLineF(pfh,"\t\t<size r=\"%f\"/>",m_Entities[i]->fSize);
       FS::writeLineF(pfh,"\t\t<position x=\"%f\" y=\"%f\"/>",m_Entities[i]->fPosX,m_Entities[i]->fPosY);			
-      for(int j=0;j<m_Entities[i]->Params.size();j++) {
+      for(unsigned int j=0;j<m_Entities[i]->Params.size();j++) {
 				FS::writeLineF(pfh,"\t\t<param name=\"%s\" value=\"%s\"/>",
 					m_Entities[i]->Params[j]->Name.c_str(),m_Entities[i]->Params[j]->Value.c_str());
       }
@@ -159,9 +170,9 @@ namespace vapp {
     }
     
     /* ZONE */
-    for(int i=0;i<m_Zones.size();i++) {
+    for(unsigned int i=0;i<m_Zones.size();i++) {
       FS::writeLineF(pfh,"\t<zone id=\"%s\">",m_Zones[i]->ID.c_str());
-      for(int j=0;j<m_Zones[i]->Prims.size();j++) {
+      for(unsigned int j=0;j<m_Zones[i]->Prims.size();j++) {
         if(m_Zones[i]->Prims[j]->Type == LZPT_BOX) {
           FS::writeLineF(pfh,"\t\t<box left=\"%f\" right=\"%f\" top=\"%f\" bottom=\"%f\"/>",
                   m_Zones[i]->Prims[j]->fLeft,m_Zones[i]->Prims[j]->fRight,
@@ -194,229 +205,251 @@ namespace vapp {
     m_ID = _GetOption(pLevelElem,"id");
     if(m_ID == "") return; /* TODO: error */    
     
-    /* Get level pack */
-    m_LevelPack = _GetOption(pLevelElem,"levelpack");
+    /* Get required xmoto version */
+    m_RequiredVersion = _GetOption(pLevelElem,"rversion");
+    m_bXMotoTooOld = false;
+    if(m_ID != "") {
+      /* Check version */
+      if(compareVersionNumbers(App::getVersionString(),m_RequiredVersion) < 0) {
+        /* Our version is too low to load this */
+        m_bXMotoTooOld = true;
+        Log("** Warning ** : Level '%s' requires a newer version (%s) to load!",m_ID.c_str(),m_RequiredVersion.c_str());
+      }
+    }
     
     /* Set default info */
-    m_Info.Name = m_FileName;
+    m_Info.Name = m_ID;
     m_Info.Date = "";
     m_Info.Description = "";
     m_Info.Author = "";
     m_Info.Sky = "sky1";
-    
-    /* Get level <info> element */
-    TiXmlElement *pInfoElem = _FindElement(pLevelElem,std::string("info"));
-    if(pInfoElem != NULL) {
-      /* Name */
-      std::string Tmp = _GetElementText(pInfoElem,"name");
-      if(Tmp != "") m_Info.Name = Tmp;
 
-      /* Author */
-      Tmp = _GetElementText(pInfoElem,"author");
-      if(Tmp != "") m_Info.Author = Tmp;
-
-      /* Description */
-      Tmp = _GetElementText(pInfoElem,"description");
-      if(Tmp != "") m_Info.Description = Tmp;
-
-      /* Date */
-      Tmp = _GetElementText(pInfoElem,"date");
-      if(Tmp != "") m_Info.Date = Tmp;
-
-      /* Sky */
-      Tmp = _GetElementText(pInfoElem,"sky");
-      if(Tmp != "") m_Info.Sky = Tmp;
-    }
-    
-    /* Get script */
     m_ScriptFile = "";
     m_ScriptSource = "";
-    
-    TiXmlElement *pScriptElem = _FindElement(pLevelElem,std::string("script"));
-    if(pScriptElem != NULL) {
-      /* External script file specified? */
-      m_ScriptFile = _GetOption(pScriptElem,"source");      
-      
-      /* Encapsulated script? */
-      for(TiXmlNode *pScript=pScriptElem->FirstChild();pScript!=NULL;
-          pScript=pScript->NextSibling()) {
-        if(pScript->Type() == TiXmlNode::TEXT) {
-          m_ScriptSource.append(pScript->Value());
-        }
-      }
-    }    
-    
-    /* Get level limits */
+
     m_fBottomLimit = m_fLeftLimit = -50.0f;
     m_fTopLimit = m_fRightLimit = 50.0f;
-    TiXmlElement *pLimitsElem = _FindElement(pLevelElem,std::string("limits"));
-    if(pLimitsElem != NULL) {
-      m_fBottomLimit = atof( _GetOption(pLimitsElem,"bottom","-50").c_str() );
-      m_fLeftLimit = atof( _GetOption(pLimitsElem,"left","-50").c_str() );
-      m_fTopLimit = atof( _GetOption(pLimitsElem,"top","50").c_str() );
-      m_fRightLimit = atof( _GetOption(pLimitsElem,"right","50").c_str() );
-    }
-    
-    /* Get player start */
+
     m_fPlayerStartX = m_fPlayerStartY = 0.0f;
-    TiXmlElement *pPlayerStartElem = _FindElement(pLevelElem,std::string("playerstart"));
-    if(pPlayerStartElem != NULL) {
-      m_fPlayerStartX = atof( _GetOption(pPlayerStartElem,"x","0").c_str() );
-      m_fPlayerStartY = atof( _GetOption(pPlayerStartElem,"y","0").c_str() );
-    }
     
-    /* Get entities */
-    for(TiXmlElement *pElem = pLevelElem->FirstChildElement("entity"); pElem!=NULL; 
-        pElem=pElem->NextSiblingElement("entity")) {
-      /* Allocate it */
-      LevelEntity *pEntity = new LevelEntity;
-      
-      pEntity->ID = _GetOption(pElem,"id");
-      pEntity->TypeID = _GetOption(pElem,"typeid");
-      
-      TiXmlElement *pPosElem = pElem->FirstChildElement("position");
-      if(pPosElem != NULL) {
-				pEntity->fPosX = atof(_GetOption(pPosElem,"x","0").c_str());
-				pEntity->fPosY = atof(_GetOption(pPosElem,"y","0").c_str());
+    if(!m_bXMotoTooOld) {    
+      /* Get level pack */
+      m_LevelPack = _GetOption(pLevelElem,"levelpack");
+                  
+      /* Get level <info> element */
+      TiXmlElement *pInfoElem = _FindElement(pLevelElem,std::string("info"));
+      if(pInfoElem != NULL) {
+        /* Name */
+        std::string Tmp = _GetElementText(pInfoElem,"name");
+        if(Tmp != "") m_Info.Name = Tmp;
+
+        /* Author */
+        Tmp = _GetElementText(pInfoElem,"author");
+        if(Tmp != "") m_Info.Author = Tmp;
+
+        /* Description */
+        Tmp = _GetElementText(pInfoElem,"description");
+        if(Tmp != "") m_Info.Description = Tmp;
+
+        /* Date */
+        Tmp = _GetElementText(pInfoElem,"date");
+        if(Tmp != "") m_Info.Date = Tmp;
+
+        /* Sky */
+        Tmp = _GetElementText(pInfoElem,"sky");
+        if(Tmp != "") m_Info.Sky = Tmp;
       }
       
-      TiXmlElement *pSizeElem = pElem->FirstChildElement("size");
-      if(pSizeElem != NULL) {
-        pEntity->fSize = atof(_GetOption(pSizeElem,"r","0.2").c_str());
-      }
-      
-      /* Get parameters */
-      for(TiXmlElement *pParamElem = pElem->FirstChildElement("param"); pParamElem!=NULL;
-          pParamElem=pParamElem->NextSiblingElement("param")) {
-				LevelEntityParam *pParam = new LevelEntityParam;
-				pParam->Name = _GetOption(pParamElem,"name");
-				pParam->Value = _GetOption(pParamElem,"value");
-				
-				pEntity->Params.push_back( pParam );
-      }
-      
-      /* Add it to the list */
-      m_Entities.push_back( pEntity );
-		}    
-    
-    /* Get zones */
-    for(TiXmlElement *pElem = pLevelElem->FirstChildElement(); pElem!=NULL; pElem=pElem->NextSiblingElement()) {
-      if(!strcmp(pElem->Value(),"zone")) {
-        /* Got one */
-        LevelZone *pZone = new LevelZone;
+      /* Get script */
+      TiXmlElement *pScriptElem = _FindElement(pLevelElem,std::string("script"));
+      if(pScriptElem != NULL) {
+        /* External script file specified? */
+        m_ScriptFile = _GetOption(pScriptElem,"source");      
         
-        pZone->ID = _GetOption(pElem,"id");
-        
-        if(pZone->ID == "") {
-          /* TODO: error */
-          delete pZone;
-          continue;
-        }        
-        
-        /* Get primitives */
-        for(TiXmlElement *pj = pElem->FirstChildElement(); pj!=NULL; pj=pj->NextSiblingElement()) {
-          if(!strcmp(pj->Value(),"box")) {
-            /* Alloc */
-            LevelZonePrim *pPrim = new LevelZonePrim;                        
-            pPrim->Type = LZPT_BOX;
-            pPrim->fBottom = atof( _GetOption(pj,"bottom","0").c_str() );
-            pPrim->fTop = atof( _GetOption(pj,"top","0").c_str() );
-            pPrim->fLeft = atof( _GetOption(pj,"left","0").c_str() );
-            pPrim->fRight = atof( _GetOption(pj,"right","0").c_str() );
-                                    
-            /* Add it */
-            pZone->Prims.push_back( pPrim );
+        /* Encapsulated script? */
+        for(TiXmlNode *pScript=pScriptElem->FirstChild();pScript!=NULL;
+            pScript=pScript->NextSibling()) {
+          if(pScript->Type() == TiXmlNode::TEXT) {
+            m_ScriptSource.append(pScript->Value());
           }
-        }   
+        }
+      }    
+      
+      /* Get level limits */
+      TiXmlElement *pLimitsElem = _FindElement(pLevelElem,std::string("limits"));
+      if(pLimitsElem != NULL) {
+        m_fBottomLimit = atof( _GetOption(pLimitsElem,"bottom","-50").c_str() );
+        m_fLeftLimit = atof( _GetOption(pLimitsElem,"left","-50").c_str() );
+        m_fTopLimit = atof( _GetOption(pLimitsElem,"top","50").c_str() );
+        m_fRightLimit = atof( _GetOption(pLimitsElem,"right","50").c_str() );
+      }
+      
+      /* Get player start */
+      TiXmlElement *pPlayerStartElem = _FindElement(pLevelElem,std::string("playerstart"));
+      if(pPlayerStartElem != NULL) {
+        m_fPlayerStartX = atof( _GetOption(pPlayerStartElem,"x","0").c_str() );
+        m_fPlayerStartY = atof( _GetOption(pPlayerStartElem,"y","0").c_str() );
+      }
+      
+      /* Get entities */
+      for(TiXmlElement *pElem = pLevelElem->FirstChildElement("entity"); pElem!=NULL; 
+          pElem=pElem->NextSiblingElement("entity")) {
+        /* Allocate it */
+        LevelEntity *pEntity = new LevelEntity;
         
-        pZone->m_bInZone = false;     
+        pEntity->ID = _GetOption(pElem,"id");
+        pEntity->TypeID = _GetOption(pElem,"typeid");
+        
+        TiXmlElement *pPosElem = pElem->FirstChildElement("position");
+        if(pPosElem != NULL) {
+				  pEntity->fPosX = atof(_GetOption(pPosElem,"x","0").c_str());
+				  pEntity->fPosY = atof(_GetOption(pPosElem,"y","0").c_str());
+        }
+        
+        TiXmlElement *pSizeElem = pElem->FirstChildElement("size");
+        if(pSizeElem != NULL) {
+          pEntity->fSize = atof(_GetOption(pSizeElem,"r","0.2").c_str());
+        }
+        
+        /* Get parameters */
+        for(TiXmlElement *pParamElem = pElem->FirstChildElement("param"); pParamElem!=NULL;
+            pParamElem=pParamElem->NextSiblingElement("param")) {
+				  LevelEntityParam *pParam = new LevelEntityParam;
+				  pParam->Name = _GetOption(pParamElem,"name");
+				  pParam->Value = _GetOption(pParamElem,"value");
+  				
+				  pEntity->Params.push_back( pParam );
+        }
         
         /* Add it to the list */
-        m_Zones.push_back( pZone );
-      }
-    }
-    
-    /* Get blocks */
-    for(TiXmlElement *pElem = pLevelElem->FirstChildElement(); pElem!=NULL; pElem=pElem->NextSiblingElement()) {
-      if(!strcmp(pElem->Value(),"block")) {
-        /* Got one */
-        LevelBlock *pBlock = new LevelBlock;
-        
-        pBlock->fPosX = 0.0f;
-        pBlock->fPosY = 0.0f;
-        pBlock->fTextureScale = 1.0f;
-        pBlock->ID = _GetOption(pElem,"id");
-        
-        if(pBlock->ID == "") {
-          /* TODO: error */
-          delete pBlock;
-          continue;
-        }
-        
-        pBlock->Texture = "default";        
-        
-        TiXmlElement *pUseTextureElem = _FindElement(pElem,std::string("usetexture"));
-        TiXmlElement *pPositionElem = _FindElement(pElem,std::string("position"));                
-        
-        if(pUseTextureElem != NULL) {
-          pBlock->Texture = _GetOption(pUseTextureElem,"id","default");
-          pBlock->fTextureScale = atof( _GetOption(pUseTextureElem,"scale","1").c_str() );
-        }
-        if(pPositionElem != NULL) {
-          pBlock->fPosX = atof( _GetOption(pPositionElem,"x","0").c_str() );
-          pBlock->fPosY = atof( _GetOption(pPositionElem,"y","0").c_str() );      
+        m_Entities.push_back( pEntity );
+		  }    
+      
+      /* Get zones */
+      for(TiXmlElement *pElem = pLevelElem->FirstChildElement(); pElem!=NULL; pElem=pElem->NextSiblingElement()) {
+        if(!strcmp(pElem->Value(),"zone")) {
+          /* Got one */
+          LevelZone *pZone = new LevelZone;
           
-          if(_GetOption(pPositionElem,"background","false") == "true")
-            pBlock->bBackground = true;
-
-          if(_GetOption(pPositionElem,"water","false") == "true")
-            pBlock->bWater = true;
+          pZone->ID = _GetOption(pElem,"id");
+          
+          if(pZone->ID == "") {
+            /* TODO: error */
+            delete pZone;
+            continue;
+          }        
+          
+          /* Get primitives */
+          for(TiXmlElement *pj = pElem->FirstChildElement(); pj!=NULL; pj=pj->NextSiblingElement()) {
+            if(!strcmp(pj->Value(),"box")) {
+              /* Alloc */
+              LevelZonePrim *pPrim = new LevelZonePrim;                        
+              pPrim->Type = LZPT_BOX;
+              pPrim->fBottom = atof( _GetOption(pj,"bottom","0").c_str() );
+              pPrim->fTop = atof( _GetOption(pj,"top","0").c_str() );
+              pPrim->fLeft = atof( _GetOption(pj,"left","0").c_str() );
+              pPrim->fRight = atof( _GetOption(pj,"right","0").c_str() );
+                                      
+              /* Add it */
+              pZone->Prims.push_back( pPrim );
+            }
+          }   
+          
+          pZone->m_bInZone = false;     
+          
+          /* Add it to the list */
+          m_Zones.push_back( pZone );
         }
-        
-        /* Get vertices */
-        for(TiXmlElement *pj = pElem->FirstChildElement(); pj!=NULL; pj=pj->NextSiblingElement()) {
-          if(!strcmp(pj->Value(),"vertex")) {
-            /* Alloc */
-            LevelBlockVertex *pVertex = new LevelBlockVertex;
-                        
-            pVertex->bSelected = false;
-                        
-            pVertex->fX = atof( _GetOption(pj,"x","0").c_str() );
-            pVertex->fY = atof( _GetOption(pj,"y","0").c_str() );
-            pVertex->EdgeEffect = _GetOption(pj,"edge","");
-            
-            std::string k;
-            k = _GetOption(pj,"tx","");
-            if(k != "") pVertex->fTX = atof( k.c_str() );
-            else pVertex->fTX = pVertex->fX * pBlock->fTextureScale;
-            k = _GetOption(pj,"ty","");
-            if(k != "") pVertex->fTY = atof( k.c_str() );
-            else pVertex->fTY = pVertex->fY * pBlock->fTextureScale;
-            
-            pVertex->r = atoi( _GetOption(pj,"r","255").c_str() );
-            pVertex->g = atoi( _GetOption(pj,"g","255").c_str() );
-            pVertex->b = atoi( _GetOption(pj,"b","255").c_str() );
-            pVertex->a = atoi( _GetOption(pj,"a","255").c_str() );
-            
-            /* Add it */
-            pBlock->Vertices.push_back( pVertex );
-          }
-        }
-        
-        /* Add it */
-        m_Blocks.push_back( pBlock );
       }
-    }  
-    
-    /* Find out where the player starts */
-    if(getEntitiesByTypeID("PlayerStart").size()>0) {
-			LevelEntity *pPlayerStart = getEntitiesByTypeID("PlayerStart")[0];
-			m_fPlayerStartX = pPlayerStart->fPosX;
-			m_fPlayerStartY = pPlayerStart->fPosY;
-		}
-		else {
-			Log("** Warning ** : %s : No player start location found",m_FileName.c_str());
-			m_fPlayerStartX = m_fPlayerStartY = 0.0f;
+      
+      /* Get blocks */
+      for(TiXmlElement *pElem = pLevelElem->FirstChildElement(); pElem!=NULL; pElem=pElem->NextSiblingElement()) {
+        if(!strcmp(pElem->Value(),"block")) {
+          /* Got one */
+          LevelBlock *pBlock = new LevelBlock;
+          
+          pBlock->fPosX = 0.0f;
+          pBlock->fPosY = 0.0f;
+          pBlock->fTextureScale = 1.0f;
+          pBlock->ID = _GetOption(pElem,"id");
+          
+          if(pBlock->ID == "") {
+            /* TODO: error */
+            delete pBlock;
+            continue;
+          }
+          
+          pBlock->Texture = "default";        
+          
+          TiXmlElement *pUseTextureElem = _FindElement(pElem,std::string("usetexture"));
+          TiXmlElement *pPositionElem = _FindElement(pElem,std::string("position"));                
+          
+          if(pUseTextureElem != NULL) {
+            pBlock->Texture = _GetOption(pUseTextureElem,"id","default");
+            pBlock->fTextureScale = atof( _GetOption(pUseTextureElem,"scale","1").c_str() );
+          }
+          if(pPositionElem != NULL) {
+            pBlock->fPosX = atof( _GetOption(pPositionElem,"x","0").c_str() );
+            pBlock->fPosY = atof( _GetOption(pPositionElem,"y","0").c_str() );      
+            
+            if(_GetOption(pPositionElem,"background","false") == "true")
+              pBlock->bBackground = true;
+
+            if(_GetOption(pPositionElem,"water","false") == "true")
+              pBlock->bWater = true;
+            
+            if(_GetOption(pPositionElem,"dynamic","false") == "true")
+              pBlock->bDynamic = true;
+              
+            //if(pBlock->bDynamic)
+            //  printf("%s: %d %d %d\n",pBlock->ID.c_str(),pBlock->bBackground,pBlock->bWater,pBlock->bDynamic);
+          }
+          
+          /* Get vertices */
+          for(TiXmlElement *pj = pElem->FirstChildElement(); pj!=NULL; pj=pj->NextSiblingElement()) {
+            if(!strcmp(pj->Value(),"vertex")) {
+              /* Alloc */
+              LevelBlockVertex *pVertex = new LevelBlockVertex;
+                          
+              pVertex->bSelected = false;
+                          
+              pVertex->fX = atof( _GetOption(pj,"x","0").c_str() );
+              pVertex->fY = atof( _GetOption(pj,"y","0").c_str() );
+              pVertex->EdgeEffect = _GetOption(pj,"edge","");
+              
+              std::string k;
+              k = _GetOption(pj,"tx","");
+              if(k != "") pVertex->fTX = atof( k.c_str() );
+              else pVertex->fTX = pVertex->fX * pBlock->fTextureScale;
+              k = _GetOption(pj,"ty","");
+              if(k != "") pVertex->fTY = atof( k.c_str() );
+              else pVertex->fTY = pVertex->fY * pBlock->fTextureScale;
+              
+              pVertex->r = atoi( _GetOption(pj,"r","255").c_str() );
+              pVertex->g = atoi( _GetOption(pj,"g","255").c_str() );
+              pVertex->b = atoi( _GetOption(pj,"b","255").c_str() );
+              pVertex->a = atoi( _GetOption(pj,"a","255").c_str() );
+              
+              /* Add it */
+              pBlock->Vertices.push_back( pVertex );
+            }
+          }
+          
+          /* Add it */
+          m_Blocks.push_back( pBlock );
+        }
+      }  
+      
+      /* Find out where the player starts */
+      if(getEntitiesByTypeID("PlayerStart").size()>0) {
+			  LevelEntity *pPlayerStart = getEntitiesByTypeID("PlayerStart")[0];
+			  m_fPlayerStartX = pPlayerStart->fPosX;
+			  m_fPlayerStartY = pPlayerStart->fPosY;
+		  }
+		  else {
+			  Log("** Warning ** : %s : No player start location found",m_FileName.c_str());
+			  m_fPlayerStartX = m_fPlayerStartY = 0.0f;
+		  }
 		}
   }
   
@@ -573,6 +606,9 @@ namespace vapp {
   Export binary level file
   ===========================================================================*/
   void LevelSrc::exportBinary(const std::string &FileName,LevelCheckSum *pSum) {
+    /* Don't do this if we failed to load level from XML */
+    if(isXMotoTooOld()) return;
+  
     /* Export binary... */
     FileHandle *pfh = FS::openOFile(FileName);
     if(pfh == NULL) {
@@ -580,7 +616,7 @@ namespace vapp {
     }
     else {
       /* Write tag */
-      FS::writeBuf(pfh,"XBL1",4);
+      FS::writeBuf(pfh,"XBL2",4); /* version two includes dynamic information about blocks */
       
       /* Write CRC32 of XML */
       FS::writeInt_LE(pfh,pSum->nCRC32);
@@ -610,8 +646,9 @@ namespace vapp {
       
       /* Write blocks */
       FS::writeInt_LE(pfh,m_Blocks.size());
-      for(int i=0;i<m_Blocks.size();i++) {
+      for(unsigned int i=0;i<m_Blocks.size();i++) {
         FS::writeString(pfh,m_Blocks[i]->ID);
+        FS::writeBool(pfh,m_Blocks[i]->bDynamic);
         FS::writeBool(pfh,m_Blocks[i]->bBackground);
         FS::writeBool(pfh,m_Blocks[i]->bWater);
         FS::writeString(pfh,m_Blocks[i]->Texture);
@@ -620,7 +657,7 @@ namespace vapp {
         
         FS::writeShort_LE(pfh,m_Blocks[i]->Vertices.size());
         
-        for(int j=0;j<m_Blocks[i]->Vertices.size();j++) {
+        for(unsigned int j=0;j<m_Blocks[i]->Vertices.size();j++) {
           FS::writeFloat(pfh,m_Blocks[i]->Vertices[j]->fX);
           FS::writeFloat(pfh,m_Blocks[i]->Vertices[j]->fY);
           FS::writeString(pfh,m_Blocks[i]->Vertices[j]->EdgeEffect);
@@ -629,14 +666,14 @@ namespace vapp {
       
       /* Write entities */
       FS::writeInt_LE(pfh,m_Entities.size());
-      for(int i=0;i<m_Entities.size();i++) {
+      for(unsigned int i=0;i<m_Entities.size();i++) {
 			  FS::writeString(pfh,m_Entities[i]->ID);
 			  FS::writeString(pfh,m_Entities[i]->TypeID);
 			  FS::writeFloat(pfh,m_Entities[i]->fSize);
         FS::writeFloat(pfh,m_Entities[i]->fPosX);
         FS::writeFloat(pfh,m_Entities[i]->fPosY);
         FS::writeByte(pfh,m_Entities[i]->Params.size());       
-        for(int j=0;j<m_Entities[i]->Params.size();j++) {
+        for(unsigned int j=0;j<m_Entities[i]->Params.size();j++) {
           FS::writeString(pfh,m_Entities[i]->Params[j]->Name);
           FS::writeString(pfh,m_Entities[i]->Params[j]->Value);        
         }
@@ -644,11 +681,11 @@ namespace vapp {
       
       /* Write zones */
       FS::writeInt_LE(pfh,m_Zones.size());
-      for(int i=0;i<m_Zones.size();i++) {
+      for(unsigned int i=0;i<m_Zones.size();i++) {
         FS::writeString(pfh,m_Zones[i]->ID);
         FS::writeByte(pfh,m_Zones[i]->Prims.size());
         
-        for(int j=0;j<m_Zones[i]->Prims.size();j++) {
+        for(unsigned int j=0;j<m_Zones[i]->Prims.size();j++) {
           FS::writeInt_LE(pfh,(int)m_Zones[i]->Prims[j]->Type);
         
           if(m_Zones[i]->Prims[j]->Type == LZPT_BOX) {
@@ -673,6 +710,8 @@ namespace vapp {
     bool bRet = true;
 
     m_fPlayerStartX = m_fPlayerStartY = 0.0f;
+    
+    m_bXMotoTooOld = false;
 
     /* Import binary */
     FileHandle *pfh = FS::openIFile(FileName);
@@ -687,9 +726,11 @@ namespace vapp {
       int nFormat = 0;
       if(!strcmp(cTag,"XBL1"))
         nFormat = 1;
+      else if(!strcmp(cTag,"XBL2"))
+        nFormat = 2;
         
-      if(nFormat == 1) {
-        /* Read "format 1" binary level */
+      if(nFormat == 1 || nFormat == 2) {
+        /* Read "format 1" / "format 2" binary level */
         m_LevelCheckSum.nCRC32 = pSum->nCRC32;
         
         /* Right CRC? */
@@ -738,6 +779,11 @@ namespace vapp {
           for(int i=0;i<nNumBlocks;i++) {
             LevelBlock *pBlock = new LevelBlock;
             pBlock->ID = FS::readString(pfh);
+            
+            if(nFormat == 2) {
+              pBlock->bDynamic = FS::readBool(pfh);
+            }
+            
             pBlock->bBackground = FS::readBool(pfh);
             pBlock->bWater = FS::readBool(pfh);
             pBlock->Texture = FS::readString(pfh);
@@ -836,6 +882,9 @@ namespace vapp {
     return bRet;
   }
 
+  /*===========================================================================
+  Some static helpers
+  ===========================================================================*/
   int LevelSrc::compareLevel(const LevelSrc *p_lvl1, const LevelSrc *p_lvl2) {
     if(p_lvl1->m_Info.Name == p_lvl2->m_Info.Name) {
       return 0;
@@ -847,6 +896,26 @@ namespace vapp {
 
     return -1;
   }
+  
+  int LevelSrc::compareVersionNumbers(const std::string &v1,const std::string &v2) {
+    int nMajor1=0,nMinor1=0,nRel1=0;
+    int nMajor2=0,nMinor2=0,nRel2=0;
     
+    sscanf(v1.c_str(),"%d.%d.%d",&nMajor1,&nMinor1,&nRel1);
+    sscanf(v2.c_str(),"%d.%d.%d",&nMajor2,&nMinor2,&nRel2);
+    
+    if(nMajor1 < nMajor2) return -1;
+    else if(nMajor1 > nMajor2) return 1;
+    
+    if(nMinor1 < nMinor2) return -1;
+    else if(nMinor1 > nMinor2) return 1;
+    
+    if(nRel1 < nRel2) return -1;
+    else if(nRel1 > nRel2) return 1;
+
+    /* Same versions */
+    return 0;    
+  }
+      
 };
 
