@@ -97,6 +97,7 @@ namespace vapp {
       fPosX = fPosY = 0.0f;
       bBackground = false;
       bWater = false;
+      bDynamic = false;
     }
   
     std::string ID;           /* Block ID */
@@ -106,6 +107,7 @@ namespace vapp {
     std::vector<LevelBlockVertex *> Vertices; /* Vertices of block */
     bool bBackground;         /* Background block */
     bool bWater;              /* Water block */
+    bool bDynamic;            /* Non-static geometry */
   };
 
 	/*===========================================================================
@@ -173,6 +175,8 @@ namespace vapp {
       LevelEntity *createEntity(std::string TypeID,float x,float y);
                               
       /* Data interface */ 
+      bool isXMotoTooOld(void) {return m_bXMotoTooOld;}
+      const std::string &getRequiredVersion(void) {return m_RequiredVersion;}
       bool isScripted(void) {if(m_ScriptFile!="" || m_ScriptSource!="") return true; return false;}           
       std::string &getFileName(void) {return m_FileName;}
       void setFileName(const std::string &File) {m_FileName = File;}     
@@ -198,33 +202,36 @@ namespace vapp {
         m_fLeftLimit=fLeft; m_fRightLimit=fRight; m_fTopLimit=fTop; m_fBottomLimit=fBottom;      
       }
       LevelBlock *getBlockByID(std::string ID) {
-        for(int i=0;i<m_Blocks.size();i++) if(m_Blocks[i]->ID == ID) return m_Blocks[i];
+        for(unsigned int i=0;i<m_Blocks.size();i++) if(m_Blocks[i]->ID == ID) return m_Blocks[i];
         return NULL;
       }
       LevelZone *getZoneByID(std::string ID) {
-        for(int i=0;i<m_Zones.size();i++) if(m_Zones[i]->ID == ID) return m_Zones[i];
+        for(unsigned int i=0;i<m_Zones.size();i++) if(m_Zones[i]->ID == ID) return m_Zones[i];
         return NULL;
       }
       LevelEntity *getEntityByID(std::string ID) {
-        for(int i=0;i<m_Entities.size();i++) if(m_Entities[i]->ID == ID) return m_Entities[i];
+        for(unsigned int i=0;i<m_Entities.size();i++) if(m_Entities[i]->ID == ID) return m_Entities[i];
 				return NULL;
       }
       std::vector<LevelEntity *> getEntitiesByTypeID(std::string TypeID) {
 				std::vector<LevelEntity *> Ret;
-        for(int i=0;i<m_Entities.size();i++) if(m_Entities[i]->TypeID == TypeID) Ret.push_back(m_Entities[i]);
+        for(unsigned int i=0;i<m_Entities.size();i++) if(m_Entities[i]->TypeID == TypeID) Ret.push_back(m_Entities[i]);
 				return Ret;				
       }
       std::string getEntityParam(LevelEntity *pEnt,std::string ID,std::string Def="") {
-        for(int i=0;i<pEnt->Params.size();i++) if(pEnt->Params[i]->Name == ID) return pEnt->Params[i]->Value;
+        for(unsigned int i=0;i<pEnt->Params.size();i++) if(pEnt->Params[i]->Name == ID) return pEnt->Params[i]->Value;
         return Def;
       }
       
       const LevelCheckSum *getLevelCheckSum(void) {return &m_LevelCheckSum;}
       void setLevelMD5Sum(const std::string &s) {m_LevelCheckSum.MD5Sum = s;}
+      
       static int compareLevel(const LevelSrc *p_lvl1, const LevelSrc *p_lvl2);    
+      static int compareVersionNumbers(const std::string &v1,const std::string &v2);
 
     private:
       /* Data */
+      std::string m_RequiredVersion;  /* Required X-Moto version */
       std::string m_LevelPack;        /* In this level pack */
       XMLDocument m_XML;              /* Plain XML source */      
       std::string m_FileName;         /* Current file name */
@@ -245,6 +252,8 @@ namespace vapp {
       
       LevelCheckSum m_LevelCheckSum;
       
+      bool m_bXMotoTooOld;            /* Flag set if our X-Moto version is too low to load level */
+      
       /* Helper methods */
       TiXmlElement *_FindElement(TiXmlElement *pRoot,const std::string &Name);
       std::string _GetOption(TiXmlElement *pElem,std::string Name,std::string Default="");
