@@ -128,8 +128,9 @@ namespace vapp {
     }
     bool bSleep = false;
     
+    //printf("{%d}\n",m_Collision.isDynamicTouched());
     //printf("]",m_nStillFrames);        
-    if(m_nStillFrames > PHYS_SLEEP_FRAMES) {
+    if(m_nStillFrames > PHYS_SLEEP_FRAMES && !m_Collision.isDynamicTouched()) {
       bSleep = true;
       dBodyDisable(m_FrontWheelBodyID);
       dBodyDisable(m_RearWheelBodyID);
@@ -163,20 +164,30 @@ namespace vapp {
       dBodyAddForce(m_RearWheelBodyID,RTotal.x,RTotal.y,0);
       dBodyAddForceAtPos(m_FrameBodyID,-RTotal.x,-RTotal.y,0,m_BikeS.RRearWheelP.x,m_BikeS.RRearWheelP.y,0);
       m_BikeS.PrevRq = Rq;
+      
+      /* Have any of the suspensions reached the "squeek-point"? (rate of compression/decompression at 
+         which they will make squeeky noises) */
+      if(Fqv.length() > PHYS_SUSP_SQUEEK_POINT || Rqv.length() > PHYS_SUSP_SQUEEK_POINT) {
+        /* Calculate how large a sqeek it should be */
+        float fSqueekSize1 = Fqv.length() - PHYS_SUSP_SQUEEK_POINT;
+        float fSqueekSize2 = Rqv.length() - PHYS_SUSP_SQUEEK_POINT;
+        float fSqueekSize = fSqueekSize1 > fSqueekSize2 ? fSqueekSize1 : fSqueekSize2;
+        float fMaxSqueek = 0.11f;        
+        float fL = fSqueekSize / fMaxSqueek;
+        if(fL > 1.0f) fL = 1.0f;
+        m_fHowMuchSqueek = fL;                
+        //printf("%f\n",fL);
+                
+        m_bSqueeking = true;
+      }
     }    
 
     /* Apply attitude control (SIMPLISTIC!) */
-    if(m_BikeC.bPullBack && getTime()-m_fLastAttitudeCon > 0.6f) {
-//      m_fAttitudeCon = 8000;
-      m_fAttitudeCon = PHYS_RIDER_ATTITUDE_TORQUE;
-      m_fLastAttitudeCon = getTime();
+    if((m_BikeC.fPull != 0.0f) && (getTime() > m_fNextAttitudeCon)) {
+      m_fAttitudeCon = m_BikeC.fPull * PHYS_RIDER_ATTITUDE_TORQUE;
+      m_fNextAttitudeCon = getTime() + (0.6f * fabsf(m_BikeC.fPull));
     }
-    else if(m_BikeC.bPushForward && getTime()-m_fLastAttitudeCon > 0.6f) {
-      m_fAttitudeCon = -PHYS_RIDER_ATTITUDE_TORQUE;
-//      m_fAttitudeCon = -8000;
-      m_fLastAttitudeCon = getTime();
-    }
-    
+   
     if(m_fAttitudeCon != 0.0f) {
       m_nStillFrames=0;
       dBodyEnable(m_FrontWheelBodyID);
@@ -236,13 +247,13 @@ namespace vapp {
     }
 
     /* Apply motor/brake torques */
-    if(m_BikeC.fBrake > 0.0f) {
+    if(m_BikeC.fDrive < 0.0f) {
       /* Brake! */        
       if(!bSleep) {
         //printf("Brake!\n");
       
-        dBodyAddTorque(m_RearWheelBodyID,0,0,-dBodyGetAngularVel(m_RearWheelBodyID)[2]*PHYS_BRAKE_FACTOR*m_BikeC.fBrake);
-        dBodyAddTorque(m_FrontWheelBodyID,0,0,-dBodyGetAngularVel(m_FrontWheelBodyID)[2]*PHYS_BRAKE_FACTOR*m_BikeC.fBrake);
+        dBodyAddTorque(m_RearWheelBodyID,0,0,dBodyGetAngularVel(m_RearWheelBodyID)[2]*PHYS_BRAKE_FACTOR*m_BikeC.fDrive);
+        dBodyAddTorque(m_FrontWheelBodyID,0,0,dBodyGetAngularVel(m_FrontWheelBodyID)[2]*PHYS_BRAKE_FACTOR*m_BikeC.fDrive);
       }
     }
     else {
@@ -274,6 +285,9 @@ namespace vapp {
     }
       
     /* Perform collision detection between the bike and the level blocks */
+    m_Collision.clearDynamicTouched();
+    _UpdateDynamicCollisionLines(); /* first make sure we now where the dynamic lines are */
+    
     int nNumContacts;
     dContact Contacts[100];
     
@@ -281,8 +295,13 @@ namespace vapp {
                                           even frames, rear wheel odd frames */
     nSlipFrameInterlace++;
         
+    nNumContacts = _IntersectWheelLevel( m_BikeS.FrontWheelP,m_BikeP.WR,Contacts );
+    if(m_Collision.isDynamicTouched()) {
+      if(!dBodyIsEnabled(m_FrontWheelBodyID)) dBodyEnable(m_FrontWheelBodyID);
+      if(!dBodyIsEnabled(m_RearWheelBodyID)) dBodyEnable(m_RearWheelBodyID);
+      if(!dBodyIsEnabled(m_FrameBodyID)) dBodyEnable(m_FrameBodyID);
+    }
     if(dBodyIsEnabled(m_FrontWheelBodyID)) {
-      nNumContacts = _IntersectWheelLevel( m_BikeS.FrontWheelP,m_BikeP.WR,Contacts );
       Vector2f WSP;
       for(int i=0;i<nNumContacts;i++) {
         dJointAttach(dJointCreateContact(m_WorldID,m_ContactGroup,&Contacts[i]),m_FrontWheelBodyID,0);                         
@@ -323,8 +342,13 @@ namespace vapp {
       }
     }
 
+    nNumContacts = _IntersectWheelLevel( m_BikeS.RearWheelP,m_BikeP.WR,Contacts );
+    if(m_Collision.isDynamicTouched()) {
+      if(!dBodyIsEnabled(m_FrontWheelBodyID)) dBodyEnable(m_FrontWheelBodyID);
+      if(!dBodyIsEnabled(m_RearWheelBodyID)) dBodyEnable(m_RearWheelBodyID);
+      if(!dBodyIsEnabled(m_FrameBodyID)) dBodyEnable(m_FrameBodyID);
+    }
     if(dBodyIsEnabled(m_RearWheelBodyID)) {
-      nNumContacts = _IntersectWheelLevel( m_BikeS.RearWheelP,m_BikeP.WR,Contacts );
       Vector2f WSP;
       for(int i=0;i<nNumContacts;i++) {
         dJointAttach(dJointCreateContact(m_WorldID,m_ContactGroup,&Contacts[i]),m_RearWheelBodyID,0);                         
@@ -382,7 +406,7 @@ namespace vapp {
 				}
       }
     }
-    
+        
     //m_PrevFrontWheelP = m_BikeS.FrontWheelP;
     //m_PrevRearWheelP = m_BikeS.RearWheelP;
     m_PrevHeadP = m_BikeS.HeadP;
@@ -439,8 +463,6 @@ namespace vapp {
     m_bFirstPhysicsUpdate = false;
   }
 
-
-#if defined(ALLOW_GHOST)
   /*===========================================================================
     Update game state
     ===========================================================================*/
@@ -541,8 +563,6 @@ namespace vapp {
     pBikeS->RRearWheelP.x = m_BikeA.Rp.x*pBikeS->fFrameRot[0] + m_BikeA.Rp.y*pBikeS->fFrameRot[1] + pBikeS->CenterP.x;
     pBikeS->RRearWheelP.y = m_BikeA.Rp.x*pBikeS->fFrameRot[2] + m_BikeA.Rp.y*pBikeS->fFrameRot[3] + pBikeS->CenterP.y;     
   }
-  
-#endif
 
   void MotoGame::_UpdateGameState(SerializedBikeState *pReplayState) {
     bool bUpdateRider=true,bUpdateAltRider=true;
