@@ -29,13 +29,13 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "BSP.h"
 #include "DBuffer.h"
 #include "Collision.h"
-
-#define GAME_EVENT_QUEUE_SIZE				128
-#define GAME_EVENT_OUTGOING_BUFFER  65536
+#include "ScriptDynamicObjects.h"
+#include "SomersaultCounter.h"
 
 namespace vapp {
 
   class Replay;
+  class GameRenderer;
 
   /*===========================================================================
   Defines
@@ -57,7 +57,10 @@ namespace vapp {
   ===========================================================================*/
   enum EdgeEffect {
     EE_UNASSIGNED,
-    EE_GRASS
+    EE_GRASS,
+    EE_REDBRICKS,
+    EE_GRAYBRICKS,
+    EE_BLUEBRICKS
   };
 
   /*===========================================================================
@@ -72,10 +75,8 @@ namespace vapp {
   Controller struct
   ===========================================================================*/
   struct BikeController {
-    float fDrive;         /* Drive throttle (0-1) */
-    float fBrake;         /* Brake amount (0-1) */
-    bool bPullBack;       /* Pull bike back, i.e. lift front wheel */
-    bool bPushForward;    /* Push bike forward, i.e. lift rear wheel */
+    float fDrive;         /* Throttle [0; 1] or Brake [-1; 0] */
+    float fPull;          /* Pull back on the handle bar [0; 1] or push forward on the handle bar [-1; 0] */
     bool bChangeDir;      /* Change direction */
     
     /* Debug-enabled controls */
@@ -88,6 +89,7 @@ namespace vapp {
   ===========================================================================*/
   struct ConvexBlockVertex {
     Vector2f P;                                   /* Position of vertex */
+    Vector2f T;                                   /* Texture vertex */
   };
 
   /*===========================================================================
@@ -102,6 +104,23 @@ namespace vapp {
     LevelBlock *pSrcBlock;                        /* Source block */
   };
 
+  /*===========================================================================
+  Dynamic block
+  ===========================================================================*/
+  struct DynamicBlock {
+    DynamicBlock() {
+      pSrcBlock = NULL;
+      fRotation = 0.0f;
+    }
+    
+    std::vector<ConvexBlock *> ConvexBlocks;      /* Polygons */
+    LevelBlock *pSrcBlock;                        /* Source block */
+    float fRotation;                              /* Block rotation */    
+    Vector2f Position;                            /* Block position */
+    
+    std::vector<Line *> CollisionLines;           /* Line to collide against */
+  };
+
   /*===========================================================================
   Overlay edge (grass, effects, etc)
   ===========================================================================*/
@@ -384,6 +403,9 @@ namespace vapp {
 	/*===========================================================================
 	Game event types
   ===========================================================================*/
+  /* never change the order of these values ! 
+     ALWAYS ADD VALUES at the end : (otherwise, old replays will not work !)
+  */
   enum GameEventType {
     GAME_EVENT_PLAYER_DIES,
     GAME_EVENT_PLAYER_ENTERS_ZONE,
@@ -400,8 +422,20 @@ namespace vapp {
     GAME_EVENT_LUA_CALL_SETBLOCKPOS,
     GAME_EVENT_LUA_CALL_SETGRAVITY,
     GAME_EVENT_LUA_CALL_SETPLAYERPOSITION,
-    GAME_EVENT_LUA_CALL_SETENTITYPOS
+    GAME_EVENT_LUA_CALL_SETENTITYPOS,
+    GAME_EVENT_LUA_CALL_SETBLOCKCENTER,
+    GAME_EVENT_LUA_CALL_SETBLOCKROTATION,
 
+    GAME_EVENT_LUA_CALL_SETDYNAMICENTITYROTATION,
+    GAME_EVENT_LUA_CALL_SETDYNAMICENTITYTRANSLATION,
+    GAME_EVENT_LUA_CALL_SETDYNAMICENTITYNONE,
+
+    GAME_EVENT_LUA_CALL_CAMERAZOOM,
+    GAME_EVENT_LUA_CALL_CAMERAMOVE,
+
+    GAME_EVENT_LUA_CALL_SETDYNAMICBLOCKROTATION,
+    GAME_EVENT_LUA_CALL_SETDYNAMICBLOCKTRANSLATION,
+    GAME_EVENT_LUA_CALL_SETDYNAMICBLOCKNONE
   };
   
 	/*===========================================================================
@@ -453,12 +487,12 @@ namespace vapp {
   };
   
   struct GameEventLuaCallMoveblock {
-    char cBlockID[64]; /* ID of block */
+    char  cBlockID[64]; /* ID of block */
     float x, y;
   };
   
   struct GameEventLuaCallSetblockpos {
-    char cBlockID[64]; /* ID of block */
+    char  cBlockID[64]; /* ID of block */
     float x, y;
   };
   
@@ -472,10 +506,73 @@ namespace vapp {
   };
   
   struct GameEventLuaCallSetentitypos {
-    char cEntityID[64]; /* ID of entity */
+    char  cEntityID[64]; /* ID of entity */
     float x,y;
   };
   
+  struct GameEventLuaCallSetBlockCenter {
+    char  cBlockID[64]; /* ID of block */
+    float x,y;
+  };
+  
+  struct GameEventLuaCallSetBlockRotation {
+    char  cBlockID[64]; /* ID of block */
+    float fAngle;
+  };
+  
+  struct GameEventLuaCallSetDynamicEntityRotation {
+    char  cEntityID[64]; /* ID of entity */
+    float fInitAngle;
+    float fRadius;
+    float fPeriod;
+    int   startTime;
+    int   endTime;
+  };
+
+  struct GameEventLuaCallSetDynamicEntityTranslation {
+    char  cEntityID[64]; /* ID of entity */
+    float fX;
+    float fY;
+    float fPeriod;
+    int   startTime;
+    int   endTime;
+  };
+ 
+  struct GameEventLuaCallSetDynamicEntityNone {
+    char cEntityID[64]; /* ID of entity */
+  };
+
+  struct GameEventLuaCallSetDynamicBlockRotation {
+    char  cBlockID[64]; /* ID of block */
+    float fInitAngle;
+    float fRadius;
+    float fPeriod;
+    int   startTime;
+    int   endTime;
+  };
+
+  struct GameEventLuaCallSetDynamicBlockTranslation {
+    char  cBlockID[64]; /* ID of block */
+    float fX;
+    float fY;
+    float fPeriod;
+    int   startTime;
+    int   endTime;
+  };
+
+  struct GameEventLuaCallSetDynamicBlockNone {
+    char cBlockID[64]; /* ID of block */
+  };
+
+  struct GameEventLuaCallCameraZoom {
+    float fZoom;
+  };
+
+  struct GameEventLuaCallCameraMove {
+    float x, y;
+  };
+
+
   struct GameEvent {
     int nSeq;                         /* Sequence number */
     GameEventType Type;								/* Type of event */
@@ -496,7 +593,6 @@ namespace vapp {
       /* GAME_EVENT_PLAYER_TOUCHES_ENTITY */
       GameEventPlayerTouchesEntity PlayerTouchesEntity;
 
-
       /* GAME_EVENT_LUA_CALL_CLEARMESSAGES     */
       GameEventLuaCallClearmessages LuaCallClearmessages;
 
@@ -526,6 +622,36 @@ namespace vapp {
 
       /* GAME_EVENT_LUA_CALL_SETENTITYPOS      */
       GameEventLuaCallSetentitypos LuaCallSetentitypos;
+      
+      /* GAME_EVENT_LUA_CALL_SETBLOCKCENTER */
+      GameEventLuaCallSetBlockCenter LuaCallSetBlockCenter;
+
+      /* GAME_EVENT_LUA_CALL_SETBLOCKROTATION */
+      GameEventLuaCallSetBlockRotation LuaCallSetBlockRotation;
+
+      /* GAME_EVENT_LUA_CALL_SETDYNAMICENTITYROTATION */
+      GameEventLuaCallSetDynamicEntityRotation LuaCallSetDynamicEntityRotation;
+
+      /* GAME_EVENT_LUA_CALL_SETDYNAMICENTITYROTATION */
+      GameEventLuaCallSetDynamicEntityTranslation LuaCallSetDynamicEntityTranslation;
+
+      /* GAME_EVENT_LUA_CALL_SETDYNAMICENTITYNONE */
+      GameEventLuaCallSetDynamicEntityNone LuaCallSetDynamicEntityNone;
+
+      /* GAME_EVENT_LUA_CALL_SETDYNAMICBLOCKROTATION */
+      GameEventLuaCallSetDynamicBlockRotation LuaCallSetDynamicBlockRotation;
+
+      /* GAME_EVENT_LUA_CALL_SETDYNAMICBLOCKROTATION */
+      GameEventLuaCallSetDynamicBlockTranslation LuaCallSetDynamicBlockTranslation;
+
+      /* GAME_EVENT_LUA_CALL_SETDYNAMICBLOCKNONE */
+      GameEventLuaCallSetDynamicBlockNone LuaCallSetDynamicBlockNone;
+
+      /* GAME_EVENT_LUA_CALL_CAMERAZOOM */
+      GameEventLuaCallCameraZoom LuaCallCameraZoom;
+
+      /* GAME_EVENT_LUA_CALL_CAMERAMOVE */
+      GameEventLuaCallCameraMove LuaCallCameraMove;
 
     } u;		
   };
@@ -542,16 +668,23 @@ namespace vapp {
   class MotoGame {
     public:          
       MotoGame() {m_pLevelSrc=NULL;
+                  m_bSqueeking=false;
                   clearStates();
 		  m_lastCallToEveryHundreath = 0.0;
 #if defined(ALLOW_GHOST)
 		  m_showGhostTimeDiff = true;
+		  m_isGhostActive = false;
 #endif
+		  m_renderer = NULL;
       }
       ~MotoGame() {endLevel();}     
     
       /* Methods */
-      void playLevel(LevelSrc *pLevelSrc, bool bIsAReplay);
+      void playLevel(
+#if defined(ALLOW_GHOST)    
+		     Replay *m_pGhostReplay,
+#endif
+		     LevelSrc *pLevelSrc, bool bIsAReplay);
       void updateLevel(float fTimeStep,SerializedBikeState *pReplayState,Replay *p_replay);
       void endLevel(void);
       
@@ -573,41 +706,46 @@ namespace vapp {
       float getBikeEngineSpeed();
 
       GameEvent *createGameEvent(GameEventType Type);
+      void destroyGameEvent(GameEvent *p_event);
       GameEvent *getNextGameEvent(void);
       int getNumPendingGameEvents(void);
+      void cleanEventsQueue();
       
       void setPlayerPosition(float x,float y,bool bFaceRight);
       const Vector2f &getPlayerPosition(void);
       bool getPlayerFaceDir(void);
+
+      Entity *getEntityByID(const std::string &ID);
       
       /* Direct Lua interaction methods */
       bool scriptCallBool(std::string FuncName,bool bDefault=false);
       void scriptCallVoid(std::string FuncName);
       void scriptCallTblVoid(std::string Table,std::string FuncName);
-      
+
       /* Data interface */
+      void resetAutoDisabler(void) {m_nStillFrames=0;}
+      bool isInitOK(void) {return m_bLevelInitSuccess;}
       bool isFinished(void) {return m_bFinished;}
       bool isDead(void) {return m_bDead;}
       LevelSrc *getLevelSrc(void) {return m_pLevelSrc;}
       std::vector<ConvexBlock *> &getBlocks(void) {return m_Blocks;}
       BikeState *getBikeState(void) {return &m_BikeS;}
-
       BikeParams *getBikeParams() { return &m_BikeP;}
+      bool isSqueeking(void) {return m_bSqueeking;}
+      float howMuchSqueek(void) {return m_fHowMuchSqueek;}
 
 #if defined(ALLOW_GHOST)
       BikeState *getGhostBikeState(void) {return &m_GhostBikeS;}
       bool isGhostActive() {return m_isGhostActive;}
       void setGhostActive(bool s) {m_isGhostActive = s;}
-      std::vector<float> m_myLastStrawberry;
-      std::vector<float> m_ghostLastStrawberry;
+      std::vector<float> m_myLastStrawberries;
+      std::vector<float> m_ghostLastStrawberries;
       float m_myDiffOfGhost; /* time diff between the ghost and the player */
-      int m_myDiffOfGhostLastStrawberry; /* last Strawberry for which the calcul has been done */
 #endif
       BikeController *getBikeController(void) {return &m_BikeC;}
       std::vector<GameMessage *> &getGameMessage(void) {return m_GameMessages;}
       std::vector<Entity *> &getEntities(void) {return m_Entities;}
-      std::vector<Entity *> &getBSprites(void) {return m_BSprites;}
-      std::vector<Entity *> &getFSprites(void) {return m_FSprites;}
+      std::vector<DynamicBlock *> &getDynBlocks(void) {return m_DynBlocks;}
       std::vector<OverlayEdge *> &getOverlayEdges(void) {return m_OvEdges;}
       float getTime(void) {return m_fTime;}
       void setTime(float f) {m_fTime=f;}
@@ -617,7 +755,7 @@ namespace vapp {
       Vector2f getWheelSpinPoint(void) {return m_WheelSpinPoint;}
       Vector2f getWheelSpinDir(void) {return m_WheelSpinDir;}
       CollisionSystem *getCollisionHandler(void) {return &m_Collision;}
-      void setGravity(float x,float y) {m_PhysGravity.x=x; m_PhysGravity.y=y;}
+      void setGravity(float x,float y) {m_PhysGravity.x=x; m_PhysGravity.y=y; resetAutoDisabler();}
       const Vector2f &getGravity(void) {return m_PhysGravity;}
         
       /* Debug */
@@ -627,23 +765,40 @@ namespace vapp {
       void addDummy(Vector2f Pos,float r,float g,float b);
     
 #if defined(ALLOW_GHOST)  
-      void UpdateGhostFromReplay(Replay *p_replay, SerializedBikeState *pReplayState);
+      void UpdateGhostFromReplay(SerializedBikeState *pReplayState);
       float getGhostDiff() {return m_myDiffOfGhost;}
       void setShowGhostTimeDiff(bool b) { m_showGhostTimeDiff = b; }
 #endif
 
+      /* action for events */
+      void SetEntityPos(String pEntityID, float pX, float pY);
+      void PlaceInGameArrow(float pX, float pY, float pAngle);
+      void PlaceScreenArrow(float pX, float pY, float pAngle);
+      void MoveBlock(String pBlockID, float pX, float pY);
+      void SetBlockPos(String pBlockID, float pX, float pY);
+      void SetBlockCenter(String pBlockID, float pX, float pY);
+      void SetBlockRotation(String pBlockID, float pAngle);
+      DynamicBlock *GetDynamicBlockByID(const std::string &ID);
+
+      void setRenderer(GameRenderer *p_renderer);
+      void CameraZoom(float pZoom);
+      void CameraMove(float p_x, float p_y);
+
     private:         
       /* Data */
-      int m_nGameEventQueueReadIdx,m_nGameEventQueueWriteIdx;
-      GameEvent m_GameEventQueue[GAME_EVENT_QUEUE_SIZE];
+      std::queue<GameEvent*> m_GameEventQueue;
       
-      float m_fTime,m_fLastAttitudeCon;
+      float m_fTime,m_fNextAttitudeCon;
       float m_fFinishTime,m_fAttitudeCon;
       
       int m_nNumDummies;
       DummyHelper m_Dummies[100];
       
       int m_nStillFrames;
+      
+      bool m_bSqueeking;
+      float m_fHowMuchSqueek;
+      bool m_bLevelInitSuccess;
 
       Vector2f m_PhysGravity; /* gravity */
 
@@ -658,11 +813,10 @@ namespace vapp {
       std::vector<Entity *> m_Entities;   /* Entities */
       dWorldID m_WorldID;                 /* World ID */
       
-      std::vector<Entity *> m_FSprites;   /* Foreground sprites */
-      std::vector<Entity *> m_BSprites;   /* Background sprites */
       std::vector<OverlayEdge *> m_OvEdges;/* Overlay edges */
       std::vector<Entity *> m_DelSchedule;/* Entities scheduled for deletion */
       std::vector<GameMessage *> m_GameMessages;
+      std::vector<DynamicBlock *> m_DynBlocks; /* Dynamic blocks */
       
       BikeParams m_BikeP;                 /* Bike physics */      
       BikeAnchors m_BikeA;                /* Important bike anchor points */
@@ -674,6 +828,13 @@ namespace vapp {
       bool m_showGhostTimeDiff;
 #endif
 
+      GameRenderer *m_renderer;
+
+      /* count somersault */
+      SomersaultCounter m_somersaultCounter;
+
+      std::vector<SDynamicObject*> m_SDynamicObjects;
+
       BikeController m_BikeC;             /* Bike controller */
       
       bool m_bFinished,m_bDead;           /* Yir */
@@ -744,11 +905,11 @@ namespace vapp {
             
       /* for EveryHundreath function */
       float m_lastCallToEveryHundreath;
-                
+            
       /* Helpers */
       void _GenerateLevel(void);          /* Called by playLevel() to 
                                              prepare the level */
-      void _CreateBlock(BSPPoly *pPoly,LevelBlock *pSrcBlock);
+      ConvexBlock *_CreateBlock(BSPPoly *pPoly,LevelBlock *pSrcBlock);
       void _CalculateBikeAnchors(void);
       int _IntersectWheelLevel(Vector2f Cp,float Cr,dContact *pContacts);
       int _IntersectWheelLine(Vector2f Cp,float Cr,int nNumContacts,dContact *pContacts,Vector2f A0,Vector2f A1);
@@ -763,10 +924,18 @@ namespace vapp {
       EdgeEffect _TransEdgeEffect(std::string Name);
       void _UpdateEntities(void);
       void _UpdateGameState(SerializedBikeState *pReplayState);
-#if defined(ALLOW_GHOST)
       /* static */ void _UpdateStateFromReplay(SerializedBikeState *pReplayState,BikeState *pBikeS);
+
+#if defined(ALLOW_GHOST)
       void UpdateDiffFromGhost();
+      void DisplayDiffFromGhost();
+      void InitGhostLastStrawberries(Replay *p_ghostReplay);
 #endif
+
+      void cleanScriptDynamicObjects();
+      void nextStateScriptDynamicObjects();
+      void removeSDynamicOfObject(std::string pObject);
+
       char _MapCoordTo8Bits(float fRef,float fMaxDiff,float fCoord);
       float _Map8BitsToCoord(float fRef,float fMaxDiff,char c);
       unsigned short _MatrixTo16Bits(const float *pfMatrix);
@@ -777,19 +946,14 @@ namespace vapp {
       void _HandleReplayEvent(GameEvent *pEvent);
       void _HandleReverseReplayEvent(GameEvent *pEvent);
       
+      void _UpdateDynamicCollisionLines(void);
+      
       /* MPhysics.cpp */
       void _UpdatePhysics(float fTimeStep);
       void _InitPhysics(void);
       void _UninitPhysics(void);
       void _PrepareBikePhysics(Vector2f StartPos);
       void _PrepareRider(Vector2f StartPos);
-         
-      /* action for events */
-      void _SetEntityPos(String pEntityID, float pX, float pY);
-      void _PlaceInGameArrow(float pX, float pY, float pAngle);
-      void _PlaceScreenArrow(float pX, float pY, float pAngle);
-      void _MoveBlock(String pBlockID, float pX, float pY);
-      void _SetBlockPos(String pBlockID, float pX, float pY);
     };
 
 };
