@@ -29,9 +29,11 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Replay.h"
 
 #define ZOOM_DEFAULT 0.195f
+#define CAMERA_OFFSETX_DEFAULT 0.0
+#define CAMERA_OFFSETY_DEFAULT 0.0
 
 namespace vapp {
-
+ 
 	/*===========================================================================
 	Quality settings
   ===========================================================================*/
@@ -47,36 +49,6 @@ namespace vapp {
     std::vector<std::string> Args;    
   };
 
-	/*===========================================================================
-	Animation frame
-  ===========================================================================*/
-  struct AnimationFrame { 
-    Texture *pTexture;              /* Texture handle */
-    Vector2f Size,Center;           /* Where */
-    float fDelay;                   /* How long it should be shown */
-  };
-
-	/*===========================================================================
-	Animation
-  ===========================================================================*/
-  struct Animation {
-    std::string Name;               /* Name of animation */
-    std::vector<AnimationFrame *> m_Frames; /* Frames */
-    
-    /* Run-time info */
-    double fFrameTime;
-    int m_nCurFrame;
-  };
-
-	/*===========================================================================
-	Sprite type
-  ===========================================================================*/
-  struct SpriteType {
-    std::string Name;               /* Name of type */
-    Vector2f Size,Center;           /* How to draw it */
-    Texture *pTexture;              /* Texture */
-  };
-
 	/*===========================================================================
 	Particle type
   ===========================================================================*/
@@ -86,6 +58,7 @@ namespace vapp {
     PT_SMOKE2,
     PT_FIRE,
     PT_DEBRIS,
+    PT_STAR
   };
   
 	/*===========================================================================
@@ -151,21 +124,6 @@ namespace vapp {
     Vector2f Min,Max; /* AABB */
   };
 
-  struct TextureTheme {
-    /* rider */
-    Texture *RiderTorso;
-    Texture *RiderUpperLeg;
-    Texture *RiderLowerLeg;
-    Texture *RiderUpperArm;
-    Texture *RiderLowerArm;
-
-    /* bike */
-    Texture *BikeBody;
-    Texture *BikeRear;
-    Texture *BikeFront;
-    Texture *BikeWheel;
-  };
-
 	/*===========================================================================
 	Special effects overlay
   ===========================================================================*/
@@ -212,12 +170,14 @@ namespace vapp {
   class GameRenderer {
     public:
       GameRenderer() {
-	m_nNumSpriteTypes=0;
 	m_bDebug=false;
 	m_Quality=GQ_HIGH;
 	m_fSpeedMultiply=1.0f;
 	m_fScale = ZOOM_DEFAULT;
+	m_cameraOffsetX = CAMERA_OFFSETX_DEFAULT;
+	m_cameraOffsetY = CAMERA_OFFSETY_DEFAULT;
 	m_bGhostMotionBlur = true;
+	m_theme = NULL;
       }
       ~GameRenderer() {_Free();}
     
@@ -225,12 +185,14 @@ namespace vapp {
       void init(void); /* only called at start-up, and not per-level */
       void shutdown(void);
       
+      void setTheme(Theme *p_theme);
       void render(void);
       void renderMiniMap(int x,int y,int nWidth,int nHeight);
       void prepareForNewLevel(void);
       void unprepareForNewLevel(void);
       void loadDebugInfo(std::string File);
       
+      void clearAllParticles(void);      
       Particle *spawnParticle(ParticleType Type,Vector2f Pos,Vector2f Vel,float fLifeTime);
     
       /* Data interface */
@@ -256,7 +218,10 @@ namespace vapp {
       void setSpeedMultiplier(float f) {m_fSpeedMultiply = f;}
       void zoom(float p_f);
       void initZoom();
+      void moveCamera(float px, float py);
+      void initCamera();
       void setGhostMotionBlur(bool b) {m_bGhostMotionBlur = b;}
+      void skipBackTime(float fTime) {m_fNextParticleUpdate -= fTime;}
       
 #if defined(ALLOW_GHOST)
       void setGhostReplay(Replay *pReplay) {m_pGhostReplay = pReplay;}
@@ -271,6 +236,8 @@ namespace vapp {
     private:
       /* Data */
       float m_fScale;
+      float m_cameraOffsetX;
+      float m_cameraOffsetY;
 
       std::vector<GraphDebugInfo *> m_DebugInfo;
       
@@ -282,12 +249,10 @@ namespace vapp {
       bool m_bDebug;
       bool m_bUglyMode;
       
-      int m_nNumSpriteTypes;
-      SpriteType m_SpriteTypes[100];
-      
-      std::vector<Animation *> m_Anims;
       UIRoot m_GUI;                 /* GUI root */
       
+      Theme *m_theme;
+
       Vector2f m_Scroll;
       float m_fZoom;
       float m_fDesiredHorizontalScrollShift;
@@ -309,20 +274,8 @@ namespace vapp {
       float m_fSpeedMultiply;
       
       UIFont *m_pMFont,*m_pSFont;
-      
-      /* Misc data */
-      Texture *m_pSkyTexture1;
-      Texture *m_pSkyTexture2;
-      Texture *m_pSkyTexture2Drift;
-      Texture *m_pEdgeGrass1;
-      Animation *m_pStrawberryAnim;
-      Animation *m_pFlowerAnim;
-      Animation *m_pWreckerAnim;
-
-      TextureTheme theme_normal;
 
 #if defined(ALLOW_GHOST)
-      TextureTheme theme_ghost;
       Vector2f m_GhostInfoPos,m_GhostInfoVel;
       float m_fNextGhostInfoUpdate;
       int m_nGhostInfoTrans;
@@ -330,13 +283,6 @@ namespace vapp {
       Replay *m_pGhostReplay;
       std::string m_ReplayDesc;
 #endif      
-
-      Texture *m_pArrowTexture;
-      
-      Texture *m_pSmoke1;
-      Texture *m_pSmoke2;
-      Texture *m_pFire1;
-      Texture *m_pDirt1;
       
       GraphQuality m_Quality;
       bool m_bGhostMotionBlur;
@@ -351,11 +297,11 @@ namespace vapp {
       /* Subroutines */
       void _RenderSprites(bool bForeground,bool bBackground);
       void _RenderSprite(Entity *pSprite);
-      void _RenderBike(BikeState *pBike, BikeParams *pBikeParms, TextureTheme *p_theme);
+      void _RenderBike(BikeState *pBike, BikeParams *pBikeParms, BikerTheme *p_theme);
       void _RenderBlocks(void);
+      void _RenderDynamicBlocks(void);
       void _RenderBackground(void);
       void _RenderSky(void);
-      void _RenderEntities(void);    
       void _RenderGameMessages(void); 
       void _RenderGameStatus(void);
       void _RenderParticles(bool bFront=true);
@@ -365,15 +311,16 @@ namespace vapp {
       /* Helpers... */
       void _Vertex(Vector2f P);     /* Spit out a correctly transformed 
                                        glVertex2f() */
-      SpriteType *_GetSpriteTypeByName(std::string Name);
       void _DbgText(Vector2f P,std::string Text,Color c);
-      void _DrawAnimation(Vector2f P,Animation *pAnim);
-      Animation *_GetAnimationByName(std::string Name);
-      void _UpdateAnimations(void);
       void _UpdateParticles(float fTimeStep);
       void _DrawRotatedMarker(Vector2f Pos,dReal *pfRot);     
       void _RenderDebugInfo(void);      
       
+      void _RenderAlphaBlendedSection(Texture *pTexture,const Vector2f &p0,const Vector2f &p1,const Vector2f &p2,const Vector2f &p3);
+      void _RenderAdditiveBlendedSection(Texture *pTexture,const Vector2f &p0,const Vector2f &p1,const Vector2f &p2,const Vector2f &p3);
+      void _RenderAlphaBlendedSectionSP(Texture *pTexture,const Vector2f &p0,const Vector2f &p1,const Vector2f &p2,const Vector2f &p3);
+      void _RenderCircle(int nSteps,Color CircleColor,const Vector2f &C,float fRadius);
+
       /* ... optimizing */
       std::vector<StaticGeom *> _FindGeomsByTexture(Texture *pTex);
       
