@@ -32,12 +32,15 @@ namespace vapp {
   /*===========================================================================
   Rendering of the bike
   ===========================================================================*/
-  void GameRenderer::_RenderBike(BikeState *pBike, BikeParams *pBikeParms, TextureTheme *p_theme) {
+  void GameRenderer::_RenderBike(BikeState *pBike, BikeParams *pBikeParms, BikerTheme *p_theme) {
+    Sprite *pSprite;
+    Texture *pTexture;
+
     /* Render bike */
     Vector2f p0,p1,p2,p3,o0,o1,o2,o3;
     Vector2f C;
     Vector2f Sv,Rc,Fc;
-      
+
     /* Draw front wheel */
     /* Ugly mode? */
     if(m_bUglyMode) {
@@ -67,42 +70,25 @@ namespace vapp {
     /* Ugly mode? */
     if(m_bUglyMode) {
       glBegin(GL_LINE_STRIP);
-      glColor3f(1,0,0);
+      glColor3ub(GET_RED(p_theme->getUglyWheelColor()),GET_GREEN(p_theme->getUglyWheelColor()),GET_BLUE(p_theme->getUglyWheelColor()));
       _Vertex(p0+C);    
       _Vertex(p2+C);
       glEnd();
       glBegin(GL_LINE_STRIP);
-      glColor3f(1,0,0);
+      glColor3ub(GET_RED(p_theme->getUglyWheelColor()),GET_GREEN(p_theme->getUglyWheelColor()),GET_BLUE(p_theme->getUglyWheelColor()));
       _Vertex(p1+C);
       _Vertex(p3+C);
       glEnd();
-      int nSteps = 16;
-      glBegin(GL_LINE_LOOP);              
-      glColor3f(1,0,0);
-      for(int i=0;i<nSteps;i++) {
-        float r = (3.14159f * 2.0f * (float)i)/ (float)nSteps;            
-        _Vertex( Vector2f(C.x + pBikeParms->WR*sin(r),C.y + pBikeParms->WR*cos(r)) );
-      }      
-      glEnd();
+      _RenderCircle(16,p_theme->getUglyWheelColor(),C,pBikeParms->WR);
     }
     else {
-      glEnable(GL_BLEND); 
-      glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-      glBindTexture(GL_TEXTURE_2D,p_theme->BikeWheel->nID);
-      glEnable(GL_TEXTURE_2D);
-      glBegin(GL_POLYGON);
-      glColor3f(1,1,1);
-      glTexCoord2f(0,1);
-      _Vertex(p0+C);    
-      glTexCoord2f(1,1);
-      _Vertex(p1+C);
-      glTexCoord2f(1,0);
-      _Vertex(p2+C);
-      glTexCoord2f(0,0);
-      _Vertex(p3+C);
-      glEnd();
-      glDisable(GL_TEXTURE_2D);
-      glDisable(GL_BLEND);
+      pSprite = p_theme->getWheel();
+      if(pSprite != NULL) {
+	pTexture = pSprite->getTexture();
+	if(pTexture != NULL) {
+	  _RenderAlphaBlendedSection(pTexture,p0+C,p1+C,p2+C,p3+C);
+	}
+      }
     }
 
     /* Draw rear wheel */        
@@ -134,42 +120,25 @@ namespace vapp {
     /* Ugly mode? */
     if(m_bUglyMode) {
       glBegin(GL_LINE_STRIP);
-      glColor3f(1,0,0);
+      glColor3ub(GET_RED(p_theme->getUglyWheelColor()),GET_GREEN(p_theme->getUglyWheelColor()),GET_BLUE(p_theme->getUglyWheelColor()));
       _Vertex(p0+C);    
       _Vertex(p2+C);
       glEnd();
       glBegin(GL_LINE_STRIP);
-      glColor3f(1,0,0);
+      glColor3ub(GET_RED(p_theme->getUglyWheelColor()),GET_GREEN(p_theme->getUglyWheelColor()),GET_BLUE(p_theme->getUglyWheelColor()));
       _Vertex(p1+C);
       _Vertex(p3+C);
       glEnd();
-      int nSteps = 16;
-      glBegin(GL_LINE_LOOP);              
-      glColor3f(1,0,0);
-      for(int i=0;i<nSteps;i++) {
-        float r = (3.14159f * 2.0f * (float)i)/ (float)nSteps;            
-        _Vertex( Vector2f(C.x + pBikeParms->WR*sin(r),C.y + pBikeParms->WR*cos(r)) );
-      }      
-      glEnd();
+      _RenderCircle(16,p_theme->getUglyWheelColor(),C,pBikeParms->WR);
     }
     else {
-      glEnable(GL_BLEND); 
-      glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-      glBindTexture(GL_TEXTURE_2D,p_theme->BikeWheel->nID);
-      glEnable(GL_TEXTURE_2D);
-      glBegin(GL_POLYGON);
-      glColor3f(1,1,1);
-      glTexCoord2f(0,1);
-      _Vertex(p0+C);    
-      glTexCoord2f(1,1);
-      _Vertex(p1+C);
-      glTexCoord2f(1,0);
-      _Vertex(p2+C);
-      glTexCoord2f(0,0);
-      _Vertex(p3+C);
-      glEnd();
-      glDisable(GL_TEXTURE_2D);
-      glDisable(GL_BLEND);
+      pSprite = p_theme->getWheel();
+      if(pSprite != NULL) {
+	pTexture = pSprite->getTexture();
+	if(pTexture != NULL) {
+	  _RenderAlphaBlendedSection(p_theme->getWheel()->getTexture(),p0+C,p1+C,p2+C,p3+C);
+	}
+      }
     }
 
     if(!m_bUglyMode) {
@@ -191,24 +160,14 @@ namespace vapp {
         p3 = pBike->FrontWheelP - Vector2f(-Sv.y,Sv.x)*0.07f - Sv*0.08f;
       }        
 
-      glEnable(GL_BLEND); 
-      glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-      glBindTexture(GL_TEXTURE_2D,p_theme->BikeRear->nID);
-      glEnable(GL_TEXTURE_2D);
-      glBegin(GL_POLYGON);
-      glColor3f(1,1,1);
-      glTexCoord2f(0,0);
-      _Vertex(p0);    
-      glTexCoord2f(1,0);
-      _Vertex(p1);
-      glTexCoord2f(1,1);
-      _Vertex(p2);
-      glTexCoord2f(0,1);
-      _Vertex(p3);
-      glEnd();
-      glDisable(GL_TEXTURE_2D);
-      glDisable(GL_BLEND);        
-   
+      pSprite = p_theme->getRear();
+      if(pSprite != NULL) {
+	pTexture = pSprite->getTexture();
+	if(pTexture != NULL) {
+	  _RenderAlphaBlendedSection(pTexture,p0,p1,p2,p3);
+	}
+      }
+
       /* Draw front suspension */
       if(pBike->Dir == DD_RIGHT) {
         Sv = pBike->FrontAnchorP - Fc;
@@ -226,24 +185,14 @@ namespace vapp {
         p2 = pBike->FrontAnchor2P - Vector2f(-Sv.y,Sv.x)*0.04f - Sv*0.35f;
         p3 = pBike->RearWheelP - Vector2f(-Sv.y,Sv.x)*0.04f - Sv*0.05f;
       }
-      
-      glEnable(GL_BLEND); 
-      glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-      glBindTexture(GL_TEXTURE_2D,p_theme->BikeFront->nID);
-      glEnable(GL_TEXTURE_2D);
-      glBegin(GL_POLYGON);
-      glColor3f(1,1,1);
-      glTexCoord2f(1,0);
-      _Vertex(p0);    
-      glTexCoord2f(1,1);
-      _Vertex(p1);
-      glTexCoord2f(0,1);
-      _Vertex(p2);
-      glTexCoord2f(0,0);
-      _Vertex(p3);
-      glEnd();
-      glDisable(GL_TEXTURE_2D);
-      glDisable(GL_BLEND);        
+
+      pSprite = p_theme->getFront();
+      if(pSprite != NULL) {
+	pTexture = pSprite->getTexture();
+	if(pTexture != NULL) {
+	  _RenderAlphaBlendedSection(pTexture,p3,p0,p1,p2);
+	}
+      }      
 
       /* Draw body/frame */
       o0 = Vector2f(-1,0.5);
@@ -259,37 +208,18 @@ namespace vapp {
       p3 = Vector2f(o3.x*pBike->fFrameRot[0] + o3.y*pBike->fFrameRot[1],
                     o3.x*pBike->fFrameRot[2] + o3.y*pBike->fFrameRot[3]);
       
-      C = pBike->CenterP; //Vector2f(pBike->pfFramePos[0],pBike->pfFramePos[1]);        
-      
-      glEnable(GL_BLEND); 
-      glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-      glBindTexture(GL_TEXTURE_2D,p_theme->BikeBody->nID);
-      glEnable(GL_TEXTURE_2D);
-      glBegin(GL_POLYGON);
-      glColor3f(1,1,1);
-      if(pBike->Dir == DD_RIGHT) {
-        glTexCoord2f(0,0);
-        _Vertex(p0+C);    
-        glTexCoord2f(1,0);
-        _Vertex(p1+C);
-        glTexCoord2f(1,1);
-        _Vertex(p2+C);
-        glTexCoord2f(0,1);
-        _Vertex(p3+C);
+      C = pBike->CenterP; 
+
+      pSprite = p_theme->getBody();
+      if(pSprite != NULL) {
+	pTexture = pSprite->getTexture();
+	if(pTexture != NULL) {
+	  if(pBike->Dir == DD_RIGHT)
+	    _RenderAlphaBlendedSection(pTexture,p3+C,p2+C,p1+C,p0+C);
+	  else
+	    _RenderAlphaBlendedSection(pTexture,p2+C,p3+C,p0+C,p1+C);
+	}
       }
-      else {
-        glTexCoord2f(1,0);
-        _Vertex(p0+C);    
-        glTexCoord2f(0,0);
-        _Vertex(p1+C);
-        glTexCoord2f(0,1);
-        _Vertex(p2+C);
-        glTexCoord2f(1,1);
-        _Vertex(p3+C);
-      }
-      glEnd();
-      glDisable(GL_TEXTURE_2D);
-      glDisable(GL_BLEND);
     }
 
     /* Draw rider */        
@@ -297,7 +227,7 @@ namespace vapp {
       if(m_bUglyMode) {
         /* Draw it ugly */
         glBegin(GL_LINE_STRIP);
-        glColor3f(0,1,0);
+        glColor3ub(GET_RED(p_theme->getUglyRiderColor()),GET_GREEN(p_theme->getUglyRiderColor()),GET_BLUE(p_theme->getUglyRiderColor()));
         _Vertex(pBike->FootP);
         _Vertex(pBike->KneeP);
         _Vertex(pBike->LowerBodyP);
@@ -305,15 +235,7 @@ namespace vapp {
         _Vertex(pBike->ElbowP);
         _Vertex(pBike->HandP);
         glEnd();
-        int nSteps = 10;
-        glBegin(GL_LINE_LOOP);              
-        glColor3f(0,1,0);
-        for(int i=0;i<nSteps;i++) {
-          float r = (3.14159f * 2.0f * (float)i)/ (float)nSteps;            
-          _Vertex( Vector2f(pBike->HeadP.x + pBikeParms->fHeadSize*sin(r),
-                            pBike->HeadP.y + pBikeParms->fHeadSize*cos(r)) );
-        }      
-        glEnd();
+        _RenderCircle(10,p_theme->getUglyRiderColor(),pBike->HeadP,pBikeParms->fHeadSize);
       }
       else {      
         /* Draw rider torso */
@@ -324,24 +246,14 @@ namespace vapp {
         p2 = pBike->LowerBodyP - Vector2f(-Sv.y,Sv.x)*0.24f - Sv*0.1f;
         p3 = pBike->ShoulderP - Vector2f(-Sv.y,Sv.x)*0.24f + Sv*0.46f;
 
-        glEnable(GL_BLEND); 
-        glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-        glBindTexture(GL_TEXTURE_2D,p_theme->RiderTorso->nID);
-        glEnable(GL_TEXTURE_2D);
-        glBegin(GL_POLYGON);
-        glColor3f(1,1,1);
-        glTexCoord2f(0,0);
-        _Vertex(p0);    
-        glTexCoord2f(0,1);
-        _Vertex(p1);
-        glTexCoord2f(1,1);
-        _Vertex(p2);
-        glTexCoord2f(1,0);
-        _Vertex(p3);
-        glEnd();
-        glDisable(GL_TEXTURE_2D);
-        glDisable(GL_BLEND);        
-        
+	pSprite = p_theme->getTorso();
+	if(pSprite != NULL) {
+	  pTexture = pSprite->getTexture();
+	  if(pTexture != NULL) {
+	    _RenderAlphaBlendedSection(pTexture,p1,p2,p3,p0);
+	  }
+	}        
+
         /* Draw rider upper arm */
         Sv = pBike->ShoulderP - pBike->ElbowP;
         Sv.normalize();         
@@ -349,24 +261,14 @@ namespace vapp {
         p1 = pBike->ElbowP + Vector2f(-Sv.y,Sv.x)*0.12f - Sv*0.05f;
         p2 = pBike->ElbowP - Vector2f(-Sv.y,Sv.x)*0.10f - Sv*0.05f;
         p3 = pBike->ShoulderP - Vector2f(-Sv.y,Sv.x)*0.10f;
-        
-        glEnable(GL_BLEND); 
-        glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-        glBindTexture(GL_TEXTURE_2D,p_theme->RiderUpperArm->nID);
-        glEnable(GL_TEXTURE_2D);
-        glBegin(GL_POLYGON);
-        glColor3f(1,1,1);
-        glTexCoord2f(0,0);
-        _Vertex(p0);    
-        glTexCoord2f(0,1);
-        _Vertex(p1);
-        glTexCoord2f(1,1);
-        _Vertex(p2);
-        glTexCoord2f(1,0);
-        _Vertex(p3);
-        glEnd();
-        glDisable(GL_TEXTURE_2D);
-        glDisable(GL_BLEND);        
+
+	pSprite = p_theme->getUpperArm();
+	if(pSprite != NULL) {
+	  pTexture = pSprite->getTexture();
+	  if(pTexture != NULL) {
+	    _RenderAlphaBlendedSection(pTexture,p1,p2,p3,p0);
+	  }
+	}        
 
         /* Draw rider lower arm */
         Sv = pBike->ElbowP - pBike->HandP;
@@ -376,24 +278,14 @@ namespace vapp {
         p2 = pBike->HandP - Vector2f(-Sv.y,Sv.x)*0.10f - Sv*0.05f;
         p3 = pBike->ElbowP - Vector2f(-Sv.y,Sv.x)*0.10f + Sv*0.09f;
         
-        glEnable(GL_BLEND); 
-        glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-        glBindTexture(GL_TEXTURE_2D,p_theme->RiderLowerArm->nID);
-        glEnable(GL_TEXTURE_2D);
-        glBegin(GL_POLYGON);
-        glColor3f(1,1,1);
-        glTexCoord2f(0,0);
-        _Vertex(p0);    
-        glTexCoord2f(1,0);
-        _Vertex(p1);
-        glTexCoord2f(1,1);
-        _Vertex(p2);
-        glTexCoord2f(0,1);
-        _Vertex(p3);
-        glEnd();
-        glDisable(GL_TEXTURE_2D);
-        glDisable(GL_BLEND);        
-        
+	pSprite = p_theme->getLowerArm();
+	if(pSprite != NULL) {
+	  pTexture = pSprite->getTexture();
+	  if(pTexture != NULL) {
+	    _RenderAlphaBlendedSection(pTexture,p3,p2,p1,p0);
+	  }
+	}        
+
         /* Draw rider upper leg */
         Sv = pBike->LowerBodyP - pBike->KneeP;
         Sv.normalize();         
@@ -401,24 +293,14 @@ namespace vapp {
         p1 = pBike->KneeP + Vector2f(-Sv.y,Sv.x)*0.15f + Sv*0.0f;
         p2 = pBike->KneeP - Vector2f(-Sv.y,Sv.x)*0.15f + Sv*0.0f;
         p3 = pBike->LowerBodyP - Vector2f(-Sv.y,Sv.x)*0.1f + Sv*0.14f;
-        
-        glEnable(GL_BLEND); 
-        glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-        glBindTexture(GL_TEXTURE_2D,p_theme->RiderUpperLeg->nID);
-        glEnable(GL_TEXTURE_2D);
-        glBegin(GL_POLYGON);
-        glColor3f(1,1,1);
-        glTexCoord2f(0,1);
-        _Vertex(p0);    
-        glTexCoord2f(1,1);
-        _Vertex(p1);
-        glTexCoord2f(1,0);
-        _Vertex(p2);
-        glTexCoord2f(0,0);
-        _Vertex(p3);
-        glEnd();
-        glDisable(GL_TEXTURE_2D);
-        glDisable(GL_BLEND);        
+
+	pSprite = p_theme->getUpperLeg();
+	if(pSprite != NULL) {
+	  pTexture = pSprite->getTexture();
+	  if(pTexture != NULL) {
+	    _RenderAlphaBlendedSection(pTexture,p0,p1,p2,p3);
+	  }
+	}        
 
         /* Draw rider lower leg */
         Sv = pBike->KneeP - pBike->FootP;
@@ -427,31 +309,21 @@ namespace vapp {
         p1 = pBike->FootP + Vector2f(-Sv.y,Sv.x)*0.2f;
         p2 = pBike->FootP - Vector2f(-Sv.y,Sv.x)*0.2f;
         p3 = pBike->KneeP - Vector2f(-Sv.y,Sv.x)*0.23f + Sv*0.1f;
-        
-        glEnable(GL_BLEND); 
-        glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-        glBindTexture(GL_TEXTURE_2D,p_theme->RiderLowerLeg->nID);
-        glEnable(GL_TEXTURE_2D);
-        glBegin(GL_POLYGON);
-        glColor3f(1,1,1);
-        glTexCoord2f(0,0);
-        _Vertex(p0);    
-        glTexCoord2f(0,1);
-        _Vertex(p1);
-        glTexCoord2f(1,1);
-        _Vertex(p2);
-        glTexCoord2f(1,0);
-        _Vertex(p3);
-        glEnd();
-        glDisable(GL_TEXTURE_2D);
-        glDisable(GL_BLEND);        
+
+	pSprite = p_theme->getLowerLeg();
+	if(pSprite != NULL) {
+	  pTexture = pSprite->getTexture();
+	  if(pTexture != NULL) {
+	    _RenderAlphaBlendedSection(pTexture,p1,p2,p3,p0);        
+	  }
+	}
       }
     }
     else if(pBike->Dir == DD_LEFT) {
       if(m_bUglyMode) {
         /* Draw it ugly */
         glBegin(GL_LINE_STRIP);
-        glColor3f(0,1,0);
+        glColor3ub(GET_RED(p_theme->getUglyRiderColor()),GET_GREEN(p_theme->getUglyRiderColor()),GET_BLUE(p_theme->getUglyRiderColor()));
         _Vertex(pBike->Foot2P);
         _Vertex(pBike->Knee2P);
         _Vertex(pBike->LowerBody2P);
@@ -459,15 +331,7 @@ namespace vapp {
         _Vertex(pBike->Elbow2P);
         _Vertex(pBike->Hand2P);
         glEnd();
-        int nSteps = 10;
-        glBegin(GL_LINE_LOOP);              
-        glColor3f(0,1,0);
-        for(int i=0;i<nSteps;i++) {
-          float r = (3.14159f * 2.0f * (float)i)/ (float)nSteps;            
-          _Vertex( Vector2f(pBike->Head2P.x + pBikeParms->fHeadSize*sin(r),
-                            pBike->Head2P.y + pBikeParms->fHeadSize*cos(r)) );
-        }      
-        glEnd();
+        _RenderCircle(10,p_theme->getUglyRiderColor(),pBike->Head2P,pBikeParms->fHeadSize);
       }
       else {      
         /* Draw rider torso */
@@ -477,25 +341,15 @@ namespace vapp {
         p1 = pBike->LowerBody2P + Vector2f(-Sv.y,Sv.x)*0.24f - Sv*0.1f;
         p2 = pBike->LowerBody2P - Vector2f(-Sv.y,Sv.x)*0.24f - Sv*0.1f;
         p3 = pBike->Shoulder2P - Vector2f(-Sv.y,Sv.x)*0.24f + Sv*0.46f;
-        
-        glEnable(GL_BLEND); 
-        glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-        glBindTexture(GL_TEXTURE_2D,p_theme->RiderTorso->nID);
-        glEnable(GL_TEXTURE_2D);
-        glBegin(GL_POLYGON);
-        glColor3f(1,1,1);
-        glTexCoord2f(1,0);
-        _Vertex(p0);    
-        glTexCoord2f(1,1);
-        _Vertex(p1);
-        glTexCoord2f(0,1);
-        _Vertex(p2);
-        glTexCoord2f(0,0);
-        _Vertex(p3);
-        glEnd();
-        glDisable(GL_TEXTURE_2D);
-        glDisable(GL_BLEND);        
-        
+
+	pSprite = p_theme->getTorso();
+	if(pSprite != NULL) {
+	  pTexture = pSprite->getTexture();
+	  if(pTexture != NULL) {
+	    _RenderAlphaBlendedSection(pTexture,p2,p1,p0,p3);        
+	  }
+	}                
+
         /* Draw rider upper arm */
         Sv = pBike->Shoulder2P - pBike->Elbow2P;
         Sv.normalize();         
@@ -503,24 +357,14 @@ namespace vapp {
         p1 = pBike->Elbow2P + Vector2f(-Sv.y,Sv.x)*0.12f - Sv*0.05f;
         p2 = pBike->Elbow2P - Vector2f(-Sv.y,Sv.x)*0.10f - Sv*0.05f;
         p3 = pBike->Shoulder2P - Vector2f(-Sv.y,Sv.x)*0.10f;
-        
-        glEnable(GL_BLEND); 
-        glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-        glBindTexture(GL_TEXTURE_2D,p_theme->RiderUpperArm->nID);
-        glEnable(GL_TEXTURE_2D);
-        glBegin(GL_POLYGON);
-        glColor3f(1,1,1);
-        glTexCoord2f(1,0);
-        _Vertex(p0);    
-        glTexCoord2f(1,1);
-        _Vertex(p1);
-        glTexCoord2f(0,1);
-        _Vertex(p2);
-        glTexCoord2f(0,0);
-        _Vertex(p3);
-        glEnd();
-        glDisable(GL_TEXTURE_2D);
-        glDisable(GL_BLEND);        
+
+	pSprite = p_theme->getUpperArm();
+	if(pSprite != NULL) {
+	  pTexture = pSprite->getTexture();
+	  if(pTexture != NULL) {
+	    _RenderAlphaBlendedSection(pTexture,p2,p1,p0,p3);        
+	  }
+	}        
 
         /* Draw rider lower arm */
         Sv = pBike->Elbow2P - pBike->Hand2P;
@@ -529,24 +373,14 @@ namespace vapp {
         p1 = pBike->Hand2P + Vector2f(-Sv.y,Sv.x)*0.12f - Sv*0.05f;
         p2 = pBike->Hand2P - Vector2f(-Sv.y,Sv.x)*0.10f - Sv*0.05f;
         p3 = pBike->Elbow2P - Vector2f(-Sv.y,Sv.x)*0.10f + Sv*0.09f;
-        
-        glEnable(GL_BLEND); 
-        glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-        glBindTexture(GL_TEXTURE_2D,p_theme->RiderLowerArm->nID);
-        glEnable(GL_TEXTURE_2D);
-        glBegin(GL_POLYGON);
-        glColor3f(1,1,1);
-        glTexCoord2f(0,1);
-        _Vertex(p0);    
-        glTexCoord2f(1,1);
-        _Vertex(p1);
-        glTexCoord2f(1,0);
-        _Vertex(p2);
-        glTexCoord2f(0,0);
-        _Vertex(p3);
-        glEnd();
-        glDisable(GL_TEXTURE_2D);
-        glDisable(GL_BLEND);              
+
+	pSprite = p_theme->getLowerArm();
+	if(pSprite != NULL) {
+	  pTexture = pSprite->getTexture();
+	  if(pTexture != NULL) {
+	    _RenderAlphaBlendedSection(pTexture,p0,p1,p2,p3);        
+	  }
+	}
 
         /* Draw rider upper leg */
         Sv = pBike->LowerBody2P - pBike->Knee2P;
@@ -555,24 +389,14 @@ namespace vapp {
         p1 = pBike->Knee2P + Vector2f(-Sv.y,Sv.x)*0.15f + Sv*0.0f;
         p2 = pBike->Knee2P - Vector2f(-Sv.y,Sv.x)*0.15f + Sv*0.0f;
         p3 = pBike->LowerBody2P - Vector2f(-Sv.y,Sv.x)*0.1f + Sv*0.14f;
-        
-        glEnable(GL_BLEND); 
-        glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-        glBindTexture(GL_TEXTURE_2D,p_theme->RiderUpperLeg->nID);
-        glEnable(GL_TEXTURE_2D);
-        glBegin(GL_POLYGON);
-        glColor3f(1,1,1);
-        glTexCoord2f(0,0);
-        _Vertex(p0);    
-        glTexCoord2f(1,0);
-        _Vertex(p1);
-        glTexCoord2f(1,1);
-        _Vertex(p2);
-        glTexCoord2f(0,1);
-        _Vertex(p3);
-        glEnd();
-        glDisable(GL_TEXTURE_2D);
-        glDisable(GL_BLEND);        
+
+	pSprite = p_theme->getUpperLeg();
+	if(pSprite != NULL) {
+	  pTexture = pSprite->getTexture();
+	  if(pTexture != NULL) {
+	    _RenderAlphaBlendedSection(pTexture,p3,p2,p1,p0);        
+	  }
+	}
 
         /* Draw rider lower leg */
         Sv = pBike->Knee2P - pBike->Foot2P;
@@ -581,45 +405,19 @@ namespace vapp {
         p1 = pBike->Foot2P + Vector2f(-Sv.y,Sv.x)*0.2f;
         p2 = pBike->Foot2P - Vector2f(-Sv.y,Sv.x)*0.2f;
         p3 = pBike->Knee2P - Vector2f(-Sv.y,Sv.x)*0.23f + Sv*0.1f;
-        
-        glEnable(GL_BLEND); 
-        glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);         
-        glBindTexture(GL_TEXTURE_2D,p_theme->RiderLowerLeg->nID);
-        glEnable(GL_TEXTURE_2D);
-        glBegin(GL_POLYGON);
-        glColor3f(1,1,1);
-        glTexCoord2f(1,0);
-        _Vertex(p0);    
-        glTexCoord2f(1,1);
-        _Vertex(p1);
-        glTexCoord2f(0,1);
-        _Vertex(p2);
-        glTexCoord2f(0,0);
-        _Vertex(p3);
-        glEnd();
-        glDisable(GL_TEXTURE_2D);
-        glDisable(GL_BLEND);     
+
+	pSprite = p_theme->getLowerLeg();
+	if(pSprite != NULL) {
+	  pTexture = pSprite->getTexture();
+	  if(pTexture != NULL) {
+	    _RenderAlphaBlendedSection(pTexture,p2,p1,p0,p3);        
+	  }
+	}
       }
     }   
     
     /* New wheel-spin particles? */
     if(getGameObject()->isWheelSpinning()) {
-      //glBegin(GL_LINE_STRIP);      
-      //glColor3f(1,0.5,0.2);
-      //_Vertex(getGameObject()->getWheelSpinPoint() - Vector2f(0.5,0));
-      //_Vertex(getGameObject()->getWheelSpinPoint() + Vector2f(0.5,0));
-      //glEnd();
-      //glBegin(GL_LINE_STRIP);      
-      //glColor3f(1,0.5,0.2);
-      //_Vertex(getGameObject()->getWheelSpinPoint() - Vector2f(0,0.5));
-      //_Vertex(getGameObject()->getWheelSpinPoint() + Vector2f(0,0.5));
-      //glEnd();      
-      //glBegin(GL_LINE_STRIP);      
-      //glColor3f(0,1,0);
-      //_Vertex(getGameObject()->getWheelSpinPoint());
-      //_Vertex(getGameObject()->getWheelSpinPoint() + getGameObject()->getWheelSpinDir());
-      //glEnd();      
-
       if(randomNum(0,1) < 0.8f) {
         Particle *pNewParticle = spawnParticle(PT_DEBRIS,getGameObject()->getWheelSpinPoint(),
                                               getGameObject()->getWheelSpinDir(),4);
