@@ -38,6 +38,7 @@ namespace vapp {
 
     if(pGame != NULL) {
       Particle *p = new Particle;
+      p->bFront = true;
       p->Type = Type;
       p->Pos = Pos;
       p->Vel = Vel;     
@@ -76,6 +77,12 @@ namespace vapp {
           p->fKillTime += 10000;
           p->fFireSeed = randomNum(0,100);
           break;
+          
+        case PT_STAR:
+          p->fAngVel = randomNum(-60,60);
+          p->Vel = Vector2f(randomNum(-2,2),randomNum(0,2));
+          p->Acc = Vector2f(0,-4);
+          break;
       }
       
       return p;
@@ -110,7 +117,9 @@ namespace vapp {
             else if(pGame->getEntities()[i]->ParticleType == "Fire") {
               for(int k=0;k<10;k++) {
                 /* Generate fire */
-                spawnParticle(PT_FIRE,pGame->getEntities()[i]->Pos,Vector2f(randomNum(-1,1),randomNum(0.1,0.3)),0);
+                Particle *pFireParticle = spawnParticle(PT_FIRE,pGame->getEntities()[i]->Pos,Vector2f(randomNum(-1,1),randomNum(0.1,0.3)),0);
+                pFireParticle->bFront = false;
+                
                 pGame->getEntities()[i]->fNextParticleTime = pGame->getTime() + randomNum(0.05,0.1f);              
               }
             }
@@ -199,6 +208,13 @@ namespace vapp {
     }
   }  
   
+  void GameRenderer::clearAllParticles(void) {
+    for(int i=0;i<m_Particles.size();i++) { 
+      delete m_Particles[i];
+    }
+    m_Particles.clear();
+  }
+  
   void GameRenderer::_RenderParticle(Vector2f P,Texture *pTexture,float fSize,float fAngle,Color c) {
     /* Render single particle */
     if(pTexture == NULL) return;
@@ -235,26 +251,49 @@ namespace vapp {
   }
   
   void GameRenderer::_RenderParticles(bool bFront) {
+    EffectSprite* pType;
+
     /* Render all particles */
     for(int i=0;i<m_Particles.size();i++) {
       if(m_Particles[i]->bFront == bFront) {
         switch(m_Particles[i]->Type) {
           case PT_SMOKE1:
-            _RenderParticle(m_Particles[i]->Pos,m_pSmoke1,m_Particles[i]->fSmokeSize,
-                            m_Particles[i]->fAng,m_Particles[i]->SmokeColor);
+	          pType = (EffectSprite*) getParent()->m_theme.getSprite(SPRITE_TYPE_EFFECT, "Smoke1");
+	          if(pType != NULL) {
+	            _RenderParticle(m_Particles[i]->Pos,pType->getTexture(),m_Particles[i]->fSmokeSize,
+			            m_Particles[i]->fAng,m_Particles[i]->SmokeColor);
+	          }
             break;
           case PT_SMOKE2:
-            _RenderParticle(m_Particles[i]->Pos,m_pSmoke2,m_Particles[i]->fSmokeSize,
-                            m_Particles[i]->fAng,m_Particles[i]->SmokeColor);
+	            pType = (EffectSprite*) getParent()->m_theme.getSprite(SPRITE_TYPE_EFFECT, "Smoke2");
+	            if(pType != NULL) {
+	              _RenderParticle(m_Particles[i]->Pos,pType->getTexture(),m_Particles[i]->fSmokeSize,
+			              m_Particles[i]->fAng,m_Particles[i]->SmokeColor);
+	            }
             break;
           case PT_FIRE:
-            _RenderParticle(m_Particles[i]->Pos,m_pFire1,m_Particles[i]->fFireSize,
-                            m_Particles[i]->fAng,m_Particles[i]->FireColor);
+	            pType = (EffectSprite*) getParent()->m_theme.getSprite(SPRITE_TYPE_EFFECT, "Fire1");
+	            if(pType != NULL) {
+	              _RenderParticle(m_Particles[i]->Pos,pType->getTexture(),m_Particles[i]->fFireSize,
+			              m_Particles[i]->fAng,m_Particles[i]->FireColor);
+	            }
             break;
           case PT_DEBRIS:
-            _RenderParticle(m_Particles[i]->Pos,m_pDirt1,m_Particles[i]->fDebrisSize,
-                            m_Particles[i]->fAng,m_Particles[i]->DebrisTint);
-            break;
+	          pType = (EffectSprite*) getParent()->m_theme.getSprite(SPRITE_TYPE_EFFECT, "Debris1");
+	          if(pType != NULL) {
+	            _RenderParticle(m_Particles[i]->Pos,pType->getTexture(),m_Particles[i]->fDebrisSize,
+			            m_Particles[i]->fAng,m_Particles[i]->DebrisTint);
+	          }
+	          break;
+	        case PT_STAR:
+	          {
+	            AnimationSprite *pStarAnim = (AnimationSprite *)getParent()->m_theme.getSprite(SPRITE_TYPE_ANIMATION,"Star");
+	            if(pStarAnim != NULL) {
+	              _RenderParticle(m_Particles[i]->Pos,pStarAnim->getTexture(),pStarAnim->getWidth(),
+			              m_Particles[i]->fAng,MAKE_COLOR(255,255,255,255));
+			        }
+	          }
+	          break; 	        
         }
       }
     }
