@@ -31,6 +31,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include <time.h>
 #include "VApp.h"
 #include "VFileIO.h"
+#include "arch/SwapEndian.h"
 
 namespace vapp {
 
@@ -128,6 +129,15 @@ namespace vapp {
   Main application entry point
   ===========================================================================*/
   void App::run(int nNumArgs,char **ppcArgs) {
+
+    /* init endian system */ 
+    SwapEndian::Swap_Init();
+    //if(SwapEndian::bigendien) {
+    //  Log("systeme bigendien");
+    //} else {
+    //  Log("systeme littleendien");
+    //}
+
     try {
       /* Parse command-line arguments */
       _ParseArgs(nNumArgs,ppcArgs);        
@@ -278,7 +288,7 @@ namespace vapp {
   }
   
   std::string App::formatTime(float fSecs) {
-    int nHSecs = fSecs * 100;
+    int nHSecs = (int) (fSecs * 100.0);
     char cBuf[256];
     sprintf(cBuf,"%02d:%02d:%02d",nHSecs/6000,(nHSecs%6000)/100,(nHSecs%6000)%100);
     return cBuf;
@@ -368,10 +378,7 @@ namespace vapp {
 	  /* Enable unicode translation and key repeats */
 	  SDL_EnableUNICODE(1);    		  
 	  SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY,SDL_DEFAULT_REPEAT_INTERVAL);
-	  
-	  /* Init drawing library */
-	  initLib(&TexMan);
-	  
+	   
 	  /* Output some general info */
 	  Log("GL: %s (%s)",glGetString(GL_RENDERER),glGetString(GL_VENDOR));
 	  if(glGetString(GL_RENDERER) == NULL || 
@@ -386,8 +393,8 @@ namespace vapp {
       if(!strcmp(reinterpret_cast<const char *>(glGetString(GL_RENDERER)),"GDI Generic") &&
          !strcmp(reinterpret_cast<const char *>(glGetString(GL_VENDOR)),"Microsoft Corporation")) {
         Log("** Warning ** : No GL hardware acceleration!");
-        m_UserNotify = "It seems that no OpenGL hardware acceleration is available!\n"
-                       "Please make sure OpenGL is configured properly.";
+        //m_UserNotify = "It seems that no OpenGL hardware acceleration is available!\n"
+        //               "Please make sure OpenGL is configured properly.";
       }
     #endif
 	  
@@ -496,7 +503,12 @@ namespace vapp {
 	  /* Set background color to black */
 	  glClearColor(0.0f,0.0f,0.0f,0.0f);
 	  glClear(GL_COLOR_BUFFER_BIT);
-	  SDL_GL_SwapBuffers();	  	      
+	  SDL_GL_SwapBuffers();	 
+
+    /* Init drawing library */
+    initLib(&m_theme);
+
+ 	      
   }
 
   /*===========================================================================
@@ -505,12 +517,12 @@ namespace vapp {
   void App::_Uninit(void) {
     /* Tell user app to turn off */
     userShutdown();
-  
+
     if(!isNoGraphics()) {
       /* Uninit drawing library */
-      uninitLib(&TexMan);
+      uninitLib(&m_theme);
     }
-        
+
     /* Shutdown SDL */
     SDL_Quit();
   }
@@ -536,12 +548,14 @@ namespace vapp {
       throw Exception("getDisplayModes : No modes available.");
     }
 
+    /* Always include these to modes */
+    modes->push_back("800 X 600");
+    modes->push_back("1024 X 768");
+
     /* Check if or resolution is restricted */
     if(sdl_modes == (SDL_Rect **)-1){
       /* Should never happen */
       //Log("All resolutions available.");
-      modes->push_back("800 X 600");
-      modes->push_back("1024 X 768");
       modes->push_back("1280 X 1024");
       modes->push_back("1600 X 1200");
     } else{
@@ -563,7 +577,7 @@ namespace vapp {
 	/* Only single */
 	bool findDouble = false;
 	//Log("size: %d", modes->size());
-	for(int j=0; j<modes->size(); j++)
+	for(unsigned int j=0; j<modes->size(); j++)
 	  if(!strcmp(tmp, (*modes)[j].c_str())){
 	    findDouble = true;
 	    break;
@@ -587,10 +601,10 @@ namespace vapp {
     //float fy = (float)(m_nDispHeight*y) / (float)getDispHeight();
     //float fw = (float)(m_nDispWidth*nWidth) / (float)getDispWidth();
     //float fh = (float)(m_nDispHeight*nHeight) / (float)getDispHeight();
-    float fx = (float)(m_nDispWidth*x) / (float)getDispWidth();
-    float fy = (float)(m_nDispHeight*y) / (float)getDispHeight();
-    float fw = (float)(m_nDispWidth*nWidth) / (float)getDispWidth();
-    float fh = (float)(m_nDispHeight*nHeight) / (float)getDispHeight();
+    //float fx = (float)(m_nDispWidth*x) / (float)getDispWidth();
+    //float fy = (float)(m_nDispHeight*y) / (float)getDispHeight();
+    //float fw = (float)(m_nDispWidth*nWidth) / (float)getDispWidth();
+    //float fh = (float)(m_nDispHeight*nHeight) / (float)getDispHeight();
   
     //glScissor(fx,m_nDispHeight - (fy+fh)-1,fw+1,fh+1);
     
