@@ -24,10 +24,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "VCommon.h"
 
-#include "VExcept.h"
-#include "VMath.h"
+//#include "VExcept.h"
+//#include "VMath.h"
 #include "VDraw.h"
-#include "VTexture.h"
+//#include "VTexture.h"
 #include "Image.h"
 
 namespace vapp {
@@ -50,6 +50,7 @@ namespace vapp {
         m_pParentApp = NULL;
         m_bShouldClose = false;
       }
+      virtual ~SubApp() {};
       
       /* Methods */
       int run(App *pParent);
@@ -107,6 +108,7 @@ namespace vapp {
              m_AppCommand="";
              m_UserNotify="";
              }
+      virtual ~App() {}
     
       /* Methods */
       void run(int nNumArgs,char **ppcArgs);
@@ -117,8 +119,8 @@ namespace vapp {
       void setAppCommand(const std::string &i) {m_AppCommand=i;}
       void setFPS(float i) {m_fFramesPerSecond=i;}      
             
-      double getTime(void); 
-      double getRealTime(void);
+      static double getTime(void); 
+      static double getRealTime(void);
       std::string getTimeStamp(void);
       void quit(void);      
       static std::string formatTime(float fSecs);
@@ -149,7 +151,7 @@ namespace vapp {
       float getFPS(void) {return m_fFramesPerSecond;}      
       bool isNoGraphics(void) {return m_bNoGraphics;}
       void setNoGraphics(bool b) {m_bNoGraphics = b;}
-      std::string getVersionString(void) {
+      static std::string getVersionString(void) {
         char cBuf[256]; sprintf(cBuf,"%d.%d.%d" BUILD_EXTRAINFO,BUILD_MAJORVERSION,BUILD_VERSION,BUILD_MINORVERSION);
         return cBuf;        
       }
@@ -162,8 +164,8 @@ namespace vapp {
       bool useFBOs(void) {return m_bFBOSupported;}
       bool useShaders(void) {return m_bShadersSupported;}
       
-      TextureManager TexMan;
-
+      Theme m_theme;
+      
       /* Extensions */
       PFNGLGENBUFFERSARBPROC glGenBuffersARB;
       PFNGLBINDBUFFERARBPROC glBindBufferARB;
