@@ -26,6 +26,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 namespace vapp {
 
+ DrawLib::DrawLib() {
+   m_pDefaultFontTex = NULL;
+ }
+
   /*===========================================================================
   Transform an OpenGL vertex to pure 2D 
   ===========================================================================*/
@@ -63,7 +67,7 @@ namespace vapp {
     }
 
     /* How many steps? */    
-    int nSteps=2.0f*(fRadius / 3.0f);
+    int nSteps= (int) (2.0f*(fRadius / 3.0f));
     if(nSteps<8) nSteps=8;
     if(nSteps>64) nSteps=64;
     
@@ -188,15 +192,15 @@ namespace vapp {
   /*===========================================================================
   Init of 2D drawing library
   ===========================================================================*/
-  void DrawLib::initLib(TextureManager *pTextureManager) {
-    _InitTextRendering(pTextureManager);
+  void DrawLib::initLib(Theme *p_theme) {
+    _InitTextRendering(p_theme);
   }
   
   /*===========================================================================
   Uninit
   ===========================================================================*/
-  void DrawLib::uninitLib(TextureManager *pTextureManager) {
-    _UninitTextRendering(pTextureManager);
+  void DrawLib::uninitLib(Theme *p_theme) {
+    _UninitTextRendering(p_theme);
   }
   
 };
