@@ -36,6 +36,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "VExcept.h"
 #include "VApp.h"
 #include "VFileIO.h"
+#include "arch/SwapEndian.h"
 
 namespace vapp {
 
@@ -52,11 +53,11 @@ namespace vapp {
   #endif
   #if !defined(_MSC_VER)
     void strlwr(char *pc) {
-      for(int i=0;i<strlen(pc);i++) pc[i] = tolower(pc[i]);
+      for(unsigned int i=0; i<strlen(pc); i++) pc[i] = tolower(pc[i]);
     }
   #endif
   mbool str_match_wildcard(char *pcMWildcard,char *pcMString,mbool CaseSensitive) {
-	  int i,nPos=0;
+	  int nPos=0;
 	  mbool PrevIsWildcard=FALSE;
 	  char c1[256],c2[256];
 	  char *pcWildcard,*pcString;
@@ -75,7 +76,7 @@ namespace vapp {
   	
 	  if(pcWildcard[0]=='\0') return TRUE;
   	
-	  for(i=0;i<strlen(pcWildcard);i++) {
+	  for(unsigned i=0; i<strlen(pcWildcard); i++) {
 		  /* If end of string is reached, we have a match */
 		  if(pcString[nPos] == '\0' && pcWildcard[i] == '\0')
 			  return TRUE;
@@ -191,7 +192,7 @@ namespace vapp {
               /* Match! */
               if(strcmp(dp->d_name,".") && strcmp(dp->d_name,"..")) {
 					      bool bFound = false;
-					      for(int k = 0;k<List.size();k++) {
+					      for(unsigned int k = 0;k<List.size();k++) {
   					      if(FS::getFileBaseName(List[k]) == FS::getFileBaseName(F)) {  
 					          bFound = true;
 					          break;
@@ -294,7 +295,7 @@ namespace vapp {
               if(strcmp(dp->d_name,".") && strcmp(dp->d_name,"..")) {
 					      std::string F = DirToSearch + std::string(dp->d_name);
 					      bool bFound = false;
-					      for(int k = 0;k<Result.size();k++) {
+					      for(unsigned int k = 0;k<Result.size();k++) {
   					      if(FS::getFileBaseName(Result[k]) == FS::getFileBaseName(F)) {  
 					          bFound = true;
 					          break;
@@ -327,7 +328,7 @@ namespace vapp {
                 if(strcmp(dp->d_name,".") && strcmp(dp->d_name,"..")) {
 					        std::string F = DirToSearch + std::string(dp->d_name);
 					        bool bFound = false;
-					        for(int k = 0;k<Result.size();k++) {
+					        for(unsigned int k = 0;k<Result.size();k++) {
     					      if(FS::getFileBaseName(Result[k]) == FS::getFileBaseName(F)) {  
 					            bFound = true;
 					            break;
@@ -361,7 +362,7 @@ namespace vapp {
                 if(strcmp(dp->d_name,".") && strcmp(dp->d_name,"..")) {
 					        std::string F = DirToSearch + std::string(dp->d_name);
 					        bool bFound = false;
-					        for(int k = 0;k<Result.size();k++) {
+					        for(unsigned int k = 0;k<Result.size();k++) {
     					      if(FS::getFileBaseName(Result[k]) == FS::getFileBaseName(F)) {  
 					            bFound = true;
 					            break;
@@ -481,7 +482,7 @@ namespace vapp {
     delete pfh;
   } 
 
-  bool FS::readBuf(FileHandle *pfh,char *pcBuf,int nBufSize) {
+  bool FS::readBuf(FileHandle *pfh,char *pcBuf, unsigned int nBufSize) {
     if(!pfh->bRead) _ThrowFileError(pfh,"readBuf -> write-only");  
     if(pfh->Type == FHT_STDIO) {
       if(fread(pcBuf,1,nBufSize,pfh->fp) != nBufSize) return false;
@@ -499,7 +500,7 @@ namespace vapp {
     return true;
   } 
   
-  bool FS::writeBuf(FileHandle *pfh,char *pcBuf,int nBufSize) {
+  bool FS::writeBuf(FileHandle *pfh, char *pcBuf, unsigned int nBufSize) {
     if(!pfh->bWrite) _ThrowFileError(pfh,"writeBuf -> read-only");  
     if(pfh->Type == FHT_STDIO) {
       if(fwrite(pcBuf,1,nBufSize,pfh->fp) != nBufSize) return false;
@@ -751,9 +752,13 @@ namespace vapp {
     if(n<0) n = Path.find_last_of("\\");
     if(n<0) {
       /* No directory info */
-      return std::string("./");
+      return std::string(".");
     }
-    return Path.substr(0,n+1);
+    std::string v_fileDir = Path.substr(0,n);
+    if(v_fileDir == "") {
+      v_fileDir = "/";
+    }
+    return v_fileDir;
   }
   
   /*===========================================================================
@@ -875,10 +880,11 @@ namespace vapp {
         if(fp == NULL) {
           /* Good one */
           FullTo = cTemp;
-          break;        
-        }
-        fclose(fp);
-        
+          break;
+        } else {
+	  fclose(fp);
+	  i++;
+	}
         /* Next */
       }      
     }
@@ -1174,6 +1180,51 @@ namespace vapp {
 
     return res;
   }  
-  
+ 
+  bool FS::isInUserDir(std::string p_filepath) {
+    std::string v_userDir;
+    std::string v_fileDir;
+
+    v_userDir = getUserDir();
+    v_fileDir = getFileDir(p_filepath);
+
+    if(v_userDir.length() > v_fileDir.length()) {
+      return false;
+    }
+
+    return v_fileDir.substr(0, v_userDir.length()) == v_userDir;
+  }
+
+  bool FS::doesDirectoryExist(std::string p_path) {
+    struct stat S;
+    return stat(p_path.c_str(), &S) == 0;
+  }
+
+  bool FS::isFileReadable(std::string p_filename) {
+    FileHandle *fh = openIFile(p_filename);
+    if(fh == NULL) {
+      return false;
+    }
+    closeFile(fh);
+    return true;
+  }
+
+  bool FS::fileExists(std::string p_filename) {
+    return isFileReadable(p_filename);
+  }
+
+  void FS::mkArborescence(std::string v_filepath) {
+    std::string v_parentDir = getFileDir(v_filepath);
+
+    if(doesDirectoryExist(v_parentDir)) {
+      return;
+    }
+
+    mkArborescence(v_parentDir);
+    if(mkDir(v_parentDir.c_str()) != 0) {
+      throw Exception("Can't create directory " + v_parentDir);
+    }
+  }
+
 };
 
