@@ -94,8 +94,8 @@ namespace vapp {
       static FileHandle *openIFile(std::string Path);
       static void closeFile(FileHandle *pfh);
 
-      static bool readBuf(FileHandle *pfh,char *pcBuf,int nBufSize);
-      static bool writeBuf(FileHandle *pfh,char *pcBuf,int nBufSize);     
+      static bool readBuf(FileHandle *pfh,char *pcBuf, unsigned int nBufSize);
+      static bool writeBuf(FileHandle *pfh,char *pcBuf, unsigned int nBufSize);     
       static bool setOffset(FileHandle *pfh,int nOffset);
       static bool setEnd(FileHandle *pfh);
       static int getOffset(FileHandle *pfh);
@@ -157,6 +157,14 @@ namespace vapp {
       static std::string getReplaysDir(void) {return m_UserDir + std::string("/Replays");}
       static std::string getLevelsDir(void) {return m_UserDir + std::string("/Levels");}
     
+      static bool doesDirectoryExist(std::string p_path);
+      static bool isFileReadable(std::string p_filename);
+      static bool fileExists(std::string p_filename);
+      static void mkArborescence(std::string v_filepath);
+
+      // return true if p_filepath is a path from user dir
+      static bool isInUserDir(std::string p_filepath);
+
     private:
       /* Helper functions */
       static void _ThrowFileError(FileHandle *pfh,std::string Description);
