@@ -98,7 +98,7 @@ namespace vapp {
   ===========================================================================*/  
   void TextureManager::destroyTexture(Texture *pTexture) {
     if(pTexture != NULL) {
-      for(int i=0;i<m_Textures.size();i++) {
+      for(unsigned int i=0;i<m_Textures.size();i++) {
         if(m_Textures[i] == pTexture) {
           glDeleteTextures(1,(GLuint *)&pTexture->nID);
           m_nTexSpaceUsage -= pTexture->nSize;
@@ -121,6 +121,15 @@ namespace vapp {
     Img TextureImage;
     Texture *pTexture = NULL;
     
+    /* Name it */
+    std::string TexName = FS::getFileBaseName(Path);
+
+    /* if the texture is already loaded, return it */
+    pTexture = getTexture(TexName);
+    if(pTexture != NULL) {
+      return pTexture;
+    }
+
     if(TextureImage.checkFile( Path,&ii )) {
       /* Valid texture size? */
       if(ii.nWidth != ii.nHeight) {
@@ -141,10 +150,7 @@ namespace vapp {
         Log("** Warning ** : TextureManager::loadTexture() : texture '%s' size is not power of two",Path.c_str());
         throw TextureError("texture size not power of two");
       }
-    
-      /* Name it */
-      std::string TexName = FS::getFileBaseName(Path);
-      
+         
       /* Load it into system memory */
       TextureImage.loadFile(Path,bSmall);
       
@@ -162,7 +168,7 @@ namespace vapp {
     }
     else {
       Log("** Warning ** : TextureManager::loadTexture() : texture '%s' not found or invalid",Path.c_str());
-      throw TextureError("invalid or missing texture file");
+      throw TextureError(std::string("invalid or missing texture file (" + Path + ")").c_str());
     }    
     
     return pTexture;
@@ -172,9 +178,7 @@ namespace vapp {
   Get loaded texture by name
   ===========================================================================*/  
   Texture *TextureManager::getTexture(std::string Name) {
-    if(Name == "default") return getTexture( m_DefaultTextureName );
-    
-    for(int i=0;i<m_Textures.size();i++)
+    for(unsigned int i=0;i<m_Textures.size();i++)
       if(m_Textures[i]->Name == Name) return m_Textures[i];
     return NULL;
   }
@@ -185,7 +189,7 @@ namespace vapp {
   std::vector<Texture *> TextureManager::fetchTaggedTextures(std::string Tag) {
     std::vector<Texture *> Ret;
     
-    for(int i=0;i<m_Textures.size();i++) {
+    for(unsigned int i=0;i<m_Textures.size();i++) {
       if(m_Textures[i]->Tag == Tag) Ret.push_back(m_Textures[i]);
     }
     return Ret;
