@@ -16,10 +16,12 @@
  */
 
 #include "WWW.h"
+#include "VApp.h"
 #include "VFileIO.h"
 #include "VExcept.h"
 #include "VXml.h"
 #include <curl/curl.h>
+
 #ifdef WIN32
   #include <io.h>
 #else
@@ -29,6 +31,8 @@
 #endif
 #include <sys/stat.h>
 #include <vector>
+#include "compression/FileCompression.h"
+#include "md5sum/md5file.h"
 
 ProxySettings::ProxySettings() {
   m_server       = "";
@@ -189,7 +193,7 @@ float WebHighscore::getFTime() const {
   v_fsec = atof(v_sec.c_str());
   v_fhun = atof(v_hun.c_str());
 
-  return v_fmin * 60.0 + v_fsec + v_fhun / 60.0;
+  return v_fmin * 60.0 + v_fsec + v_fhun / 100.0;
 }
 
 WebRoom* WebHighscore::getRoom() const {
@@ -313,7 +317,11 @@ void WebRoom::fillHash() {
 
 void WebRoom::update() {
   /* download xml file */
-  FSWeb::downloadFile(m_userFilename, m_webhighscores_url, NULL, NULL, m_proxy_settings);
+  FSWeb::downloadFileBz2UsingMd5(m_userFilename,
+				 m_webhighscores_url,
+				 NULL,
+				 NULL,
+				 m_proxy_settings);
 }
 
 void WebRoom::upgrade() {
@@ -324,6 +332,80 @@ size_t FSWeb::writeData(void *ptr, size_t size, size_t nmemb, FILE *stream) {
   return fwrite (ptr, size, nmemb, stream);
 }
 
+void FSWeb::downloadFileBz2(const std::string &p_local_file,
+			    const std::string &p_web_file,
+			    int (*curl_progress_callback)(void *clientp,
+							  double dltotal,
+							  double dlnow,
+							  double ultotal,
+							  double ulnow),
+			    void *p_data,
+			    const ProxySettings *p_proxy_settings) {
+  std::string v_bzFile = p_local_file + ".bz2";
+
+  /* remove in case it already exists */
+  remove(v_bzFile.c_str());
+  downloadFile(v_bzFile,
+	       p_web_file + ".bz2",
+	       curl_progress_callback,
+	       p_data,
+	       p_proxy_settings
+	       );
+
+  try {
+    FileCompression::bunzip2(v_bzFile, p_local_file);
+    remove(v_bzFile.c_str());
+  } catch(vapp::Exception &e) {
+    remove(v_bzFile.c_str());
+    throw e;
+  }
+}
+
+void FSWeb::downloadFileBz2UsingMd5(const std::string &p_local_file,
+				    const std::string &p_web_file,
+				    int (*curl_progress_callback)(void *clientp,
+								  double dltotal,
+								  double dlnow,
+								  double ultotal,
+								  double ulnow),
+				    void *p_data,
+				    const ProxySettings *p_proxy_settings) {
+  bool require_dwd = true;
+
+  try {
+    if(vapp::FS::isFileReadable(p_local_file) == true) {
+      std::string v_md5Local  = md5file(p_local_file);
+      if(v_md5Local != "") {
+	std::string v_md5File = p_local_file + ".md5";
+	
+	/* remove in case it already exists */
+	remove(v_md5File.c_str());
+	downloadFile(v_md5File,
+		     p_web_file + ".md5",
+		     NULL, /* nothing for this */
+		     NULL,
+		     p_proxy_settings
+		     );
+
+	std::string v_md5Web = md5Contents(v_md5File);
+	remove(v_md5File.c_str());
+	if(v_md5Web != "") {
+	  require_dwd = v_md5Web != v_md5Local;
+	}
+      }
+    }
+  } catch(vapp::Exception &e) {
+    /* no pb, just dwd */
+  }
+    
+  if(require_dwd) {
+    FSWeb::downloadFileBz2(p_local_file,
+			   p_web_file,
+			   curl_progress_callback,
+			   p_data,
+			   p_proxy_settings);
+  }
+}
 
 void FSWeb::downloadFile(const std::string &p_local_file,
 			 const std::string &p_web_file,
@@ -344,6 +426,7 @@ void FSWeb::downloadFile(const std::string &p_local_file,
 
   std::string v_proxy_server;
   std::string v_proxy_auth_str;
+  std::string v_www_agent = WWW_AGENT;
 
   /* open the file */
   if( (v_destinationFile = fopen(v_local_file_tmp.c_str(), "wb")) == false) {
@@ -363,6 +446,8 @@ void FSWeb::downloadFile(const std::string &p_local_file,
   curl_easy_setopt(v_curl, CURLOPT_WRITEFUNCTION, FSWeb::writeData);
   curl_easy_setopt(v_curl, CURLOPT_TIMEOUT, DEFAULT_TRANSFERT_TIMEOUT);
   curl_easy_setopt(v_curl, CURLOPT_CONNECTTIMEOUT, DEFAULT_TRANSFERT_CONNECT_TIMEOUT);
+  curl_easy_setopt(v_curl, CURLOPT_USERAGENT,  v_www_agent.c_str());
+  curl_easy_setopt(v_curl, CURLOPT_FAILONERROR, 1);
 
   /* set proxy settings */
   if(p_proxy_settings != NULL) {
@@ -404,6 +489,12 @@ void FSWeb::downloadFile(const std::string &p_local_file,
   curl_easy_cleanup(v_curl);
   fclose(v_destinationFile);
 
+  /* this is not considered as an error */
+  if(res == CURLE_ABORTED_BY_CALLBACK) {
+    remove(v_local_file_tmp.c_str());
+    return;
+  }
+
   if(res != CURLE_OK) {
     remove(v_local_file_tmp.c_str());
     throw vapp::Exception("error : unable to download file "
@@ -460,6 +551,7 @@ WebLevels::WebLevels(vapp::WWWAppInterface *p_WebLevelApp,
 		     const ProxySettings *p_proxy_settings) {
   m_WebLevelApp    = p_WebLevelApp;
   m_proxy_settings = p_proxy_settings;
+  m_levels_url     = DEFAULT_WEBLEVELS_URL;
 }
 
 WebLevels::~WebLevels() {
@@ -475,11 +567,11 @@ std::string WebLevels::getXmlFileName() {
 }
 
 void WebLevels::downloadXml() {
-  FSWeb::downloadFile(getXmlFileName(),
-		      m_levels_url,
-		      NULL,
-		      NULL,
-		      m_proxy_settings);
+  FSWeb::downloadFileBz2UsingMd5(getXmlFileName(),
+				 m_levels_url,
+				 NULL,
+				 NULL,
+				 m_proxy_settings);
 }
 
 std::string WebLevels::getDestinationDir() {
@@ -575,28 +667,28 @@ void WebLevels::update() {
 }
 
 struct f_curl_download_data {
-  vapp::WWWAppInterface *v_WebLevelApp;
-  int v_nb_levels_to_download;
-  int v_nb_levels_performed;
+  vapp::WWWAppInterface *v_WebApp;
+  int v_nb_files_to_download;
+  int v_nb_files_performed;
 };
 
-int WebLevels::f_curl_progress_callback(void *clientp,
-					double dltotal,
-					double dlnow,
-					double ultotal,
-					double ulnow) {
+int FSWeb::f_curl_progress_callback(void *clientp,
+				    double dltotal,
+				    double dlnow,
+				    double ultotal,
+				    double ulnow) {
   f_curl_download_data *data = ((f_curl_download_data*) clientp);
   float real_percentage_already_done;
   float real_percentage_of_current_file;
 
   /* cancel if it's wanted */
-  if(data->v_WebLevelApp->isCancelAsSoonAsPossible()) {
+  if(data->v_WebApp->isCancelAsSoonAsPossible()) {
     return 1;
   }
 
   real_percentage_already_done = 
-    (((float)data->v_nb_levels_performed) * 100.0) 
-    / ((float)data->v_nb_levels_to_download);
+    (((float)data->v_nb_files_performed) * 100.0) 
+    / ((float)data->v_nb_files_to_download);
 
   /* we can't make confiance to the web server information */
   real_percentage_of_current_file = 0.0;
@@ -604,11 +696,11 @@ int WebLevels::f_curl_progress_callback(void *clientp,
     if((dlnow / dltotal) >= 0.0 && (dlnow / dltotal) <= 1.0) {
       real_percentage_of_current_file = 
 	(dlnow * 100.0) 
-	/ (((float)data->v_nb_levels_to_download) * dltotal);
+	/ (((float)data->v_nb_files_to_download) * dltotal);
     }
   }
 
-  data->v_WebLevelApp->setTaskProgress(real_percentage_already_done + real_percentage_of_current_file);
+  data->v_WebApp->setTaskProgress(real_percentage_already_done + real_percentage_of_current_file);
 
   return 0;
 }
@@ -623,8 +715,8 @@ void WebLevels::upgrade() {
   int v_nb_levels_to_download = m_webLevels.size();
   int v_nb_levels_performed  = 0;
 
-  v_data.v_WebLevelApp = m_WebLevelApp;
-  v_data.v_nb_levels_to_download = v_nb_levels_to_download;
+  v_data.v_WebApp = m_WebLevelApp;
+  v_data.v_nb_files_to_download = v_nb_levels_to_download;
 
   /* download levels */
   it = m_webLevels.begin();
@@ -633,7 +725,7 @@ void WebLevels::upgrade() {
     float v_percentage = (((float)v_nb_levels_performed) * 100.0) / ((float)v_nb_levels_to_download);
 
     m_WebLevelApp->setTaskProgress(v_percentage);
-    m_WebLevelApp->setBeingDownloadedLevel((*it)->getName(), (*it)->requireUpdate());
+    m_WebLevelApp->setBeingDownloadedInformation((*it)->getName(), (*it)->requireUpdate());
 
     /* should the level be updated */
     to_download = true;
@@ -643,7 +735,7 @@ void WebLevels::upgrade() {
     }
 
     if(to_download) {
-      v_data.v_nb_levels_performed = v_nb_levels_performed;
+      v_data.v_nb_files_performed = v_nb_levels_performed;
       std::string v_destFile;
       
       if((*it)->requireUpdate()) {
@@ -652,23 +744,16 @@ void WebLevels::upgrade() {
 	v_destFile = getDestinationFile(v_url);
       }
       
-      try {
-	FSWeb::downloadFile(v_destFile,
-			    v_url,
-			    f_curl_progress_callback,
-			    &v_data,
-			    m_proxy_settings);
-
-	if((*it)->requireUpdate()) {
-	  m_webLevelsUpdatedDownloadedOK.push_back(v_destFile);
-	} else {
-	  m_webLevelsNewDownloadedOK.push_back(v_destFile);
-	}
-
-      } catch(vapp::Exception &e) {
-	if(m_WebLevelApp->isCancelAsSoonAsPossible() == false) {
-	  throw e;
-	}
+      FSWeb::downloadFileBz2(v_destFile,
+			     v_url,
+			     FSWeb::f_curl_progress_callback,
+			     &v_data,
+			     m_proxy_settings);
+      
+      if((*it)->requireUpdate()) {
+	m_webLevelsUpdatedDownloadedOK.push_back(v_destFile);
+      } else {
+	m_webLevelsNewDownloadedOK.push_back(v_destFile);
       }
     }    
 
@@ -693,6 +778,212 @@ const std::vector<std::string> &WebLevels::getUpdatedDownloadedLevels(void) {
   return m_webLevelsUpdatedDownloadedOK;
 }
 
+WebTheme::WebTheme(std::string pName, std::string pUrl, std::string pSum) {
+  m_name = pName;
+  m_url  = pUrl;
+  m_sum  = pSum;
+}
+
+WebTheme::~WebTheme() {
+}
+
+std::string WebTheme::getName() const {
+  return m_name;
+}
+
+std::string WebTheme::getUrl() const {
+  return m_url;
+}
+
+std::string WebTheme::getSum() const {
+  return m_sum;
+}
+
+WebThemes::WebThemes(vapp::WWWAppInterface *p_WebApp,
+		     const ProxySettings *p_proxy_settings) {
+  m_proxy_settings = p_proxy_settings;
+  m_themes_url     = DEFAULT_WEBTHEMES_URL;
+  m_themes_urlBase = DEFAULT_WEBTHEMES_SPRITESURLBASE;
+  m_WebApp = p_WebApp;
+}
+
+WebThemes::~WebThemes() {
+  clean();
+}
+
+void WebThemes::update() {
+  FSWeb::downloadFileBz2UsingMd5(getXmlFileName(),
+				 m_themes_url,
+				 NULL,
+				 NULL,
+				 m_proxy_settings);
+}
+
+void WebThemes::upgrade() {
+  clean();
+  extractThemesAvailableFromXml();
+}
+
+std::string WebThemes::getXmlFileName() {
+  return vapp::FS::getUserDir() + "/" + DEFAULT_WEBTHEMES_FILENAME;
+}
+
+void WebThemes::extractThemesAvailableFromXml() {
+  vapp::XMLDocument v_webTXml;
+  TiXmlDocument *v_webTXmlData;
+  TiXmlElement *v_webTXmlDataElement;
+  const char *pc;
+  std::string v_themeName, v_url, v_MD5sum_web;
+  
+  v_webTXml.readFromFile(getXmlFileName());
+  v_webTXmlData = v_webTXml.getLowLevelAccess();
+
+  if(v_webTXmlData == NULL) {
+    throw vapp::Exception("error : unable analyse xml theme file");
+  }
+
+  v_webTXmlDataElement = v_webTXmlData->FirstChildElement("xmoto_themes");
+  
+  if(v_webTXmlDataElement == NULL) {
+    throw vapp::Exception("error : unable analyse xml theme file");
+  }
+
+  TiXmlElement *pVarElem = v_webTXmlDataElement->FirstChildElement("theme");
+  while(pVarElem != NULL) {
+    
+    pc = pVarElem->Attribute("name");
+    if(pc != NULL) {
+      v_themeName = pc;
+	
+      pc = pVarElem->Attribute("url");
+      if(pc != NULL) {
+	v_url = pc;	 
+	  
+	pc = pVarElem->Attribute("sum");
+	if(pc != NULL) {
+	  v_MD5sum_web = pc;
+
+	  m_availableThemes.push_back(new WebTheme(v_themeName, v_url, v_MD5sum_web));
+	    
+	}
+      }
+      pVarElem = pVarElem->NextSiblingElement("theme");
+    }
+  }
+}
+
+void WebThemes::clean() {
+  for(unsigned int i=0;i<m_availableThemes.size();i++) {
+    delete m_availableThemes[i];
+  }    
+
+  m_availableThemes.clear();
+}
+
+const std::vector<WebTheme*> &WebThemes::getAvailableThemes() {
+  return m_availableThemes;
+}
+
+void WebThemes::upgrade(ThemeChoice *p_themeChoice) {
+  std::string v_destinationFile;
+  std::string v_sourceFile;
+  WebTheme *v_associated_webtheme;
+  f_curl_download_data v_data;
+  
+  /* no update required */
+  if(p_themeChoice->getHosted() && p_themeChoice->getRequireUpdate() == false) {
+    // do nothing : it give a possibility to download file removed by mistake
+  }
+
+  /* find the associated webtheme */
+  v_associated_webtheme = NULL;
+  for(unsigned int i=0; i<m_availableThemes.size(); i++) {
+    if(m_availableThemes[i]->getName() == p_themeChoice->ThemeName()) {
+      v_associated_webtheme = m_availableThemes[i];
+    }
+  }
+
+  /* the destination file must be in the user dir */
+  if(vapp::FS::isInUserDir(p_themeChoice->ThemeFile())) {
+    v_destinationFile = p_themeChoice->ThemeFile();
+  }
+
+  // theme avaible on the web get it
+  if(v_associated_webtheme != NULL) {
+
+    if(v_destinationFile == "") {
+      /* determine destination file */
+      v_destinationFile = 
+	vapp::FS::getUserDir() + "/" + THEMES_DIRECTORY + "/" + 
+	vapp::FS::getFileBaseName(v_associated_webtheme->getUrl()) + ".xml";
+    }    
+
+    /* download the theme file */
+    vapp::FS::mkArborescence(v_destinationFile);
+    FSWeb::downloadFileBz2(v_destinationFile,
+			   v_associated_webtheme->getUrl(),
+			   NULL,
+			   NULL,
+			   m_proxy_settings);
+  }
+
+  if(v_destinationFile == "") {
+    throw vapp::Exception("error : unable to determine theme destination file");
+  }
+
+  /* download all the files required */
+  Theme *v_theme = new Theme();
+  std::vector<std::string> *v_required_files;
+  v_theme->load(v_destinationFile);
+  v_required_files = v_theme->getRequiredFiles();
+
+  int v_nb_files_to_download = 0;
+  for(unsigned int i=0; i<v_required_files->size(); i++) {
+    if(vapp::FS::fileExists((*v_required_files)[i]) == false) {
+      v_nb_files_to_download++;
+    }
+  }
+  if(v_nb_files_to_download != 0) {
+
+    int v_nb_files_performed  = 0;
+    
+    v_data.v_WebApp = m_WebApp;
+    v_data.v_nb_files_to_download = v_nb_files_to_download;
+
+    unsigned int i = 0;
+    while(i<v_required_files->size() && m_WebApp->isCancelAsSoonAsPossible() == false) {
+      // download v_required_files[i]     
+      v_destinationFile = vapp::FS::getUserDir() + std::string("/") + (*v_required_files)[i];
+      v_sourceFile = m_themes_urlBase + 
+	std::string("/") + (*v_required_files)[i];
+      
+      if(vapp::FS::fileExists((*v_required_files)[i]) == false) {
+	v_data.v_nb_files_performed = v_nb_files_performed;
+	
+	float v_percentage = (((float)v_nb_files_performed) * 100.0) / ((float)v_nb_files_to_download);
+	m_WebApp->setTaskProgress(v_percentage);
+	m_WebApp->setBeingDownloadedInformation((*v_required_files)[i], true);
+
+	vapp::FS::mkArborescence(v_destinationFile);
+
+	FSWeb::downloadFile(v_destinationFile,
+			    v_sourceFile,
+			    FSWeb::f_curl_progress_callback,
+			    &v_data,
+			    m_proxy_settings);
+	
+	v_nb_files_performed++;
+      }
+      m_WebApp->readEvents();
+      i++;
+    }
+    m_WebApp->setTaskProgress(100.0);
+  }
+
+  delete v_theme;
+
+  p_themeChoice->setRequireUpdate(false);
+  p_themeChoice->setHosted(true);
+}
+
 #endif
-
-
