@@ -1,3 +1,24 @@
+/*=============================================================================
+XMOTO
+Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
+
+This file is part of XMOTO.
+
+XMOTO is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+XMOTO is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with XMOTO; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+=============================================================================*/
+
 /* file contributed by Nicolas Adenis-Lamarre */
 
 #ifndef __WWW_H__
@@ -14,6 +35,8 @@
 #endif
 
 #include "WWWAppInterface.h"
+#include "Theme.h"
+class ThemeChoice;
 
 #define DEFAULT_WEBHIGHSCORES_URL         "http://xmoto.free.fr/highscores.xml"
 #define DEFAULT_WEBHIGHSCORES_FILENAME    "webhighscores.xml"
@@ -22,6 +45,11 @@
 #define DEFAULT_WEBLEVELS_URL             "http://xmoto.free.fr/levels.xml"
 #define DEFAULT_WEBLEVELS_FILENAME        "weblevels.xml"
 #define DEFAULT_WEBLEVELS_DIR             "downloaded"
+#define DEFAULT_WEBTHEMES_URL             "http://xmoto.free.fr/themes.xml"
+#define DEFAULT_WEBTHEMES_FILENAME        "webthemes.xml"
+#define DEFAULT_WEBTHEMES_SPRITESURLBASE  "http://xmoto.free.fr/sprites"
+
+#define WWW_AGENT ("xmoto-" + vapp::App::getVersionString())
 
 #if defined(USE_HASH_MAP)
   #ifdef __GNUC__
@@ -93,6 +121,33 @@ class FSWeb {
 							 double ulnow),
 			   void *p_data,
 			   const ProxySettings *p_proxy_settings);
+
+  static void downloadFileBz2(const std::string &p_local_file,
+			      const std::string &p_web_file,
+			      int (*curl_progress_callback)(void *clientp,
+							    double dltotal,
+							    double dlnow,
+							    double ultotal,
+							    double ulnow),
+			      void *p_data,
+			      const ProxySettings *p_proxy_settings);
+
+  static void downloadFileBz2UsingMd5(const std::string &p_local_file,
+				      const std::string &p_web_file,
+				      int (*curl_progress_callback)(void *clientp,
+								    double dltotal,
+								    double dlnow,
+								    double ultotal,
+								    double ulnow),
+				      void *p_data,
+				      const ProxySettings *p_proxy_settings);
+
+  static int f_curl_progress_callback(void *clientp,
+				      double dltotal,
+				      double dlnow,
+				      double ultotal,
+				      double ulnow); 
+
  private:
   static size_t writeData(void *ptr, size_t size, size_t nmemb, FILE *stream);
 };
@@ -220,12 +275,53 @@ class WebLevels {
   std::string getDestinationDir();
   std::string getDestinationFile(std::string p_url);
   void createDestinationDirIfRequired();
-  void extractLevelsToDownloadFromXml(); /* throw exceptions */
-  static int f_curl_progress_callback(void *clientp,
-				      double dltotal,
-				      double dlnow,
-				      double ultotal,
-				      double ulnow);  				      
+  void extractLevelsToDownloadFromXml(); /* throw exceptions */				      
+};
+
+class WebTheme {
+ public:
+  WebTheme(std::string pName, std::string pUrl, std::string pSum);
+  ~WebTheme();
+  std::string getName() const;
+  std::string getUrl() const;
+  std::string getSum() const;
+
+ private:
+  std::string m_name;
+  std::string m_url;
+  std::string m_sum;
+};
+
+class WebThemes {
+ public:
+  WebThemes(vapp::WWWAppInterface *p_WebApp,
+	    const ProxySettings *p_proxy_settings);
+  ~WebThemes();
+
+  /* check for new themes to download */
+  void update(); /* throws exceptions */
+
+  /* fill the list of avaible theme ; does not required an internet connexion */
+  void upgrade();
+
+  /* download a theme or just update it */
+  void upgrade(ThemeChoice *p_themeChoice);
+
+  const std::vector<WebTheme*> &getAvailableThemes();
+
+  void setURL(const std::string &p_url) {m_themes_url = p_url;}
+  void setURLBase(const std::string &p_urlBase) {m_themes_urlBase = p_urlBase;}
+
+ private:
+  std::string getXmlFileName();
+  void extractThemesAvailableFromXml();
+  void clean();
+
+  vapp::WWWAppInterface *m_WebApp;
+  std::string m_themes_url;
+  std::string m_themes_urlBase;
+  const ProxySettings *m_proxy_settings;
+  std::vector<WebTheme*> m_availableThemes;
 };
 
 #endif
